Class: Google::Ads::AdManager::V1::AdMediaDeliveryConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/cdn_config_messages.rb

Overview

Parameters about this CDN config of a CDN used for delivering ad media.

Instance Attribute Summary collapse

Instance Attribute Details

#additional_delivery_settings::Array<::Google::Ads::AdManager::V1::MediaLocation>

Returns Optional. List of additional delivery locations. From MediaLocationDto, the URL prefix field represents the hostname of the external CDN and the security policy will be ignored. In your stream create request, you can set the value of the dai-dlid parameter to the name of the MediaLocation you want to use.

Returns:

  • (::Array<::Google::Ads::AdManager::V1::MediaLocation>)

    Optional. List of additional delivery locations. From MediaLocationDto, the URL prefix field represents the hostname of the external CDN and the security policy will be ignored. In your stream create request, you can set the value of the dai-dlid parameter to the name of the MediaLocation you want to use.



139
140
141
142
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 139

class AdMediaDeliveryConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#delivery_settings::Google::Ads::AdManager::V1::MediaLocation

Returns Optional. Config for the delivery location that will override the default. From MediaLocationDto, the URL prefix field represents the hostname of the external CDN and the security policy will be ignored. Null if overrideDefaultDeliverySettings is false.

Returns:

  • (::Google::Ads::AdManager::V1::MediaLocation)

    Optional. Config for the delivery location that will override the default. From MediaLocationDto, the URL prefix field represents the hostname of the external CDN and the security policy will be ignored. Null if overrideDefaultDeliverySettings is false.



139
140
141
142
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 139

class AdMediaDeliveryConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#override_default_delivery_settings::Boolean

Returns Optional. Whether to override the default delivery CDN. If false, deliverySettings must be null.

Returns:

  • (::Boolean)

    Optional. Whether to override the default delivery CDN. If false, deliverySettings must be null.



139
140
141
142
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 139

class AdMediaDeliveryConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end