Class: Google::Ads::AdManager::V1::AdReviewCenterAd
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::AdReviewCenterAd
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/ad_review_center_ad_messages.rb
Overview
Represents an ad that can be acted on or viewed in the Ad Review Center. AdReviewCenterAd.
Instance Attribute Summary collapse
-
#ad_review_center_ad_id ⇒ ::String
readonly
Output only.
-
#manual_review_statuses ⇒ ::Array<::Google::Ads::AdManager::V1::ManualAdReviewCenterAdStatusEnum::ManualAdReviewCenterAdStatus>
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#preview_url ⇒ ::String
readonly
Output only.
-
#product_type ⇒ ::Google::Ads::AdManager::V1::ExchangeSyndicationProductEnum::ExchangeSyndicationProduct
readonly
Output only.
-
#status ⇒ ::Google::Ads::AdManager::V1::AdReviewCenterAdStatusEnum::AdReviewCenterAdStatus
The status of the AdReviewCenterAd.
Instance Attribute Details
#ad_review_center_ad_id ⇒ ::String (readonly)
Returns Output only. AdReviewCenterAd ID.
53 54 55 56 |
# File 'proto_docs/google/ads/admanager/v1/ad_review_center_ad_messages.rb', line 53 class AdReviewCenterAd include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#manual_review_statuses ⇒ ::Array<::Google::Ads::AdManager::V1::ManualAdReviewCenterAdStatusEnum::ManualAdReviewCenterAdStatus> (readonly)
Returns Output only. The manual review status of the AdReviewCenterAd (for web properties in MCR mode). For MCR mode, a single ad could have multiple statuses (for example, pending and serving at the same time, if the ad is affected by a protection in certain inventory only). This field is not set for the standard mode.
53 54 55 56 |
# File 'proto_docs/google/ads/admanager/v1/ad_review_center_ad_messages.rb', line 53 class AdReviewCenterAd include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The resource name of the AdReviewCenterAd.
Format:
networks/{network_code}/webProperties/{web_property_code}/adReviewCenterAds/{ad_review_center_ad_id}.
53 54 55 56 |
# File 'proto_docs/google/ads/admanager/v1/ad_review_center_ad_messages.rb', line 53 class AdReviewCenterAd include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#preview_url ⇒ ::String (readonly)
Returns Output only. The preview URL that can be embedded or accessed directly which will present the rendered contents of the ad. (This URL expires 72 hours after being retrieved.).
53 54 55 56 |
# File 'proto_docs/google/ads/admanager/v1/ad_review_center_ad_messages.rb', line 53 class AdReviewCenterAd include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#product_type ⇒ ::Google::Ads::AdManager::V1::ExchangeSyndicationProductEnum::ExchangeSyndicationProduct (readonly)
Returns Output only. Specifies the ExchangeSyndicationProduct for this AdReviewCenterAd.
53 54 55 56 |
# File 'proto_docs/google/ads/admanager/v1/ad_review_center_ad_messages.rb', line 53 class AdReviewCenterAd include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#status ⇒ ::Google::Ads::AdManager::V1::AdReviewCenterAdStatusEnum::AdReviewCenterAdStatus
Returns The status of the AdReviewCenterAd.
53 54 55 56 |
# File 'proto_docs/google/ads/admanager/v1/ad_review_center_ad_messages.rb', line 53 class AdReviewCenterAd include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |