Class: Google::Ads::AdManager::V1::AdRule

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/ad_rule_messages.rb

Overview

An AdRule contains data that the ad server will use to generate a playlist of video ads.

Instance Attribute Summary collapse

Instance Attribute Details

#display_name::String

Returns Required. The unique name of the AdRule. This attribute is required to create an ad rule and has a maximum length of 255 characters.

Returns:

  • (::String)

    Required. The unique name of the AdRule. This attribute is required to create an ad rule and has a maximum length of 255 characters.



88
89
90
91
# File 'proto_docs/google/ads/admanager/v1/ad_rule_messages.rb', line 88

class AdRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#end_time::Google::Protobuf::Timestamp

Returns Optional. This end time of the AdRule. This attribute is required unless end_time_unlimited is set to true. If specified, it must be after the start_time.

Returns:



88
89
90
91
# File 'proto_docs/google/ads/admanager/v1/ad_rule_messages.rb', line 88

class AdRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#end_time_unlimited::Boolean

Returns Optional. Specifies whether or not the AdRule has an end time. This attribute is optional and defaults to false.

Returns:

  • (::Boolean)

    Optional. Specifies whether or not the AdRule has an end time. This attribute is optional and defaults to false.



88
89
90
91
# File 'proto_docs/google/ads/admanager/v1/ad_rule_messages.rb', line 88

class AdRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#frequency_cap_behavior::Google::Ads::AdManager::V1::AdRuleFrequencyCapBehaviorEnum::AdRuleFrequencyCapBehavior

Returns Optional. The FrequencyCapBehavior of the AdRule. This attribute is optional and defaults to [FrequencyCapBehavior.DEFER][].

Returns:



88
89
90
91
# File 'proto_docs/google/ads/admanager/v1/ad_rule_messages.rb', line 88

class AdRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_impressions_per_line_item_per_pod::Integer

Returns Optional. This AdRule object's frequency cap for the maximum impressions per pod. This attribute is optional and defaults to 0.

Returns:

  • (::Integer)

    Optional. This AdRule object's frequency cap for the maximum impressions per pod. This attribute is optional and defaults to 0.



88
89
90
91
# File 'proto_docs/google/ads/admanager/v1/ad_rule_messages.rb', line 88

class AdRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_impressions_per_line_item_per_stream::Integer

Returns Optional. This AdRule object's frequency cap for the maximum impressions per stream. This attribute is optional and defaults to 0.

Returns:

  • (::Integer)

    Optional. This AdRule object's frequency cap for the maximum impressions per stream. This attribute is optional and defaults to 0.



88
89
90
91
# File 'proto_docs/google/ads/admanager/v1/ad_rule_messages.rb', line 88

class AdRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#midrolls::Array<::Google::Ads::AdManager::V1::AdRuleSlot>

Returns Required. This AdRule object's video mid-roll slots. This attribute is required, and there must be at least one mid-roll.

Returns:



88
89
90
91
# File 'proto_docs/google/ads/admanager/v1/ad_rule_messages.rb', line 88

class AdRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The resource name of the AdRule. Format: networks/{network_code}/adRules/{ad_rule_id}.

Returns:

  • (::String)

    Identifier. The resource name of the AdRule. Format: networks/{network_code}/adRules/{ad_rule_id}



88
89
90
91
# File 'proto_docs/google/ads/admanager/v1/ad_rule_messages.rb', line 88

class AdRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#postroll::Google::Ads::AdManager::V1::AdRuleSlot

Returns Required. This AdRule object's post-roll slot. This attribute is required.

Returns:



88
89
90
91
# File 'proto_docs/google/ads/admanager/v1/ad_rule_messages.rb', line 88

class AdRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#preroll::Google::Ads::AdManager::V1::AdRuleSlot

Returns Required. This AdRule object's pre-roll slot. This attribute is required.

Returns:



88
89
90
91
# File 'proto_docs/google/ads/admanager/v1/ad_rule_messages.rb', line 88

class AdRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#priority::Integer

Returns Optional. The priority of the AdRule. This attribute is required and can range from 1 to 1000, with 1 being the highest possible priority.

Changing an ad rule's priority can affect the priorities of other ad rules. For example, increasing an ad rule's priority from 5 to 1 will shift the ad rules that were previously in priority positions 1 through 4 down one.

Returns:

  • (::Integer)

    Optional. The priority of the AdRule. This attribute is required and can range from 1 to 1000, with 1 being the highest possible priority.

    Changing an ad rule's priority can affect the priorities of other ad rules. For example, increasing an ad rule's priority from 5 to 1 will shift the ad rules that were previously in priority positions 1 through 4 down one.



88
89
90
91
# File 'proto_docs/google/ads/admanager/v1/ad_rule_messages.rb', line 88

class AdRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_time::Google::Protobuf::Timestamp

Returns Required. The start time of the AdRule. This attribute is required and must be a date in the future for new ad rules.

Returns:

  • (::Google::Protobuf::Timestamp)

    Required. The start time of the AdRule. This attribute is required and must be a date in the future for new ad rules.



88
89
90
91
# File 'proto_docs/google/ads/admanager/v1/ad_rule_messages.rb', line 88

class AdRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#status::Google::Ads::AdManager::V1::AdRuleStatusEnum::AdRuleStatus (readonly)

Returns Output only. The AdRuleStatus of the AdRule. This attribute is read-only and defaults to [AdRuleStatus.INACTIVE][].

Returns:



88
89
90
91
# File 'proto_docs/google/ads/admanager/v1/ad_rule_messages.rb', line 88

class AdRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#targeting::Google::Ads::AdManager::V1::Targeting

Returns Required. The targeting of the AdRule.

Returns:



88
89
90
91
# File 'proto_docs/google/ads/admanager/v1/ad_rule_messages.rb', line 88

class AdRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end