Class: Google::Ads::AdManager::V1::AdSpot

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/ad_spot_messages.rb

Overview

An AdSpot is a targetable entity used in the creation of AdRule objects. A ad spot contains a variable number of ads and has constraints (ad duration, reservation type, etc) on the ads that can appear in it.

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_line_item_types::Array<::Google::Ads::AdManager::V1::LineItemTypeEnum::LineItemType>

Returns Optional. The set of line item types that may appear in the ad spot. This field is optional and defaults to an empty set, which means that all types are allowed. Note, backfill reservation types are controlled by the backfillBlocked field.

Returns:

  • (::Array<::Google::Ads::AdManager::V1::LineItemTypeEnum::LineItemType>)

    Optional. The set of line item types that may appear in the ad spot. This field is optional and defaults to an empty set, which means that all types are allowed. Note, backfill reservation types are controlled by the backfillBlocked field.



89
90
91
92
# File 'proto_docs/google/ads/admanager/v1/ad_spot_messages.rb', line 89

class AdSpot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#backfill_blocked::Boolean

Returns Optional. Whether backfill is blocked in this ad spot. This field is optional and defaults to false.

Returns:

  • (::Boolean)

    Optional. Whether backfill is blocked in this ad spot. This field is optional and defaults to false.



89
90
91
92
# File 'proto_docs/google/ads/admanager/v1/ad_spot_messages.rb', line 89

class AdSpot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#canonical_display_name::String

Returns Optional. Name of the AdSpot. The name is case insensitive and can be referenced in ad tags. This value is required if customSpot is true, and cannot be set otherwise. You can use alphanumeric characters and symbols other than the following: ", ', =, !, +, #, , ~, ;, ^, (, ), <, >, [, ], the white space character.

Returns:

  • (::String)

    Optional. Name of the AdSpot. The name is case insensitive and can be referenced in ad tags. This value is required if customSpot is true, and cannot be set otherwise. You can use alphanumeric characters and symbols other than the following: ", ', =, !, +, #, , ~, ;, ^, (, ), <, >, [, ], the white space character.



89
90
91
92
# File 'proto_docs/google/ads/admanager/v1/ad_spot_messages.rb', line 89

class AdSpot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#custom_spot::Boolean

Returns Optional. Whether this ad spot is a custom spot. This field is optional and defaults to false. Custom spots can be reused and targeted in the targeting picker.

Returns:

  • (::Boolean)

    Optional. Whether this ad spot is a custom spot. This field is optional and defaults to false. Custom spots can be reused and targeted in the targeting picker.



89
90
91
92
# File 'proto_docs/google/ads/admanager/v1/ad_spot_messages.rb', line 89

class AdSpot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String

Returns Optional. Descriptive name for the AdSpot.This value is optional if customSpot is true, and cannot be set otherwise.

Returns:

  • (::String)

    Optional. Descriptive name for the AdSpot.This value is optional if customSpot is true, and cannot be set otherwise.



89
90
91
92
# File 'proto_docs/google/ads/admanager/v1/ad_spot_messages.rb', line 89

class AdSpot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#flexible::Boolean

Returns Optional. Whether this ad spot is a flexible spot. This field is optional and defaults to false. Flexible spots are allowed to have no max number of ads.

Returns:

  • (::Boolean)

    Optional. Whether this ad spot is a flexible spot. This field is optional and defaults to false. Flexible spots are allowed to have no max number of ads.



89
90
91
92
# File 'proto_docs/google/ads/admanager/v1/ad_spot_messages.rb', line 89

class AdSpot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#inventory_sharing_blocked::Boolean

Returns Optional. Whether inventory sharing is blocked in this ad spot. This field is optional and defaults to false.

Returns:

  • (::Boolean)

    Optional. Whether inventory sharing is blocked in this ad spot. This field is optional and defaults to false.



89
90
91
92
# File 'proto_docs/google/ads/admanager/v1/ad_spot_messages.rb', line 89

class AdSpot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_ad_duration::Google::Protobuf::Duration

Returns Required. The maximum allowed duration for ads in the AdSpot. This field is required and must be greater than min_ad_duration.

Returns:



89
90
91
92
# File 'proto_docs/google/ads/admanager/v1/ad_spot_messages.rb', line 89

class AdSpot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_ads::Integer

Returns Optional. The maximum number of ads allowed in the AdSpot. This field is optional and defaults to 0. A value of 0 means that there is no maximum for the number of ads in the ad spot. No max ads is only supported for ad spots that have flexible set to true.

Returns:

  • (::Integer)

    Optional. The maximum number of ads allowed in the AdSpot. This field is optional and defaults to 0. A value of 0 means that there is no maximum for the number of ads in the ad spot. No max ads is only supported for ad spots that have flexible set to true.



89
90
91
92
# File 'proto_docs/google/ads/admanager/v1/ad_spot_messages.rb', line 89

class AdSpot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_duration::Google::Protobuf::Duration

Returns Optional. The maximum total duration for this AdSpot. This field is optional, defaults to 0, and supports precision to the nearest second.

Returns:

  • (::Google::Protobuf::Duration)

    Optional. The maximum total duration for this AdSpot. This field is optional, defaults to 0, and supports precision to the nearest second.



89
90
91
92
# File 'proto_docs/google/ads/admanager/v1/ad_spot_messages.rb', line 89

class AdSpot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#min_ad_duration::Google::Protobuf::Duration

Returns Optional. The minimum allowed duration for ads in the AdSpot. This field is optional and defaults to 0.

Returns:

  • (::Google::Protobuf::Duration)

    Optional. The minimum allowed duration for ads in the AdSpot. This field is optional and defaults to 0.



89
90
91
92
# File 'proto_docs/google/ads/admanager/v1/ad_spot_messages.rb', line 89

class AdSpot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The resource name of the AdSpot. Format: networks/{network_code}/adSpots/{ad_spot_id}.

Returns:

  • (::String)

    Identifier. The resource name of the AdSpot. Format: networks/{network_code}/adSpots/{ad_spot_id}



89
90
91
92
# File 'proto_docs/google/ads/admanager/v1/ad_spot_messages.rb', line 89

class AdSpot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#targeting_type::Google::Ads::AdManager::V1::AdSpotTargetingTypeEnum::AdSpotTargetingType

Returns Optional. The AdSpot TargetingType determines how this ad spot can be targeted. This field is required.

Returns:



89
90
91
92
# File 'proto_docs/google/ads/admanager/v1/ad_spot_messages.rb', line 89

class AdSpot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end