Class: Google::Ads::AdManager::V1::AdUnitService::Rest::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/ads/ad_manager/v1/ad_unit_service/rest/client.rb

Overview

REST client for the AdUnitService service.

Provides methods for handling AdUnit objects.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#ad_unit_path, #label_path, #network_path, #team_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new AdUnitService REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Ads::AdManager::V1::AdUnitService::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Ads::AdManager::V1::AdUnitService::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the AdUnitService client.

Yield Parameters:



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/google/ads/ad_manager/v1/ad_unit_service/rest/client.rb', line 126

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @ad_unit_service_stub = ::Google::Ads::AdManager::V1::AdUnitService::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @ad_unit_service_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the AdUnitService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all AdUnitService clients
::Google::Ads::AdManager::V1::AdUnitService::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/google/ads/ad_manager/v1/ad_unit_service/rest/client.rb', line 64

def self.configure
  @configure ||= begin
    namespace = ["Google", "Ads", "AdManager", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#batch_activate_ad_units(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchActivateAdUnitsResponse #batch_activate_ad_units(parent: nil, names: nil) ⇒ ::Google::Ads::AdManager::V1::BatchActivateAdUnitsResponse

API to batch activate AdUnit objects.

Examples:

Basic example

require "google/ads/ad_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::AdManager::V1::AdUnitService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::AdManager::V1::BatchActivateAdUnitsRequest.new

# Call the batch_activate_ad_units method.
result = client.batch_activate_ad_units request

# The returned object is of type Google::Ads::AdManager::V1::BatchActivateAdUnitsResponse.
p result

Overloads:

  • #batch_activate_ad_units(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchActivateAdUnitsResponse

    Pass arguments to batch_activate_ad_units via a request object, either of type BatchActivateAdUnitsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::AdManager::V1::BatchActivateAdUnitsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #batch_activate_ad_units(parent: nil, names: nil) ⇒ ::Google::Ads::AdManager::V1::BatchActivateAdUnitsResponse

    Pass arguments to batch_activate_ad_units via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. Format: networks/{network_code}

    • names (::Array<::String>) (defaults to: nil)

      Required. The resource names of the AdUnits to activate. Format: networks/{network_code}/adUnits/{ad_unit_id}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
# File 'lib/google/ads/ad_manager/v1/ad_unit_service/rest/client.rb', line 864

def batch_activate_ad_units request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchActivateAdUnitsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.batch_activate_ad_units..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::AdManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.batch_activate_ad_units.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.batch_activate_ad_units.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @ad_unit_service_stub.batch_activate_ad_units request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#batch_archive_ad_units(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchArchiveAdUnitsResponse #batch_archive_ad_units(parent: nil, names: nil) ⇒ ::Google::Ads::AdManager::V1::BatchArchiveAdUnitsResponse

Archives a list of AdUnit objects.

Examples:

Basic example

require "google/ads/ad_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::AdManager::V1::AdUnitService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::AdManager::V1::BatchArchiveAdUnitsRequest.new

# Call the batch_archive_ad_units method.
result = client.batch_archive_ad_units request

# The returned object is of type Google::Ads::AdManager::V1::BatchArchiveAdUnitsResponse.
p result

Overloads:

  • #batch_archive_ad_units(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchArchiveAdUnitsResponse

    Pass arguments to batch_archive_ad_units via a request object, either of type BatchArchiveAdUnitsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::AdManager::V1::BatchArchiveAdUnitsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #batch_archive_ad_units(parent: nil, names: nil) ⇒ ::Google::Ads::AdManager::V1::BatchArchiveAdUnitsResponse

    Pass arguments to batch_archive_ad_units via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. Format: networks/{network_code}

    • names (::Array<::String>) (defaults to: nil)

      Required. The resource names of the AdUnits to archive. Format: networks/{network_code}/adUnits/{ad_unit_id}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
# File 'lib/google/ads/ad_manager/v1/ad_unit_service/rest/client.rb', line 1026

def batch_archive_ad_units request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchArchiveAdUnitsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.batch_archive_ad_units..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::AdManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.batch_archive_ad_units.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.batch_archive_ad_units.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @ad_unit_service_stub.batch_archive_ad_units request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#batch_create_ad_units(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchCreateAdUnitsResponse #batch_create_ad_units(parent: nil, requests: nil) ⇒ ::Google::Ads::AdManager::V1::BatchCreateAdUnitsResponse

API to batch create AdUnit objects.

Examples:

Basic example

require "google/ads/ad_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::AdManager::V1::AdUnitService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::AdManager::V1::BatchCreateAdUnitsRequest.new

# Call the batch_create_ad_units method.
result = client.batch_create_ad_units request

# The returned object is of type Google::Ads::AdManager::V1::BatchCreateAdUnitsResponse.
p result

Overloads:

  • #batch_create_ad_units(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchCreateAdUnitsResponse

    Pass arguments to batch_create_ad_units via a request object, either of type BatchCreateAdUnitsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::AdManager::V1::BatchCreateAdUnitsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #batch_create_ad_units(parent: nil, requests: nil) ⇒ ::Google::Ads::AdManager::V1::BatchCreateAdUnitsResponse

    Pass arguments to batch_create_ad_units via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource where AdUnits will be created. Format: networks/{network_code} The parent field in the CreateAdUnitRequest must match this field.

    • requests (::Array<::Google::Ads::AdManager::V1::CreateAdUnitRequest, ::Hash>) (defaults to: nil)

      Required. The AdUnit objects to create. A maximum of 100 objects can be created in a batch.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
# File 'lib/google/ads/ad_manager/v1/ad_unit_service/rest/client.rb', line 699

def batch_create_ad_units request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchCreateAdUnitsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.batch_create_ad_units..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::AdManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.batch_create_ad_units.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.batch_create_ad_units.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @ad_unit_service_stub.batch_create_ad_units request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#batch_deactivate_ad_units(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchDeactivateAdUnitsResponse #batch_deactivate_ad_units(parent: nil, names: nil) ⇒ ::Google::Ads::AdManager::V1::BatchDeactivateAdUnitsResponse

Deactivates a list of AdUnit objects.

Examples:

Basic example

require "google/ads/ad_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::AdManager::V1::AdUnitService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::AdManager::V1::BatchDeactivateAdUnitsRequest.new

# Call the batch_deactivate_ad_units method.
result = client.batch_deactivate_ad_units request

# The returned object is of type Google::Ads::AdManager::V1::BatchDeactivateAdUnitsResponse.
p result

Overloads:

  • #batch_deactivate_ad_units(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchDeactivateAdUnitsResponse

    Pass arguments to batch_deactivate_ad_units via a request object, either of type BatchDeactivateAdUnitsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::AdManager::V1::BatchDeactivateAdUnitsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #batch_deactivate_ad_units(parent: nil, names: nil) ⇒ ::Google::Ads::AdManager::V1::BatchDeactivateAdUnitsResponse

    Pass arguments to batch_deactivate_ad_units via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. Format: networks/{network_code}

    • names (::Array<::String>) (defaults to: nil)

      Required. The resource names of the AdUnits to deactivate. Format: networks/{network_code}/adUnits/{ad_unit_id}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
# File 'lib/google/ads/ad_manager/v1/ad_unit_service/rest/client.rb', line 945

def batch_deactivate_ad_units request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchDeactivateAdUnitsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.batch_deactivate_ad_units..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::AdManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.batch_deactivate_ad_units.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.batch_deactivate_ad_units.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @ad_unit_service_stub.batch_deactivate_ad_units request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#batch_update_ad_units(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchUpdateAdUnitsResponse #batch_update_ad_units(parent: nil, requests: nil) ⇒ ::Google::Ads::AdManager::V1::BatchUpdateAdUnitsResponse

API to batch update AdUnit objects.

Examples:

Basic example

require "google/ads/ad_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::AdManager::V1::AdUnitService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::AdManager::V1::BatchUpdateAdUnitsRequest.new

# Call the batch_update_ad_units method.
result = client.batch_update_ad_units request

# The returned object is of type Google::Ads::AdManager::V1::BatchUpdateAdUnitsResponse.
p result

Overloads:

  • #batch_update_ad_units(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchUpdateAdUnitsResponse

    Pass arguments to batch_update_ad_units via a request object, either of type BatchUpdateAdUnitsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::AdManager::V1::BatchUpdateAdUnitsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #batch_update_ad_units(parent: nil, requests: nil) ⇒ ::Google::Ads::AdManager::V1::BatchUpdateAdUnitsResponse

    Pass arguments to batch_update_ad_units via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource where AdUnits will be updated. Format: networks/{network_code} The parent field in the UpdateAdUnitRequest must match this field.

    • requests (::Array<::Google::Ads::AdManager::V1::UpdateAdUnitRequest, ::Hash>) (defaults to: nil)

      Required. The AdUnit objects to update. A maximum of 100 objects can be updated in a batch.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
# File 'lib/google/ads/ad_manager/v1/ad_unit_service/rest/client.rb', line 783

def batch_update_ad_units request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchUpdateAdUnitsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.batch_update_ad_units..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::AdManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.batch_update_ad_units.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.batch_update_ad_units.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @ad_unit_service_stub.batch_update_ad_units request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#configure {|config| ... } ⇒ Client::Configuration

Configure the AdUnitService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



96
97
98
99
# File 'lib/google/ads/ad_manager/v1/ad_unit_service/rest/client.rb', line 96

def configure
  yield @config if block_given?
  @config
end

#create_ad_unit(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::AdUnit #create_ad_unit(parent: nil, ad_unit: nil) ⇒ ::Google::Ads::AdManager::V1::AdUnit

API to create an AdUnit object.

Examples:

Basic example

require "google/ads/ad_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::AdManager::V1::AdUnitService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::AdManager::V1::CreateAdUnitRequest.new

# Call the create_ad_unit method.
result = client.create_ad_unit request

# The returned object is of type Google::Ads::AdManager::V1::AdUnit.
p result

Overloads:

  • #create_ad_unit(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::AdUnit

    Pass arguments to create_ad_unit via a request object, either of type CreateAdUnitRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::AdManager::V1::CreateAdUnitRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #create_ad_unit(parent: nil, ad_unit: nil) ⇒ ::Google::Ads::AdManager::V1::AdUnit

    Pass arguments to create_ad_unit via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource where this AdUnit will be created. Format: networks/{network_code}

    • ad_unit (::Google::Ads::AdManager::V1::AdUnit, ::Hash) (defaults to: nil)

      Required. The AdUnit to create.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
# File 'lib/google/ads/ad_manager/v1/ad_unit_service/rest/client.rb', line 532

def create_ad_unit request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::CreateAdUnitRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_ad_unit..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::AdManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_ad_unit.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_ad_unit.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @ad_unit_service_stub.create_ad_unit request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_ad_unit(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::AdUnit #get_ad_unit(name: nil) ⇒ ::Google::Ads::AdManager::V1::AdUnit

API to retrieve an AdUnit object.

Examples:

Basic example

require "google/ads/ad_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::AdManager::V1::AdUnitService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::AdManager::V1::GetAdUnitRequest.new

# Call the get_ad_unit method.
result = client.get_ad_unit request

# The returned object is of type Google::Ads::AdManager::V1::AdUnit.
p result

Overloads:

  • #get_ad_unit(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::AdUnit

    Pass arguments to get_ad_unit via a request object, either of type GetAdUnitRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::AdManager::V1::GetAdUnitRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_ad_unit(name: nil) ⇒ ::Google::Ads::AdManager::V1::AdUnit

    Pass arguments to get_ad_unit via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The resource name of the AdUnit. Format: networks/{network_code}/adUnits/{ad_unit_id}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/google/ads/ad_manager/v1/ad_unit_service/rest/client.rb', line 223

def get_ad_unit request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::GetAdUnitRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_ad_unit..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::AdManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_ad_unit.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_ad_unit.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @ad_unit_service_stub.get_ad_unit request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_ad_unit_sizes(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::AdUnitSize> #list_ad_unit_sizes(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil, skip: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::AdUnitSize>

API to retrieve a list of AdUnitSize objects.

Examples:

Basic example

require "google/ads/ad_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::AdManager::V1::AdUnitService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::AdManager::V1::ListAdUnitSizesRequest.new

# Call the list_ad_unit_sizes method.
result = client.list_ad_unit_sizes request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Ads::AdManager::V1::AdUnitSize.
  p item
end

Overloads:

  • #list_ad_unit_sizes(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::AdUnitSize>

    Pass arguments to list_ad_unit_sizes via a request object, either of type ListAdUnitSizesRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::AdManager::V1::ListAdUnitSizesRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_ad_unit_sizes(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil, skip: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::AdUnitSize>

    Pass arguments to list_ad_unit_sizes via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent, which owns this collection of AdUnitSizes. Format: networks/{network_code}

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of AdUnitSizes to return. The service may return fewer than this value. If unspecified, at most 50 ad unit sizes will be returned. The maximum value is 1000; values greater than 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous ListAdUnitSizes call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListAdUnitSizes must match the call that provided the page token.

    • filter (::String) (defaults to: nil)

      Optional. Expression to filter the response. See syntax details at https://developers.google.com/ad-manager/api/beta/filters

    • order_by (::String) (defaults to: nil)

      Optional. Expression to specify sorting order. See syntax details at https://developers.google.com/ad-manager/api/beta/filters#order

    • skip (::Integer) (defaults to: nil)

      Optional. Number of individual resources to skip while paginating.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
# File 'lib/google/ads/ad_manager/v1/ad_unit_service/rest/client.rb', line 449

def list_ad_unit_sizes request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::ListAdUnitSizesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_ad_unit_sizes..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::AdManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_ad_unit_sizes.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_ad_unit_sizes.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @ad_unit_service_stub.list_ad_unit_sizes request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @ad_unit_service_stub, :list_ad_unit_sizes, "ad_unit_sizes", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_ad_units(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::AdUnit> #list_ad_units(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil, skip: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::AdUnit>

API to retrieve a list of AdUnit objects.

Examples:

Basic example

require "google/ads/ad_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::AdManager::V1::AdUnitService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::AdManager::V1::ListAdUnitsRequest.new

# Call the list_ad_units method.
result = client.list_ad_units request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Ads::AdManager::V1::AdUnit.
  p item
end

Overloads:

  • #list_ad_units(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::AdUnit>

    Pass arguments to list_ad_units via a request object, either of type ListAdUnitsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::AdManager::V1::ListAdUnitsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_ad_units(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil, skip: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::AdUnit>

    Pass arguments to list_ad_units via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent, which owns this collection of AdUnits. Format: networks/{network_code}

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of AdUnits to return. The service may return fewer than this value. If unspecified, at most 50 ad units will be returned. The maximum value is 1000; values greater than 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous ListAdUnits call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListAdUnits must match the call that provided the page token.

    • filter (::String) (defaults to: nil)

      Optional. Expression to filter the response. See syntax details at https://developers.google.com/ad-manager/api/beta/filters

      Filterable fields:

      • adUnitCode
      • adUnitSizes.canonicalName
      • displayName
      • effectiveAdsenseEnabled
      • explicitlyTargeted
      • externalSetTopBoxChannelId
      • hasChildren
      • name
      • parentAdUnit
      • status
      • teams
      • updateTime
    • order_by (::String) (defaults to: nil)

      Optional. Expression to specify sorting order. See syntax details at https://developers.google.com/ad-manager/api/beta/filters#order

    • skip (::Integer) (defaults to: nil)

      Optional. Number of individual resources to skip while paginating.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/google/ads/ad_manager/v1/ad_unit_service/rest/client.rb', line 343

def list_ad_units request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::ListAdUnitsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_ad_units..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::AdManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_ad_units.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_ad_units.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @ad_unit_service_stub.list_ad_units request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @ad_unit_service_stub, :list_ad_units, "ad_units", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


173
174
175
# File 'lib/google/ads/ad_manager/v1/ad_unit_service/rest/client.rb', line 173

def logger
  @ad_unit_service_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


106
107
108
# File 'lib/google/ads/ad_manager/v1/ad_unit_service/rest/client.rb', line 106

def universe_domain
  @ad_unit_service_stub.universe_domain
end

#update_ad_unit(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::AdUnit #update_ad_unit(ad_unit: nil, update_mask: nil) ⇒ ::Google::Ads::AdManager::V1::AdUnit

API to update an AdUnit object.

Examples:

Basic example

require "google/ads/ad_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::AdManager::V1::AdUnitService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::AdManager::V1::UpdateAdUnitRequest.new

# Call the update_ad_unit method.
result = client.update_ad_unit request

# The returned object is of type Google::Ads::AdManager::V1::AdUnit.
p result

Overloads:

  • #update_ad_unit(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::AdUnit

    Pass arguments to update_ad_unit via a request object, either of type UpdateAdUnitRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::AdManager::V1::UpdateAdUnitRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #update_ad_unit(ad_unit: nil, update_mask: nil) ⇒ ::Google::Ads::AdManager::V1::AdUnit

    Pass arguments to update_ad_unit via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • ad_unit (::Google::Ads::AdManager::V1::AdUnit, ::Hash) (defaults to: nil)

      Required. The AdUnit to update.

      The AdUnit's name is used to identify the AdUnit to update. Format: networks/{network_code}/adUnits/{ad_unit_id}

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      Optional. The list of fields to update.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
# File 'lib/google/ads/ad_manager/v1/ad_unit_service/rest/client.rb', line 615

def update_ad_unit request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::UpdateAdUnitRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_ad_unit..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::AdManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.update_ad_unit.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_ad_unit.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @ad_unit_service_stub.update_ad_unit request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end