Module: Google::Ads::AdManager::V1::ApplicationApprovalStatusEnum::ApplicationApprovalStatus

Defined in:
proto_docs/google/ads/admanager/v1/application_enums.rb

Overview

The approval status of the application.

Constant Summary collapse

APPLICATION_APPROVAL_STATUS_UNSPECIFIED =

Default value. This value is unused.

0
APPEALING =

The application is disapproved but has a pending review status, signaling an appeal.

1
APPROVED =

The application can serve ads.

2
DISAPPROVED =

The application failed approval checks and it cannot serve any ads.

3
DRAFT =

The application is not yet ready for review.

4
UNCHECKED =

The application has not yet been reviewed.

5