Class: Google::Ads::AdManager::V1::AuxiliaryAdSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/live_stream_messages.rb

Overview

Settings for auxiliary ads (e.g. pause ads) on a live stream.

Instance Attribute Summary collapse

Instance Attribute Details

#ad_tag_url::String

Returns Required. The ad tag URL used to request auxiliary ads (such as pause ads). This can be a Google Ad Manager ad tag or a third-party ad tag. Publishers are responsible for ensuring the correctness of the URL.

Returns:

  • (::String)

    Required. The ad tag URL used to request auxiliary ads (such as pause ads). This can be a Google Ad Manager ad tag or a third-party ad tag. Publishers are responsible for ensuring the correctness of the URL.



289
290
291
292
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 289

class AuxiliaryAdSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end