Class: Google::Ads::AdManager::V1::BatchDeactivateTargetingPresetsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/targeting_preset_service.rb

Overview

Response message for DeactivateTargetingPresets method.

Instance Attribute Summary collapse

Instance Attribute Details

#change_count::Integer

Returns The number of objects that were deactivated as a result of performing the action.

Returns:

  • (::Integer)

    The number of objects that were deactivated as a result of performing the action.



172
173
174
175
# File 'proto_docs/google/ads/admanager/v1/targeting_preset_service.rb', line 172

class BatchDeactivateTargetingPresetsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end