Class: Google::Ads::AdManager::V1::BatchSubmitOrdersForApprovalRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/order_service.rb

Overview

Request message for BatchSubmitOrdersForApproval method.

Instance Attribute Summary collapse

Instance Attribute Details

#names::Array<::String>

Returns Required. The resource names of the orders to submit for approval. Format: networks/{network_code}/orders/{order_id}.

Returns:

  • (::Array<::String>)

    Required. The resource names of the orders to submit for approval. Format: networks/{network_code}/orders/{order_id}



85
86
87
88
# File 'proto_docs/google/ads/admanager/v1/order_service.rb', line 85

class BatchSubmitOrdersForApprovalRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent, which owns this collection of Orders. Format: networks/{network_code}.

Returns:

  • (::String)

    Required. The parent, which owns this collection of Orders. Format: networks/{network_code}



85
86
87
88
# File 'proto_docs/google/ads/admanager/v1/order_service.rb', line 85

class BatchSubmitOrdersForApprovalRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#skip_inventory_check::Boolean

Returns Optional. Indicates whether the inventory check should be skipped when performing this action.

Returns:

  • (::Boolean)

    Optional. Indicates whether the inventory check should be skipped when performing this action.



85
86
87
88
# File 'proto_docs/google/ads/admanager/v1/order_service.rb', line 85

class BatchSubmitOrdersForApprovalRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end