Class: Google::Ads::AdManager::V1::CdnConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/cdn_config_messages.rb

Overview

A CdnConfig encapsulates information about where and how to ingest and deliver content enabled for DAI (Dynamic Ad Insertion).

Instance Attribute Summary collapse

Instance Attribute Details

#ad_media_delivery_config::Google::Ads::AdManager::V1::AdMediaDeliveryConfig

Returns Optional. Config of CDN to deliver ad media.

Returns:



48
49
50
51
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 48

class CdnConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#cdn_config_status::Google::Ads::AdManager::V1::CdnConfigStatusEnum::CdnConfigStatus (readonly)

Returns Output only. The status of the CDN config.

Returns:



48
49
50
51
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 48

class CdnConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#cdn_config_type::Google::Ads::AdManager::V1::CdnConfigTypeEnum::CdnConfigType

Returns Required. The type of CDN config represented by this CdnConfig.

Returns:



48
49
50
51
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 48

class CdnConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String

Returns Required. The name of the CdnConfig. This value is required to create a CDN config and has a maximum length of 255 characters.

Returns:

  • (::String)

    Required. The name of the CdnConfig. This value is required to create a CDN config and has a maximum length of 255 characters.



48
49
50
51
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 48

class CdnConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The resource name of the CdnConfig. Format: networks/{network_code}/cdnConfigs/{cdn_config_id}.

Returns:

  • (::String)

    Identifier. The resource name of the CdnConfig. Format: networks/{network_code}/cdnConfigs/{cdn_config_id}



48
49
50
51
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 48

class CdnConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#source_content_config::Google::Ads::AdManager::V1::SourceContentConfig

Returns Optional. Parameters about this CDN config as a source of content. This facilitates fetching the original content for conditioning and delivering the original content as part of a modified stream.

Returns:

  • (::Google::Ads::AdManager::V1::SourceContentConfig)

    Optional. Parameters about this CDN config as a source of content. This facilitates fetching the original content for conditioning and delivering the original content as part of a modified stream.



48
49
50
51
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 48

class CdnConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end