Module: Google::Ads::AdManager::V1::CdnSecurityPolicyOriginForwardingEnum::CdnSecurityPolicyOriginForwarding

Defined in:
proto_docs/google/ads/admanager/v1/cdn_security_policy_origin_forwarding_enum.rb

Overview

Indicates the type of origin forwarding used to support Akamai authentication policies for LiveStreamEvent.

Constant Summary collapse

CDN_SECURITY_POLICY_ORIGIN_FORWARDING_UNSPECIFIED =

Default value. This value is unused.

0
CONVENTIONAL =

Indicates that conventional origin forwarding is used.

1
NONE =

Indicates that origin forwarding is not being used.

2
ORIGIN_PATH =

Indicates that origin forwarding is set up by passing an origin path query string parameter (necessary for Akamai dynamic packaging to work).

3