Module: Google::Ads::AdManager::V1::ChildContentEligibilityEnum::ChildContentEligibility

Defined in:
proto_docs/google/ads/admanager/v1/child_content_eligibility_enum.rb

Overview

Child content eligibility designation.

Constant Summary collapse

CHILD_CONTENT_ELIGIBILITY_UNSPECIFIED =

Default value. This value is unused.

0
ALLOWED =

This line item is eligible to serve on requests that are child-directed.

1
DISALLOWED =

This line item is not eligible to serve on any requests that are child-directed.

2