Module: Google::Ads::AdManager::V1::CompanionDeliveryOptionEnum::CompanionDeliveryOption
- Defined in:
- proto_docs/google/ads/admanager/v1/delivery_enums.rb
Overview
Defines the different delivery types of a line item companion.
Constant Summary collapse
- COMPANION_DELIVERY_OPTION_UNSPECIFIED =
No value specified.
0- OPTIONAL =
Companions are not required to serve a CreativeSet. The creative set can serve to inventory that has zero or more matching companions.
1- AT_LEAST_ONE =
At least one companion must be served in order for the creative set to be used.
2- ALL =
All companions in the set must be served in order for the creative set to be used. This can still serve to inventory that has more companions than can be filled.
3