Class: Google::Ads::AdManager::V1::ContactService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::ContactService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/ads/ad_manager/v1/contact_service/rest/client.rb
Overview
REST client for the ContactService service.
Provides methods for handling Contact objects.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the ContactService Client class.
Instance Method Summary collapse
-
#batch_create_contacts(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::BatchCreateContactsResponse
API to batch create
Contactobjects. -
#batch_update_contacts(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::BatchUpdateContactsResponse
API to batch update
Contactobjects. -
#configure {|config| ... } ⇒ Client::Configuration
Configure the ContactService Client instance.
-
#create_contact(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::Contact
API to create a
Contactobject. -
#get_contact(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::Contact
API to retrieve a
Contactobject. -
#initialize {|config| ... } ⇒ Client
constructor
Create a new ContactService REST client object.
-
#list_contacts(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::Contact>
API to retrieve a list of
Contactobjects. -
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_contact(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::Contact
API to update a
Contactobject.
Methods included from Paths
#company_path, #contact_path, #network_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new ContactService REST client object.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/google/ads/ad_manager/v1/contact_service/rest/client.rb', line 126 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @contact_service_stub = ::Google::Ads::AdManager::V1::ContactService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @contact_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the ContactService Client class.
See Configuration for a description of the configuration fields.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/google/ads/ad_manager/v1/contact_service/rest/client.rb', line 64 def self.configure @configure ||= begin namespace = ["Google", "Ads", "AdManager", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config end yield @configure if block_given? @configure end |
Instance Method Details
#batch_create_contacts(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchCreateContactsResponse #batch_create_contacts(parent: nil, requests: nil) ⇒ ::Google::Ads::AdManager::V1::BatchCreateContactsResponse
API to batch create Contact objects.
509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/google/ads/ad_manager/v1/contact_service/rest/client.rb', line 509 def batch_create_contacts request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchCreateContactsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_create_contacts..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.batch_create_contacts.timeout, metadata: , retry_policy: @config.rpcs.batch_create_contacts.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @contact_service_stub.batch_create_contacts request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#batch_update_contacts(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchUpdateContactsResponse #batch_update_contacts(parent: nil, requests: nil) ⇒ ::Google::Ads::AdManager::V1::BatchUpdateContactsResponse
API to batch update Contact objects.
675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 |
# File 'lib/google/ads/ad_manager/v1/contact_service/rest/client.rb', line 675 def batch_update_contacts request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchUpdateContactsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_update_contacts..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.batch_update_contacts.timeout, metadata: , retry_policy: @config.rpcs.batch_update_contacts.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @contact_service_stub.batch_update_contacts request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the ContactService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
96 97 98 99 |
# File 'lib/google/ads/ad_manager/v1/contact_service/rest/client.rb', line 96 def configure yield @config if block_given? @config end |
#create_contact(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::Contact #create_contact(parent: nil, contact: nil) ⇒ ::Google::Ads::AdManager::V1::Contact
API to create a Contact object.
425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 |
# File 'lib/google/ads/ad_manager/v1/contact_service/rest/client.rb', line 425 def create_contact request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::CreateContactRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_contact..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_contact.timeout, metadata: , retry_policy: @config.rpcs.create_contact.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @contact_service_stub.create_contact request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_contact(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::Contact #get_contact(name: nil) ⇒ ::Google::Ads::AdManager::V1::Contact
API to retrieve a Contact object.
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/google/ads/ad_manager/v1/contact_service/rest/client.rb', line 223 def get_contact request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::GetContactRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_contact..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_contact.timeout, metadata: , retry_policy: @config.rpcs.get_contact.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @contact_service_stub.get_contact request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_contacts(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::Contact> #list_contacts(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil, skip: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::Contact>
API to retrieve a list of Contact objects.
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/google/ads/ad_manager/v1/contact_service/rest/client.rb', line 342 def list_contacts request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::ListContactsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_contacts..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_contacts.timeout, metadata: , retry_policy: @config.rpcs.list_contacts.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @contact_service_stub.list_contacts request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @contact_service_stub, :list_contacts, "contacts", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
173 174 175 |
# File 'lib/google/ads/ad_manager/v1/contact_service/rest/client.rb', line 173 def logger @contact_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
106 107 108 |
# File 'lib/google/ads/ad_manager/v1/contact_service/rest/client.rb', line 106 def universe_domain @contact_service_stub.universe_domain end |
#update_contact(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::Contact #update_contact(contact: nil, update_mask: nil) ⇒ ::Google::Ads::AdManager::V1::Contact
API to update a Contact object.
591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 |
# File 'lib/google/ads/ad_manager/v1/contact_service/rest/client.rb', line 591 def update_contact request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::UpdateContactRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_contact..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_contact.timeout, metadata: , retry_policy: @config.rpcs.update_contact.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @contact_service_stub.update_contact request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |