Class: Google::Ads::AdManager::V1::ContentBundle

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/content_bundle_messages.rb

Overview

A ContentBundle is a grouping of individual Content. A ContentBundle is defined as including the Content that match certain filter rules along with the option to explicitly include or exclude certain Content IDs.

Instance Attribute Summary collapse

Instance Attribute Details

#display_name::String

Returns Required. The name of the ContentBundle. This attribute is required and has a maximum length of 255 characters.

Returns:

  • (::String)

    Required. The name of the ContentBundle. This attribute is required and has a maximum length of 255 characters.



48
49
50
51
# File 'proto_docs/google/ads/admanager/v1/content_bundle_messages.rb', line 48

class ContentBundle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The resource name of the ContentBundle. Format: networks/{network_code}/contentBundles/{content_bundle_id}.

Returns:

  • (::String)

    Identifier. The resource name of the ContentBundle. Format: networks/{network_code}/contentBundles/{content_bundle_id}



48
49
50
51
# File 'proto_docs/google/ads/admanager/v1/content_bundle_messages.rb', line 48

class ContentBundle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#status::Google::Ads::AdManager::V1::ContentBundleStatusEnum::ContentBundleStatus (readonly)

Returns Output only. The ContentBundleStatus of the ContentBundle. This attribute is read-only and defaults to [ContentBundleStatus.INACTIVE][].

Returns:



48
49
50
51
# File 'proto_docs/google/ads/admanager/v1/content_bundle_messages.rb', line 48

class ContentBundle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time the ContentBundle was last modified.

Returns:



48
49
50
51
# File 'proto_docs/google/ads/admanager/v1/content_bundle_messages.rb', line 48

class ContentBundle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end