Module: Google::Ads::AdManager::V1::ContentStatusEnum::ContentStatus

Defined in:
proto_docs/google/ads/admanager/v1/content_enums.rb

Overview

Describes the status of a Content object.

Constant Summary collapse

CONTENT_STATUS_UNSPECIFIED =

Default value. This value is unused.

0
ACTIVE =

Indicates the Content has been created and is eligible to have ads served against it.

1
INACTIVE =

Indicates the Content has been deactivated and cannot have ads served against it.

2
ARCHIVED =

Indicates the Content has been archived; user-visible.

3
DELETED =

Indicates the Content has been removed from an external CMS.

4
DUPLICATED =

Indicates the Content is a duplicate of another piece of content.

5