Module: Google::Ads::AdManager::V1::ContentStatusSourceEnum::ContentStatusSource

Defined in:
proto_docs/google/ads/admanager/v1/content_enums.rb

Overview

Describes who defined the status of the Content object.

Constant Summary collapse

CONTENT_STATUS_SOURCE_UNSPECIFIED =

Default value. This value is unused.

0
CMS =

Indicates that the status of the Content is defined by the CMS.

1
USER =

Indicates that the status of the Content is defined by the user.

2