Class: Google::Ads::AdManager::V1::CreateLabelRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/label_service.rb

Overview

Request object for CreateLabel method.

Instance Attribute Summary collapse

Instance Attribute Details

#label::Google::Ads::AdManager::V1::Label

Returns Required. The Label to create.

Returns:



113
114
115
116
# File 'proto_docs/google/ads/admanager/v1/label_service.rb', line 113

class CreateLabelRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource where this Label will be created. Format: networks/{network_code}.

Returns:

  • (::String)

    Required. The parent resource where this Label will be created. Format: networks/{network_code}



113
114
115
116
# File 'proto_docs/google/ads/admanager/v1/label_service.rb', line 113

class CreateLabelRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end