Class: Google::Ads::AdManager::V1::CreateSlateRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/slate_service.rb

Overview

Request object for CreateSlate method.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The parent resource where this Slate will be created. Format: networks/{network_code}.

Returns:

  • (::String)

    Required. The parent resource where this Slate will be created. Format: networks/{network_code}



103
104
105
106
# File 'proto_docs/google/ads/admanager/v1/slate_service.rb', line 103

class CreateSlateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#slate::Google::Ads::AdManager::V1::Slate

Returns Required. The Slate to create.

Returns:



103
104
105
106
# File 'proto_docs/google/ads/admanager/v1/slate_service.rb', line 103

class CreateSlateRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end