Class: Google::Ads::AdManager::V1::CreativePlaceholder

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/creative_placeholder.rb

Overview

Describes a slot that a creative is expected to fill. This is used in forecasting and to validate that the correct creatives are associated with the line item.

Instance Attribute Summary collapse

Instance Attribute Details

#amp_only::Boolean

Returns Optional. Non-empty default. Indicates if the expected creative of this placeholder has an AMP only variant. This is used to improve the accuracy of forecasting and has no effect on serving. By default, the value is false.

Returns:

  • (::Boolean)

    Optional. Non-empty default. Indicates if the expected creative of this placeholder has an AMP only variant. This is used to improve the accuracy of forecasting and has no effect on serving. By default, the value is false.



58
59
60
61
# File 'proto_docs/google/ads/admanager/v1/creative_placeholder.rb', line 58

class CreativePlaceholder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#applied_labels::Array<::Google::Ads::AdManager::V1::AppliedLabel>

Returns Optional. Set of labels applied directly to this CreativePlaceholder.

Returns:



58
59
60
61
# File 'proto_docs/google/ads/admanager/v1/creative_placeholder.rb', line 58

class CreativePlaceholder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#companions::Array<::Google::Ads::AdManager::V1::CreativePlaceholderCompanion>

Returns Optional. The companions that the creative is expected to have. This attribute can only be set if the line item it belongs to has an EnvironmentType of VIDEO_PLAYER or roadblocking_type of CREATIVE_SET.

Returns:



58
59
60
61
# File 'proto_docs/google/ads/admanager/v1/creative_placeholder.rb', line 58

class CreativePlaceholder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#creative_targeting_display_name::String

Returns Optional. The display name of the creative targeting that this CreativePlaceholder represents.

Returns:

  • (::String)

    Optional. The display name of the creative targeting that this CreativePlaceholder represents.



58
59
60
61
# File 'proto_docs/google/ads/admanager/v1/creative_placeholder.rb', line 58

class CreativePlaceholder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#expected_creative_count::Integer

Returns Optional. Non-empty default. Expected number of creatives that will be uploaded corresponding to this creative placeholder. This estimate is used to improve the accuracy of forecasting; for example, if label frequency capping limits the number of times a creative may be served. By default, the expected creative count is set to 1.

Returns:

  • (::Integer)

    Optional. Non-empty default. Expected number of creatives that will be uploaded corresponding to this creative placeholder. This estimate is used to improve the accuracy of forecasting; for example, if label frequency capping limits the number of times a creative may be served. By default, the expected creative count is set to 1.



58
59
60
61
# File 'proto_docs/google/ads/admanager/v1/creative_placeholder.rb', line 58

class CreativePlaceholder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#size::Google::Ads::AdManager::V1::Size

Returns Required. The size that the creative is expected to have.

Returns:



58
59
60
61
# File 'proto_docs/google/ads/admanager/v1/creative_placeholder.rb', line 58

class CreativePlaceholder
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end