Class: Google::Ads::AdManager::V1::CreativeTemplateVariable::AssetCreativeTemplateVariable

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/creative_template_messages.rb

Overview

Represents a file asset variable defined in a creative template.

Use [AssetCreativeTemplateVariableValue][] to specify the value for this variable when creating a [TemplateCreative][] from a CreativeTemplate.

Defined Under Namespace

Modules: MimeType

Instance Attribute Summary collapse

Instance Attribute Details

#mime_types::Array<::Google::Ads::AdManager::V1::CreativeTemplateVariable::AssetCreativeTemplateVariable::MimeType>

Returns Optional. The set of allowed MIME types. If unspecified, all MIME types are allowed.

Returns:

  • Optional. The set of allowed MIME types. If unspecified, all MIME types are allowed.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/ads/admanager/v1/creative_template_messages.rb', line 129

class AssetCreativeTemplateVariable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Different MIME types that the asset variable supports.
  module MimeType
    # Default value. This value is unused.
    MIME_TYPE_UNSPECIFIED = 0

    # The `image/jpeg` MIME type.
    JPG = 1

    # The `image/png` MIME type.
    PNG = 2

    # The `image/gif` MIME type.
    GIF = 3
  end
end