Class: Google::Ads::AdManager::V1::CustomPacingCurve

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/custom_pacing_curve.rb

Overview

A curve consisting of CustomPacingGoal objects that is used to pace line item delivery.

Instance Attribute Summary collapse

Instance Attribute Details

#custom_pacing_goal_unit::Google::Ads::AdManager::V1::CustomPacingGoalUnitEnum::CustomPacingGoalUnit

Returns Required. The unit of the CustomPacingGoal.amount values.



34
35
36
37
# File 'proto_docs/google/ads/admanager/v1/custom_pacing_curve.rb', line 34

class CustomPacingCurve
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#custom_pacing_goals::Array<::Google::Ads::AdManager::V1::CustomPacingGoal>

Returns Required. The list of goals that make up the custom pacing curve.

Returns:



34
35
36
37
# File 'proto_docs/google/ads/admanager/v1/custom_pacing_curve.rb', line 34

class CustomPacingCurve
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end