Class: Google::Ads::AdManager::V1::CustomPacingGoal

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/custom_pacing_curve.rb

Overview

An interval of a CustomPacingCurve. A custom pacing goal contains a start time and an amount. The goal will apply until either the next custom pacing goal's getStartTime or the line item's end time if it is the last goal.

Instance Attribute Summary collapse

Instance Attribute Details

#amount::Integer

Returns Optional. The amount associated with the goal. This field is required.

Returns:

  • (::Integer)

    Optional. The amount associated with the goal. This field is required.



57
58
59
60
# File 'proto_docs/google/ads/admanager/v1/custom_pacing_curve.rb', line 57

class CustomPacingGoal
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_time::Google::Protobuf::Timestamp

Returns Optional. The start date and time of the goal. This field is required unless use_line_item_start_time is true.

Returns:



57
58
59
60
# File 'proto_docs/google/ads/admanager/v1/custom_pacing_curve.rb', line 57

class CustomPacingGoal
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#use_line_item_start_time::Boolean

Returns Optional. Input only. Whether the [LineItem.start_time] should be used for the start date and time of this goal. This field is not persisted and if it is set to true, the [start_time] field will be populated by the line item's start time.

Returns:

  • (::Boolean)

    Optional. Input only. Whether the [LineItem.start_time] should be used for the start date and time of this goal. This field is not persisted and if it is set to true, the [start_time] field will be populated by the line item's start time.



57
58
59
60
# File 'proto_docs/google/ads/admanager/v1/custom_pacing_curve.rb', line 57

class CustomPacingGoal
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end