Module: Google::Ads::AdManager::V1::CustomPacingGoalUnitEnum::CustomPacingGoalUnit

Defined in:
proto_docs/google/ads/admanager/v1/custom_pacing_goal_unit_enum.rb

Overview

Options for the unit of the custom pacing goal amounts.

Constant Summary collapse

CUSTOM_PACING_GOAL_UNIT_UNSPECIFIED =

Default value. This value is unused.

0
ABSOLUTE =

The custom pacing goal amounts represent absolute numbers corresponding to the line item's [Goal.unitType][].

1
MILLI_PERCENT =

The custom pacing goal amounts represent a millipercent. For example, 15000 millipercent equals 15%.

2