Class: Google::Ads::AdManager::V1::CustomTargetingValueService::Rest::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/ads/ad_manager/v1/custom_targeting_value_service/rest/client.rb

Overview

REST client for the CustomTargetingValueService service.

Provides methods for handling CustomTargetingValue objects.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#custom_targeting_key_path, #custom_targeting_value_path, #network_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new CustomTargetingValueService REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Ads::AdManager::V1::CustomTargetingValueService::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Ads::AdManager::V1::CustomTargetingValueService::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the CustomTargetingValueService client.

Yield Parameters:



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/google/ads/ad_manager/v1/custom_targeting_value_service/rest/client.rb', line 126

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @custom_targeting_value_service_stub = ::Google::Ads::AdManager::V1::CustomTargetingValueService::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @custom_targeting_value_service_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the CustomTargetingValueService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all CustomTargetingValueService clients
::Google::Ads::AdManager::V1::CustomTargetingValueService::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/google/ads/ad_manager/v1/custom_targeting_value_service/rest/client.rb', line 64

def self.configure
  @configure ||= begin
    namespace = ["Google", "Ads", "AdManager", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#batch_activate_custom_targeting_values(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchActivateCustomTargetingValuesResponse #batch_activate_custom_targeting_values(parent: nil, requests: nil) ⇒ ::Google::Ads::AdManager::V1::BatchActivateCustomTargetingValuesResponse

Batch activates CustomTargetingValue objects.

Examples:

Basic example

require "google/ads/ad_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::AdManager::V1::CustomTargetingValueService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::AdManager::V1::BatchActivateCustomTargetingValuesRequest.new

# Call the batch_activate_custom_targeting_values method.
result = client.batch_activate_custom_targeting_values request

# The returned object is of type Google::Ads::AdManager::V1::BatchActivateCustomTargetingValuesResponse.
p result

Overloads:

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
# File 'lib/google/ads/ad_manager/v1/custom_targeting_value_service/rest/client.rb', line 757

def batch_activate_custom_targeting_values request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchActivateCustomTargetingValuesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.batch_activate_custom_targeting_values..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::AdManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.batch_activate_custom_targeting_values.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.batch_activate_custom_targeting_values.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @custom_targeting_value_service_stub.batch_activate_custom_targeting_values request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#batch_create_custom_targeting_values(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchCreateCustomTargetingValuesResponse #batch_create_custom_targeting_values(parent: nil, requests: nil) ⇒ ::Google::Ads::AdManager::V1::BatchCreateCustomTargetingValuesResponse

Creates CustomTargetingValue objects.

Examples:

Basic example

require "google/ads/ad_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::AdManager::V1::CustomTargetingValueService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::AdManager::V1::BatchCreateCustomTargetingValuesRequest.new

# Call the batch_create_custom_targeting_values method.
result = client.batch_create_custom_targeting_values request

# The returned object is of type Google::Ads::AdManager::V1::BatchCreateCustomTargetingValuesResponse.
p result

Overloads:

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
# File 'lib/google/ads/ad_manager/v1/custom_targeting_value_service/rest/client.rb', line 508

def batch_create_custom_targeting_values request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchCreateCustomTargetingValuesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.batch_create_custom_targeting_values..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::AdManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.batch_create_custom_targeting_values.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.batch_create_custom_targeting_values.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @custom_targeting_value_service_stub.batch_create_custom_targeting_values request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#batch_deactivate_custom_targeting_values(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchDeactivateCustomTargetingValuesResponse #batch_deactivate_custom_targeting_values(parent: nil, requests: nil) ⇒ ::Google::Ads::AdManager::V1::BatchDeactivateCustomTargetingValuesResponse

Deactivates a list of CustomTargetingValue objects.

Examples:

Basic example

require "google/ads/ad_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::AdManager::V1::CustomTargetingValueService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::AdManager::V1::BatchDeactivateCustomTargetingValuesRequest.new

# Call the batch_deactivate_custom_targeting_values method.
result = client.batch_deactivate_custom_targeting_values request

# The returned object is of type Google::Ads::AdManager::V1::BatchDeactivateCustomTargetingValuesResponse.
p result

Overloads:

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
# File 'lib/google/ads/ad_manager/v1/custom_targeting_value_service/rest/client.rb', line 839

def batch_deactivate_custom_targeting_values request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchDeactivateCustomTargetingValuesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.batch_deactivate_custom_targeting_values..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::AdManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.batch_deactivate_custom_targeting_values.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.batch_deactivate_custom_targeting_values.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @custom_targeting_value_service_stub.batch_deactivate_custom_targeting_values request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#batch_update_custom_targeting_values(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchUpdateCustomTargetingValuesResponse #batch_update_custom_targeting_values(parent: nil, requests: nil) ⇒ ::Google::Ads::AdManager::V1::BatchUpdateCustomTargetingValuesResponse

Batch updates CustomTargetingValue objects.

Examples:

Basic example

require "google/ads/ad_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::AdManager::V1::CustomTargetingValueService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::AdManager::V1::BatchUpdateCustomTargetingValuesRequest.new

# Call the batch_update_custom_targeting_values method.
result = client.batch_update_custom_targeting_values request

# The returned object is of type Google::Ads::AdManager::V1::BatchUpdateCustomTargetingValuesResponse.
p result

Overloads:

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
# File 'lib/google/ads/ad_manager/v1/custom_targeting_value_service/rest/client.rb', line 674

def batch_update_custom_targeting_values request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchUpdateCustomTargetingValuesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.batch_update_custom_targeting_values..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::AdManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.batch_update_custom_targeting_values.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.batch_update_custom_targeting_values.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @custom_targeting_value_service_stub.batch_update_custom_targeting_values request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#configure {|config| ... } ⇒ Client::Configuration

Configure the CustomTargetingValueService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



96
97
98
99
# File 'lib/google/ads/ad_manager/v1/custom_targeting_value_service/rest/client.rb', line 96

def configure
  yield @config if block_given?
  @config
end

#create_custom_targeting_value(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::CustomTargetingValue #create_custom_targeting_value(parent: nil, custom_targeting_value: nil) ⇒ ::Google::Ads::AdManager::V1::CustomTargetingValue

Creates a CustomTargetingValue object.

Examples:

Basic example

require "google/ads/ad_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::AdManager::V1::CustomTargetingValueService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::AdManager::V1::CreateCustomTargetingValueRequest.new

# Call the create_custom_targeting_value method.
result = client.create_custom_targeting_value request

# The returned object is of type Google::Ads::AdManager::V1::CustomTargetingValue.
p result

Overloads:

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'lib/google/ads/ad_manager/v1/custom_targeting_value_service/rest/client.rb', line 425

def create_custom_targeting_value request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::CreateCustomTargetingValueRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_custom_targeting_value..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::AdManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_custom_targeting_value.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_custom_targeting_value.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @custom_targeting_value_service_stub.create_custom_targeting_value request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_custom_targeting_value(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::CustomTargetingValue #get_custom_targeting_value(name: nil) ⇒ ::Google::Ads::AdManager::V1::CustomTargetingValue

Retrieves a CustomTargetingValue object.

Examples:

Basic example

require "google/ads/ad_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::AdManager::V1::CustomTargetingValueService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::AdManager::V1::GetCustomTargetingValueRequest.new

# Call the get_custom_targeting_value method.
result = client.get_custom_targeting_value request

# The returned object is of type Google::Ads::AdManager::V1::CustomTargetingValue.
p result

Overloads:

  • #get_custom_targeting_value(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::CustomTargetingValue

    Pass arguments to get_custom_targeting_value via a request object, either of type GetCustomTargetingValueRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::AdManager::V1::GetCustomTargetingValueRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_custom_targeting_value(name: nil) ⇒ ::Google::Ads::AdManager::V1::CustomTargetingValue

    Pass arguments to get_custom_targeting_value via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The resource name of the CustomTargetingValue. Format: networks/{network_code}/customTargetingValues/{custom_targeting_value_id}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/google/ads/ad_manager/v1/custom_targeting_value_service/rest/client.rb', line 224

def get_custom_targeting_value request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::GetCustomTargetingValueRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_custom_targeting_value..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::AdManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_custom_targeting_value.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_custom_targeting_value.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @custom_targeting_value_service_stub.get_custom_targeting_value request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_custom_targeting_values(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::CustomTargetingValue> #list_custom_targeting_values(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil, skip: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::CustomTargetingValue>

Lists CustomTargetingValue objects.

Examples:

Basic example

require "google/ads/ad_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::AdManager::V1::CustomTargetingValueService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::AdManager::V1::ListCustomTargetingValuesRequest.new

# Call the list_custom_targeting_values method.
result = client.list_custom_targeting_values request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Ads::AdManager::V1::CustomTargetingValue.
  p item
end

Overloads:

  • #list_custom_targeting_values(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::CustomTargetingValue>

    Pass arguments to list_custom_targeting_values via a request object, either of type ListCustomTargetingValuesRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::AdManager::V1::ListCustomTargetingValuesRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_custom_targeting_values(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil, skip: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::CustomTargetingValue>

    Pass arguments to list_custom_targeting_values via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent, which owns this collection of CustomTargetingValues. Format: networks/{network_code}

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of CustomTargetingValues to return. The service may return fewer than this value. If unspecified, at most 50 CustomTargetingValues will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous ListCustomTargetingValues call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListCustomTargetingValues must match the call that provided the page token.

    • filter (::String) (defaults to: nil)

      Optional. Expression to filter the response. See syntax details at https://developers.google.com/ad-manager/api/beta/filters

      Filterable fields:

      • adTagName
      • customTargetingKey
      • displayName
      • matchType
      • name
      • status
    • order_by (::String) (defaults to: nil)

      Optional. Expression to specify sorting order. See syntax details at https://developers.google.com/ad-manager/api/beta/filters#order

    • skip (::Integer) (defaults to: nil)

      Optional. Number of individual resources to skip while paginating.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/google/ads/ad_manager/v1/custom_targeting_value_service/rest/client.rb', line 341

def list_custom_targeting_values request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::ListCustomTargetingValuesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_custom_targeting_values..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::AdManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_custom_targeting_values.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_custom_targeting_values.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @custom_targeting_value_service_stub.list_custom_targeting_values request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @custom_targeting_value_service_stub, :list_custom_targeting_values, "custom_targeting_values", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


173
174
175
# File 'lib/google/ads/ad_manager/v1/custom_targeting_value_service/rest/client.rb', line 173

def logger
  @custom_targeting_value_service_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


106
107
108
# File 'lib/google/ads/ad_manager/v1/custom_targeting_value_service/rest/client.rb', line 106

def universe_domain
  @custom_targeting_value_service_stub.universe_domain
end

#update_custom_targeting_value(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::CustomTargetingValue #update_custom_targeting_value(custom_targeting_value: nil, update_mask: nil) ⇒ ::Google::Ads::AdManager::V1::CustomTargetingValue

Updates a CustomTargetingValue object.

Examples:

Basic example

require "google/ads/ad_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::AdManager::V1::CustomTargetingValueService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::AdManager::V1::UpdateCustomTargetingValueRequest.new

# Call the update_custom_targeting_value method.
result = client.update_custom_targeting_value request

# The returned object is of type Google::Ads::AdManager::V1::CustomTargetingValue.
p result

Overloads:

  • #update_custom_targeting_value(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::CustomTargetingValue

    Pass arguments to update_custom_targeting_value via a request object, either of type UpdateCustomTargetingValueRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::AdManager::V1::UpdateCustomTargetingValueRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #update_custom_targeting_value(custom_targeting_value: nil, update_mask: nil) ⇒ ::Google::Ads::AdManager::V1::CustomTargetingValue

    Pass arguments to update_custom_targeting_value via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
# File 'lib/google/ads/ad_manager/v1/custom_targeting_value_service/rest/client.rb', line 591

def update_custom_targeting_value request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::UpdateCustomTargetingValueRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_custom_targeting_value..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::AdManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.update_custom_targeting_value.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_custom_targeting_value.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @custom_targeting_value_service_stub.update_custom_targeting_value request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end