Class: Google::Ads::AdManager::V1::DeviceCapabilityTargeting

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/targeting.rb

Overview

Device Capability Targeting.

Can be used to target/exclude users using mobile apps, ad requests resulting from apps built on the MRAID standard, or users on devices that are able to make phone calls versus devices that aren't able to make phone calls, such as tablets.

Instance Attribute Summary collapse

Instance Attribute Details

#excluded_capabilities::Array<::String>

Returns Optional. A list of device capability resource names that should be excluded.

Returns:

  • (::Array<::String>)

    Optional. A list of device capability resource names that should be excluded.



189
190
191
192
# File 'proto_docs/google/ads/admanager/v1/targeting.rb', line 189

class DeviceCapabilityTargeting
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#targeted_capabilities::Array<::String>

Returns Optional. A list of device capability resource names that should be targeted/included.

Returns:

  • (::Array<::String>)

    Optional. A list of device capability resource names that should be targeted/included.



189
190
191
192
# File 'proto_docs/google/ads/admanager/v1/targeting.rb', line 189

class DeviceCapabilityTargeting
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end