Class: Google::Ads::AdManager::V1::FetchMcmEarningsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/mcm_earnings_service.rb

Overview

Request object for FetchMcmEarnings method.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Expression to filter the response. See syntax details at https://developers.google.com/ad-manager/api/beta/filters.

Returns:



59
60
61
62
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_service.rb', line 59

class FetchMcmEarningsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#month::Google::Type::Date

Returns Required. The month to fetch earnings for. The date will be specified as the first of the month.

Returns:

  • (::Google::Type::Date)

    Required. The month to fetch earnings for. The date will be specified as the first of the month.



59
60
61
62
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_service.rb', line 59

class FetchMcmEarningsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Expression to specify sorting order. See syntax details at https://developers.google.com/ad-manager/api/beta/filters#order.

Returns:



59
60
61
62
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_service.rb', line 59

class FetchMcmEarningsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Optional. The maximum number of McmEarnings to return. The service may return fewer than this value. If unspecified, at most 50 McmEarnings will be returned. The maximum value is 1000; values greater than 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of McmEarnings to return. The service may return fewer than this value. If unspecified, at most 50 McmEarnings will be returned. The maximum value is 1000; values greater than 1000 will be coerced to 1000.



59
60
61
62
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_service.rb', line 59

class FetchMcmEarningsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous FetchMcmEarnings call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to FetchMcmEarnings must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous FetchMcmEarnings call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to FetchMcmEarnings must match the call that provided the page token.



59
60
61
62
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_service.rb', line 59

class FetchMcmEarningsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent, which owns this collection of McmEarnings. Format: networks/{network_code}.

Returns:

  • (::String)

    Required. The parent, which owns this collection of McmEarnings. Format: networks/{network_code}



59
60
61
62
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_service.rb', line 59

class FetchMcmEarningsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#skip::Integer

Returns Optional. Number of individual resources to skip while paginating.

Returns:

  • (::Integer)

    Optional. Number of individual resources to skip while paginating.



59
60
61
62
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_service.rb', line 59

class FetchMcmEarningsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end