Class: Google::Ads::AdManager::V1::HlsSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/live_stream_messages.rb

Overview

LiveStream settings that are specific to the HTTP live streaming (HLS) protocol.

Instance Attribute Summary collapse

Instance Attribute Details

#master_playlist_settings::Google::Ads::AdManager::V1::MasterPlaylistSettings

Returns Optional. The settings for the master playlist. If it is not set will default to a MasterPlaylistSettings with a refresh type of AUTOMATIC.

Returns:



253
254
255
256
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 253

class HlsSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#playlist_type::Google::Ads::AdManager::V1::HlsSettingsPlaylistTypeEnum::HlsSettingsPlaylistType

Returns Immutable. Indicates the type of the playlist associated with this live stream. The playlist type is analogous to the EXT-X-PLAYLIST-TYPE HLS tag. Will default to LIVE.

Returns:



253
254
255
256
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 253

class HlsSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end