Module: Google::Ads::AdManager::V1::LineItemDeliveryForecastSourceEnum::LineItemDeliveryForecastSource

Defined in:
proto_docs/google/ads/admanager/v1/line_item_delivery_forecast_source_enum.rb

Overview

Strategies for choosing forecasted traffic shapes to pace line items.

Constant Summary collapse

LINE_ITEM_DELIVERY_FORECAST_SOURCE_UNSPECIFIED =

Default value. This value is unused.

0
CUSTOM_PACING_CURVE =

A user specified custom pacing curve will be used to pace line item delivery.

1
FORECASTING =

The line item's projected future traffic will be used to pace line item delivery.

2
HISTORICAL =

The line item's historical traffic shape will be used to pace line item delivery.

3