Class: Google::Ads::AdManager::V1::LineItemDiscount

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/line_item_discount.rb

Overview

Discount information for a LineItem.

Instance Attribute Summary collapse

Instance Attribute Details

#discount::Float

Returns Optional. The number here is either a percentage or an absolute value depending on the DiscountType. If the DiscountType is PERCENTAGE, then only non-fractional values are supported.

Returns:

  • (::Float)

    Optional. The number here is either a percentage or an absolute value depending on the DiscountType. If the DiscountType is PERCENTAGE, then only non-fractional values are supported.



35
36
37
38
# File 'proto_docs/google/ads/admanager/v1/line_item_discount.rb', line 35

class LineItemDiscount
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#discount_type::Google::Ads::AdManager::V1::DiscountTypeEnum::DiscountType

Returns Optional. The type of discount being applied to a LineItem, either percentage based or absolute. This attribute is optional and defaults to PERCENTAGE.

Returns:



35
36
37
38
# File 'proto_docs/google/ads/admanager/v1/line_item_discount.rb', line 35

class LineItemDiscount
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end