Class: Google::Ads::AdManager::V1::LinkedDevice

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/linked_device_messages.rb

Overview

A test mobile device that is linked to the network. Can be used to preview a creative within a mobile application.

Instance Attribute Summary collapse

Instance Attribute Details

#display_name::String

Returns Required. The display name of the LinkedDevice.

Returns:

  • (::String)

    Required. The display name of the LinkedDevice.



40
41
42
43
# File 'proto_docs/google/ads/admanager/v1/linked_device_messages.rb', line 40

class LinkedDevice
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The resource name of the LinkedDevice. Format: networks/{network_code}/linkedDevices/{linked_device_id}.

Returns:

  • (::String)

    Identifier. The resource name of the LinkedDevice. Format: networks/{network_code}/linkedDevices/{linked_device_id}



40
41
42
43
# File 'proto_docs/google/ads/admanager/v1/linked_device_messages.rb', line 40

class LinkedDevice
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#owner::String (readonly)

Returns Output only. The user who owns this device linking. Format: networks/{network_code}/users/{user}.

Returns:

  • (::String)

    Output only. The user who owns this device linking. Format: networks/{network_code}/users/{user}



40
41
42
43
# File 'proto_docs/google/ads/admanager/v1/linked_device_messages.rb', line 40

class LinkedDevice
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#visibility::Google::Ads::AdManager::V1::LinkedDeviceVisibilityEnum::LinkedDeviceVisibility

Returns Optional. The visibility of the device.

Returns:



40
41
42
43
# File 'proto_docs/google/ads/admanager/v1/linked_device_messages.rb', line 40

class LinkedDevice
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end