Class: Google::Ads::AdManager::V1::ListAdRulesResponse
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::ListAdRulesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/ad_rule_service.rb
Overview
Response object for ListAdRulesRequest containing matching AdRule
objects.
Instance Attribute Summary collapse
-
#ad_rules ⇒ ::Array<::Google::Ads::AdManager::V1::AdRule>
The
AdRuleobjects from the specified network. -
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page. -
#total_size ⇒ ::Integer
Total number of
AdRuleobjects.
Instance Attribute Details
#ad_rules ⇒ ::Array<::Google::Ads::AdManager::V1::AdRule>
Returns The AdRule objects from the specified network.
100 101 102 103 |
# File 'proto_docs/google/ads/admanager/v1/ad_rule_service.rb', line 100 class ListAdRulesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
100 101 102 103 |
# File 'proto_docs/google/ads/admanager/v1/ad_rule_service.rb', line 100 class ListAdRulesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_size ⇒ ::Integer
Returns Total number of AdRule objects.
If a filter was included in the request, this reflects the total number
after the filtering is applied.
total_size won't be calculated in the response unless it has been
included in a response field mask. The response field mask can be provided
to the method by using the URL parameter $fields or fields, or by using
the HTTP/gRPC header X-Goog-FieldMask.
For more information, see https://developers.google.com/ad-manager/api/beta/field-masks.
100 101 102 103 |
# File 'proto_docs/google/ads/admanager/v1/ad_rule_service.rb', line 100 class ListAdRulesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |