Class: Google::Ads::AdManager::V1::ListCreativeSetsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/creative_set_service.rb

Overview

Request object for ListCreativeSets method.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Expression to filter the response. See syntax details at https://developers.google.com/ad-manager/api/beta/filters

Filterable fields:

  • companionCreatives
  • displayName
  • masterCreative
  • name
  • updateTime
.

Returns:



74
75
76
77
# File 'proto_docs/google/ads/admanager/v1/creative_set_service.rb', line 74

class ListCreativeSetsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Expression to specify sorting order. See syntax details at https://developers.google.com/ad-manager/api/beta/filters#order.

Returns:



74
75
76
77
# File 'proto_docs/google/ads/admanager/v1/creative_set_service.rb', line 74

class ListCreativeSetsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Optional. The maximum number of CreativeSets to return. The service may return fewer than this value. If unspecified, at most 50 CreativeSets will be returned. The maximum value is 1000; values greater than 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of CreativeSets to return. The service may return fewer than this value. If unspecified, at most 50 CreativeSets will be returned. The maximum value is 1000; values greater than 1000 will be coerced to 1000.



74
75
76
77
# File 'proto_docs/google/ads/admanager/v1/creative_set_service.rb', line 74

class ListCreativeSetsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListCreativeSets call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListCreativeSets must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListCreativeSets call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListCreativeSets must match the call that provided the page token.



74
75
76
77
# File 'proto_docs/google/ads/admanager/v1/creative_set_service.rb', line 74

class ListCreativeSetsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent, which owns this collection of CreativeSets. Format: networks/{network_code}.

Returns:

  • (::String)

    Required. The parent, which owns this collection of CreativeSets. Format: networks/{network_code}



74
75
76
77
# File 'proto_docs/google/ads/admanager/v1/creative_set_service.rb', line 74

class ListCreativeSetsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#skip::Integer

Returns Optional. Number of individual resources to skip while paginating.

Returns:

  • (::Integer)

    Optional. Number of individual resources to skip while paginating.



74
75
76
77
# File 'proto_docs/google/ads/admanager/v1/creative_set_service.rb', line 74

class ListCreativeSetsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end