Class: Google::Ads::AdManager::V1::ListSlatesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/slate_service.rb

Overview

Request message for ListSlates method.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Expression to filter the response. See syntax details at https://google.aip.dev/160

Filterable fields:

  • displayName
  • name
  • status
.

Returns:

  • (::String)

    Optional. Expression to filter the response. See syntax details at https://google.aip.dev/160

    Filterable fields:

    • displayName
    • name
    • status


70
71
72
73
# File 'proto_docs/google/ads/admanager/v1/slate_service.rb', line 70

class ListSlatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Expression to specify sorting order. See syntax details at https://google.aip.dev/132#ordering.

Returns:



70
71
72
73
# File 'proto_docs/google/ads/admanager/v1/slate_service.rb', line 70

class ListSlatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Optional. The maximum number of Slates to return. The service may return fewer than this value. If unspecified, at most 50 Slates will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of Slates to return. The service may return fewer than this value. If unspecified, at most 50 Slates will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



70
71
72
73
# File 'proto_docs/google/ads/admanager/v1/slate_service.rb', line 70

class ListSlatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListSlates call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListSlates must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListSlates call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListSlates must match the call that provided the page token.



70
71
72
73
# File 'proto_docs/google/ads/admanager/v1/slate_service.rb', line 70

class ListSlatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource containing the Slates. Format: networks/{network_code}.

Returns:

  • (::String)

    Required. The parent resource containing the Slates. Format: networks/{network_code}



70
71
72
73
# File 'proto_docs/google/ads/admanager/v1/slate_service.rb', line 70

class ListSlatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#skip::Integer

Returns Optional. Number of individual resources to skip while paginating.

Returns:

  • (::Integer)

    Optional. Number of individual resources to skip while paginating.



70
71
72
73
# File 'proto_docs/google/ads/admanager/v1/slate_service.rb', line 70

class ListSlatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end