Class: Google::Ads::AdManager::V1::McmEarnings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/mcm_earnings_messages.rb

Overview

The earnings for a given month between a parent and child publisher in MCM

Instance Attribute Summary collapse

Instance Attribute Details

#child::String (readonly)

Returns Output only. The resource name of the ChildPublisher's Ad Manager network in the MCM relationship. Format: networks/{network_code}.

Returns:

  • (::String)

    Output only. The resource name of the ChildPublisher's Ad Manager network in the MCM relationship. Format: networks/{network_code}



70
71
72
73
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_messages.rb', line 70

class McmEarnings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#child_display_name::String (readonly)

Returns Output only. The name of the child publisher in the MCM relationship.

Returns:

  • (::String)

    Output only. The name of the child publisher in the MCM relationship.



70
71
72
73
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_messages.rb', line 70

class McmEarnings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#child_payment::Google::Type::Money (readonly)

Returns Output only. The portion of the total earnings paid to the child publisher.

Returns:

  • (::Google::Type::Money)

    Output only. The portion of the total earnings paid to the child publisher.



70
71
72
73
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_messages.rb', line 70

class McmEarnings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#child_publisher::String (readonly)

Returns Output only. The resource name of the child publisher in the MCM relationship. Format: "networks/{network_code}/childPublishers/{child_publisher_id}".

Returns:

  • (::String)

    Output only. The resource name of the child publisher in the MCM relationship. Format: "networks/{network_code}/childPublishers/{child_publisher_id}"



70
71
72
73
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_messages.rb', line 70

class McmEarnings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#deductions::Google::Type::Money (readonly)

Returns Output only. The deductions for the month due to spam in micro units. Null for earnings prior to August 2020.

Returns:

  • (::Google::Type::Money)

    Output only. The deductions for the month due to spam in micro units. Null for earnings prior to August 2020.



70
71
72
73
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_messages.rb', line 70

class McmEarnings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#delegation_type::Google::Ads::AdManager::V1::DelegationTypeEnum::DelegationType (readonly)

Returns Output only. The current type of MCM delegation between the parent and child publisher.

Returns:



70
71
72
73
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_messages.rb', line 70

class McmEarnings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#earnings_product_breakdown::Array<::Google::Ads::AdManager::V1::EarningsProductBreakdown> (readonly)

Returns Output only. The product type breakdown of earnings for a given month between a parent and child publisher in MCM.

Returns:



70
71
72
73
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_messages.rb', line 70

class McmEarnings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#month::Google::Type::Date (readonly)

Returns Output only. The year and month that the MCM earnings data applies to. The date will be specified as the first of the month.

Returns:

  • (::Google::Type::Date)

    Output only. The year and month that the MCM earnings data applies to. The date will be specified as the first of the month.



70
71
72
73
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_messages.rb', line 70

class McmEarnings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String (readonly)

Returns Output only. The parent publisher in the MCM relationship. Format: networks/{network_code}.

Returns:

  • (::String)

    Output only. The parent publisher in the MCM relationship. Format: networks/{network_code}



70
71
72
73
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_messages.rb', line 70

class McmEarnings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent_display_name::String (readonly)

Returns Output only. The name of the parent publisher.

Returns:

  • (::String)

    Output only. The name of the parent publisher.



70
71
72
73
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_messages.rb', line 70

class McmEarnings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent_payment::Google::Type::Money (readonly)

Returns Output only. The portion of the total earnings paid to the parent publisher.

Returns:

  • (::Google::Type::Money)

    Output only. The portion of the total earnings paid to the parent publisher.



70
71
72
73
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_messages.rb', line 70

class McmEarnings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#total_earnings::Google::Type::Money (readonly)

Returns Output only. The total earnings for the month.

Returns:



70
71
72
73
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_messages.rb', line 70

class McmEarnings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end