Class: Google::Ads::AdManager::V1::MediaLocation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/cdn_config_messages.rb

Overview

Config that associates a media location with a security policy and the authentication credentials needed to access the content.

Instance Attribute Summary collapse

Instance Attribute Details

#display_name::String (readonly)

Returns Output only. The name of the media location. This value is read-only and is assigned by Google.

Returns:

  • (::String)

    Output only. The name of the media location. This value is read-only and is assigned by Google.



184
185
186
187
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 184

class MediaLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#security_policy::Google::Ads::AdManager::V1::CdnSecurityPolicy

Returns Optional. The security policy and authentication credentials needed to access the content in this media location. Optional; if omitted, no security policy will be applied (indicating a public/unprotected location). Must NOT be configured for ad media delivery locations (doing so will trigger a validation error).

Returns:

  • (::Google::Ads::AdManager::V1::CdnSecurityPolicy)

    Optional. The security policy and authentication credentials needed to access the content in this media location. Optional; if omitted, no security policy will be applied (indicating a public/unprotected location). Must NOT be configured for ad media delivery locations (doing so will trigger a validation error).



184
185
186
187
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 184

class MediaLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#url_prefix::String

Returns Required. The URL prefix of the media location. This value is required for a valid media location.

Returns:

  • (::String)

    Required. The URL prefix of the media location. This value is required for a valid media location.



184
185
186
187
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 184

class MediaLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end