Class: Google::Ads::AdManager::V1::Order
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::Order
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/order_messages.rb
Overview
The Order resource.
Instance Attribute Summary collapse
-
#advertiser ⇒ ::String
Required.
-
#advertiser_contacts ⇒ ::Array<::String>
Optional.
-
#agency ⇒ ::String
Optional.
-
#agency_contacts ⇒ ::Array<::String>
Optional.
-
#applied_labels ⇒ ::Array<::Google::Ads::AdManager::V1::AppliedLabel>
Optional.
-
#applied_teams ⇒ ::Array<::String>
Optional.
-
#archived ⇒ ::Boolean
readonly
Output only.
-
#creator ⇒ ::String
readonly
Output only.
-
#currency_code ⇒ ::String
readonly
Output only.
-
#custom_field_values ⇒ ::Array<::Google::Ads::AdManager::V1::CustomFieldValue>
Optional.
-
#display_name ⇒ ::String
Required.
-
#effective_applied_labels ⇒ ::Array<::Google::Ads::AdManager::V1::AppliedLabel>
readonly
Output only.
-
#effective_teams ⇒ ::Array<::String>
readonly
Output only.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#external_order_id ⇒ ::Integer
Optional.
-
#impressions_delivered ⇒ ::Integer
readonly
Output only.
-
#last_modified_by_app ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#notes ⇒ ::String
Optional.
-
#order_id ⇒ ::Integer
readonly
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#po_number ⇒ ::String
Optional.
-
#programmatic ⇒ ::Boolean
Optional.
-
#salesperson ⇒ ::String
Optional.
-
#secondary_salespeople ⇒ ::Array<::String>
Optional.
-
#secondary_traffickers ⇒ ::Array<::String>
Optional.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#status ⇒ ::Google::Ads::AdManager::V1::OrderStatusEnum::OrderStatus
readonly
Output only.
-
#total_clicks_delivered ⇒ ::Integer
readonly
Output only.
-
#total_viewable_impressions_delivered ⇒ ::Integer
readonly
Output only.
-
#trafficker ⇒ ::String
Required.
-
#unlimited_end_time ⇒ ::Boolean
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#advertiser ⇒ ::String
Returns Required. The resource name of the Company, which is of type Company.Type.ADVERTISER, to which this order belongs. Format: "networks/{network_code}/companies/{company_id}".
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#advertiser_contacts ⇒ ::Array<::String>
Returns Optional. Unordered list. The resource names of Contacts from the advertiser of this Order. Format: "networks/{network_code}/contacts/{contact_id}".
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#agency ⇒ ::String
Returns Optional. The resource name of the Company, which is of type Company.Type.AGENCY, with which this order is associated. Format: "networks/{network_code}/companies/{company_id}".
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#agency_contacts ⇒ ::Array<::String>
Returns Optional. The resource names of Contacts from the advertising Agency of this Order. Format: "networks/{network_code}/contacts/{contact_id}".
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#applied_labels ⇒ ::Array<::Google::Ads::AdManager::V1::AppliedLabel>
Returns Optional. The set of labels applied directly to this order.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#applied_teams ⇒ ::Array<::String>
Returns Optional. The resource names of Teams directly applied to this Order. Format: "networks/{network_code}/teams/{team_id}".
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#archived ⇒ ::Boolean (readonly)
Returns Output only. The archival status of the Order.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#creator ⇒ ::String (readonly)
Returns Output only. The resource name of the User who created the Order on behalf of the advertiser. Format: "networks/{network_code}/users/{user_id}".
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#currency_code ⇒ ::String (readonly)
Returns Output only. The ISO 4217 3-letter currency code for the currency used by the Order. This value is the network's currency code.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#custom_field_values ⇒ ::Array<::Google::Ads::AdManager::V1::CustomFieldValue>
Returns Optional. The set of custom field values to this order.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Required. The display name of the Order. This value has a maximum length of 255 characters.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#effective_applied_labels ⇒ ::Array<::Google::Ads::AdManager::V1::AppliedLabel> (readonly)
Returns Output only. Contains the set of labels applied directly to the order as well as those inherited from the company that owns the order. If a label has been negated, only the negated label is returned. This field is assigned by Google.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#effective_teams ⇒ ::Array<::String> (readonly)
Returns Output only. The resource names of Teams applied to this Order including inherited values. Format: "networks/{network_code}/teams/{team_id}".
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#end_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The instant at which the Order and its associated Line items
stop being served. This attribute is derived from the Line item of the
order that has the latest LineItem.end_time.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#external_order_id ⇒ ::Integer
Returns Optional. An arbitrary ID to associate to the Order, which can be used as a key to an external system.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#impressions_delivered ⇒ ::Integer (readonly)
Returns Output only. The total number of impressions delivered for Line items in this order.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#last_modified_by_app ⇒ ::String (readonly)
Returns Output only. The application which modified this order.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The resource name of the Order.
Format: networks/{network_code}/orders/{order_id}.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#notes ⇒ ::String
Returns Optional. Provides any additional notes that may annotate the Order. This attribute has a maximum length of 65,535 characters.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_id ⇒ ::Integer (readonly)
This field is deprecated and may be removed in the next major version update.
Returns Output only. Deprecated: Order ID.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#po_number ⇒ ::String
Returns Optional. The purchase order number for the Order. This value has a maximum length of 63 characters.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#programmatic ⇒ ::Boolean
Returns Optional. Specifies whether or not the Order is a programmatic order.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#salesperson ⇒ ::String
Returns Optional. The resource name of the User responsible for the sales of the Order. Format: "networks/{network_code}/users/{user_id}".
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#secondary_salespeople ⇒ ::Array<::String>
Returns Optional. Unordered list. The resource names of the secondary salespeople associated with the order. Format: "networks/{network_code}/users/{user_id}".
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#secondary_traffickers ⇒ ::Array<::String>
Returns Optional. Unordered list. The resource names of the secondary traffickers associated with the order. Format: "networks/{network_code}/users/{user_id}".
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The instant at which the Order and its associated Line items
are eligible to begin serving. This attribute is derived from the Line item
of the order that has the earliest LineItem.start_time.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#status ⇒ ::Google::Ads::AdManager::V1::OrderStatusEnum::OrderStatus (readonly)
Returns Output only. The status of the Order.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_clicks_delivered ⇒ ::Integer (readonly)
Returns Output only. Total clicks delivered for all Line items of this Order.
This value is calculated from the associated LineItem values.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_viewable_impressions_delivered ⇒ ::Integer (readonly)
Returns Output only. Total viewable impressions delivered for all Line items of
this Order. This value is calculated from the associated LineItem
values.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#trafficker ⇒ ::String
Returns Required. The resource name of the User responsible for trafficking the Order. Format: "networks/{network_code}/users/{user_id}".
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unlimited_end_time ⇒ ::Boolean (readonly)
Returns Output only. Indicates whether or not this Order has an end time.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The instant this Order was last modified.
155 156 157 158 |
# File 'proto_docs/google/ads/admanager/v1/order_messages.rb', line 155 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |