Class: Google::Ads::AdManager::V1::PrivateAuction

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/private_auction_messages.rb

Overview

The PrivateAuction resource.

Instance Attribute Summary collapse

Instance Attribute Details

#archived::Boolean (readonly)

Returns Output only. Whether the PrivateAuction is archived.

Returns:

  • (::Boolean)

    Output only. Whether the PrivateAuction is archived.



55
56
57
58
# File 'proto_docs/google/ads/admanager/v1/private_auction_messages.rb', line 55

class PrivateAuction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The instant at which the PrivateAuction was created.

Returns:



55
56
57
58
# File 'proto_docs/google/ads/admanager/v1/private_auction_messages.rb', line 55

class PrivateAuction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description::String

Returns Optional. Description of the PrivateAuction. This attribute has a maximum length of 4096 bytes.

Returns:

  • (::String)

    Optional. Description of the PrivateAuction. This attribute has a maximum length of 4096 bytes.



55
56
57
58
# File 'proto_docs/google/ads/admanager/v1/private_auction_messages.rb', line 55

class PrivateAuction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String

Returns Required. Display name of the PrivateAuction. This attribute has a maximum length of 255 bytes.

Returns:

  • (::String)

    Required. Display name of the PrivateAuction. This attribute has a maximum length of 255 bytes.



55
56
57
58
# File 'proto_docs/google/ads/admanager/v1/private_auction_messages.rb', line 55

class PrivateAuction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The resource name of the PrivateAuction. Format: networks/{network_code}/privateAuctions/{private_auction_id}.

Returns:

  • (::String)

    Identifier. The resource name of the PrivateAuction. Format: networks/{network_code}/privateAuctions/{private_auction_id}



55
56
57
58
# File 'proto_docs/google/ads/admanager/v1/private_auction_messages.rb', line 55

class PrivateAuction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#private_auction_id::Integer (readonly)

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Output only. Deprecated: PrivateAuction ID.

Returns:

  • (::Integer)

    Output only. Deprecated: PrivateAuction ID.



55
56
57
58
# File 'proto_docs/google/ads/admanager/v1/private_auction_messages.rb', line 55

class PrivateAuction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#seller_contact_users::Array<::String>

Returns Optional. The resource names of the seller contact users associated with this PrivateAuction. Format: networks/{network_code}/users/{user_id}.

Returns:

  • (::Array<::String>)

    Optional. The resource names of the seller contact users associated with this PrivateAuction. Format: networks/{network_code}/users/{user_id}



55
56
57
58
# File 'proto_docs/google/ads/admanager/v1/private_auction_messages.rb', line 55

class PrivateAuction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The instant at which the PrivateAuction was last updated.

Returns:



55
56
57
58
# File 'proto_docs/google/ads/admanager/v1/private_auction_messages.rb', line 55

class PrivateAuction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end