Class: Google::Ads::AdManager::V1::ReportDefinition::Flag

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/report_definition.rb

Overview

A flag for a report. Flags are used show if certain thresholds are met. Result rows that match the filter will have the corresponding [MetricValueGroup.flagValues][MetricValueGroup] index set to true. For more information about flags see: https://support.google.com/admanager/answer/15079975

Instance Attribute Summary collapse

Instance Attribute Details

#filters::Array<::Google::Ads::AdManager::V1::ReportDefinition::Filter>



526
527
528
529
# File 'proto_docs/google/ads/admanager/v1/report_definition.rb', line 526

class Flag
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String



526
527
528
529
# File 'proto_docs/google/ads/admanager/v1/report_definition.rb', line 526

class Flag
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end