Class: Google::Ads::AdManager::V1::ScheduleOptions
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::ScheduleOptions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/report_delivery.rb
Overview
The options for a scheduled report.
Defined Under Namespace
Modules: DeliveryCondition Classes: Schedule
Instance Attribute Summary collapse
-
#delivery_condition ⇒ ::Google::Ads::AdManager::V1::ScheduleOptions::DeliveryCondition
Option for when to deliver the scheduled report.
-
#flags ⇒ ::Array<::Google::Ads::AdManager::V1::ReportDefinition::Flag>
Optional.
-
#schedule ⇒ ::Google::Ads::AdManager::V1::ScheduleOptions::Schedule
Information pertaining to schedule itself.
Instance Attribute Details
#delivery_condition ⇒ ::Google::Ads::AdManager::V1::ScheduleOptions::DeliveryCondition
Returns Option for when to deliver the scheduled report.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'proto_docs/google/ads/admanager/v1/report_delivery.rb', line 35 class ScheduleOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The schedule for the report # @!attribute [rw] weekly_schedule # @return [::Google::Ads::AdManager::V1::ScheduleOptions::Schedule::WeeklySchedule] # Days of week to schedule report run. # # Note: The following fields are mutually exclusive: `weekly_schedule`, `monthly_schedule`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] monthly_schedule # @return [::Google::Ads::AdManager::V1::ScheduleOptions::Schedule::MonthlySchedule] # Days of month to schedule report run. # # Note: The following fields are mutually exclusive: `monthly_schedule`, `weekly_schedule`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] start_date # @return [::Google::Type::Date] # Date for the first run of the report. # @!attribute [rw] end_date # @return [::Google::Type::Date] # Date for the final run of the report. # @!attribute [rw] frequency # @return [::Google::Ads::AdManager::V1::ScheduleOptions::Schedule::Frequency] # Frequency to run report. # @!attribute [rw] start_time # @return [::Google::Type::TimeOfDay] # Indicates start time for schedule to run # Will use the time_zone from `ReportDefinition`. Defaults # to the publisher's time zone if not specified. # # For HOURLY, TWO_TIMES_DAILY, THREE_TIMES_DAILY, or FOUR_TIMES_DAILY, this # will be the time of day that the first report will run on the first day. # For example, if the start time is 2:00 PM, and the frequency is # THREE_TIMES_DAILY, the first day will have reports scheduled at 2:00 PM, # 10:00 PM. Each subsequent day will have reports scheduled at 6:00 AM, # 2:00 PM, 10:00 PM. class Schedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Days of week to schedule report run. # @!attribute [rw] weekly_scheduled_days # @return [::Array<::Google::Type::DayOfWeek>] # Specifies days of the week on which to run report. class WeeklySchedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Days of Month to schedule report run. # @!attribute [rw] monthly_scheduled_days # @return [::Array<::Integer>] # Specifies days of the month to run report. Range is from 1-31. # Will ignore days that are not valid for the given month. class MonthlySchedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Frequency to run report. module Frequency # No Frequency specified. FREQUENCY_UNSPECIFIED = 0 # Schedule report to run every hour. HOURLY = 1 # Schedule report to run twice a day (every 12 hours). TWO_TIMES_DAILY = 2 # Schedule report to run three times a day (every 8 hours). THREE_TIMES_DAILY = 3 # Schedule report to run four times a day (every 6 hours). FOUR_TIMES_DAILY = 4 # Schedule report to run on a daily basis. DAILY = 5 # Schedule report to run on a weekly basis. WEEKLY = 6 # Schedule report to run on a monthly basis. MONTHLY = 7 end end # Condition for when to email the scheduled report. module DeliveryCondition # Never deliver report. NEVER = 0 # Always deliver report. ALWAYS = 1 # Deliver report when flag's conditions are met. WHEN_FLAG_CONDITIONS_MET = 2 end end |
#flags ⇒ ::Array<::Google::Ads::AdManager::V1::ReportDefinition::Flag>
Returns Optional. The flags evaluated when ReportDeliveryOption.WHEN_FLAG_PRESENT is specified.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'proto_docs/google/ads/admanager/v1/report_delivery.rb', line 35 class ScheduleOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The schedule for the report # @!attribute [rw] weekly_schedule # @return [::Google::Ads::AdManager::V1::ScheduleOptions::Schedule::WeeklySchedule] # Days of week to schedule report run. # # Note: The following fields are mutually exclusive: `weekly_schedule`, `monthly_schedule`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] monthly_schedule # @return [::Google::Ads::AdManager::V1::ScheduleOptions::Schedule::MonthlySchedule] # Days of month to schedule report run. # # Note: The following fields are mutually exclusive: `monthly_schedule`, `weekly_schedule`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] start_date # @return [::Google::Type::Date] # Date for the first run of the report. # @!attribute [rw] end_date # @return [::Google::Type::Date] # Date for the final run of the report. # @!attribute [rw] frequency # @return [::Google::Ads::AdManager::V1::ScheduleOptions::Schedule::Frequency] # Frequency to run report. # @!attribute [rw] start_time # @return [::Google::Type::TimeOfDay] # Indicates start time for schedule to run # Will use the time_zone from `ReportDefinition`. Defaults # to the publisher's time zone if not specified. # # For HOURLY, TWO_TIMES_DAILY, THREE_TIMES_DAILY, or FOUR_TIMES_DAILY, this # will be the time of day that the first report will run on the first day. # For example, if the start time is 2:00 PM, and the frequency is # THREE_TIMES_DAILY, the first day will have reports scheduled at 2:00 PM, # 10:00 PM. Each subsequent day will have reports scheduled at 6:00 AM, # 2:00 PM, 10:00 PM. class Schedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Days of week to schedule report run. # @!attribute [rw] weekly_scheduled_days # @return [::Array<::Google::Type::DayOfWeek>] # Specifies days of the week on which to run report. class WeeklySchedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Days of Month to schedule report run. # @!attribute [rw] monthly_scheduled_days # @return [::Array<::Integer>] # Specifies days of the month to run report. Range is from 1-31. # Will ignore days that are not valid for the given month. class MonthlySchedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Frequency to run report. module Frequency # No Frequency specified. FREQUENCY_UNSPECIFIED = 0 # Schedule report to run every hour. HOURLY = 1 # Schedule report to run twice a day (every 12 hours). TWO_TIMES_DAILY = 2 # Schedule report to run three times a day (every 8 hours). THREE_TIMES_DAILY = 3 # Schedule report to run four times a day (every 6 hours). FOUR_TIMES_DAILY = 4 # Schedule report to run on a daily basis. DAILY = 5 # Schedule report to run on a weekly basis. WEEKLY = 6 # Schedule report to run on a monthly basis. MONTHLY = 7 end end # Condition for when to email the scheduled report. module DeliveryCondition # Never deliver report. NEVER = 0 # Always deliver report. ALWAYS = 1 # Deliver report when flag's conditions are met. WHEN_FLAG_CONDITIONS_MET = 2 end end |
#schedule ⇒ ::Google::Ads::AdManager::V1::ScheduleOptions::Schedule
Returns Information pertaining to schedule itself.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'proto_docs/google/ads/admanager/v1/report_delivery.rb', line 35 class ScheduleOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The schedule for the report # @!attribute [rw] weekly_schedule # @return [::Google::Ads::AdManager::V1::ScheduleOptions::Schedule::WeeklySchedule] # Days of week to schedule report run. # # Note: The following fields are mutually exclusive: `weekly_schedule`, `monthly_schedule`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] monthly_schedule # @return [::Google::Ads::AdManager::V1::ScheduleOptions::Schedule::MonthlySchedule] # Days of month to schedule report run. # # Note: The following fields are mutually exclusive: `monthly_schedule`, `weekly_schedule`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] start_date # @return [::Google::Type::Date] # Date for the first run of the report. # @!attribute [rw] end_date # @return [::Google::Type::Date] # Date for the final run of the report. # @!attribute [rw] frequency # @return [::Google::Ads::AdManager::V1::ScheduleOptions::Schedule::Frequency] # Frequency to run report. # @!attribute [rw] start_time # @return [::Google::Type::TimeOfDay] # Indicates start time for schedule to run # Will use the time_zone from `ReportDefinition`. Defaults # to the publisher's time zone if not specified. # # For HOURLY, TWO_TIMES_DAILY, THREE_TIMES_DAILY, or FOUR_TIMES_DAILY, this # will be the time of day that the first report will run on the first day. # For example, if the start time is 2:00 PM, and the frequency is # THREE_TIMES_DAILY, the first day will have reports scheduled at 2:00 PM, # 10:00 PM. Each subsequent day will have reports scheduled at 6:00 AM, # 2:00 PM, 10:00 PM. class Schedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Days of week to schedule report run. # @!attribute [rw] weekly_scheduled_days # @return [::Array<::Google::Type::DayOfWeek>] # Specifies days of the week on which to run report. class WeeklySchedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Days of Month to schedule report run. # @!attribute [rw] monthly_scheduled_days # @return [::Array<::Integer>] # Specifies days of the month to run report. Range is from 1-31. # Will ignore days that are not valid for the given month. class MonthlySchedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Frequency to run report. module Frequency # No Frequency specified. FREQUENCY_UNSPECIFIED = 0 # Schedule report to run every hour. HOURLY = 1 # Schedule report to run twice a day (every 12 hours). TWO_TIMES_DAILY = 2 # Schedule report to run three times a day (every 8 hours). THREE_TIMES_DAILY = 3 # Schedule report to run four times a day (every 6 hours). FOUR_TIMES_DAILY = 4 # Schedule report to run on a daily basis. DAILY = 5 # Schedule report to run on a weekly basis. WEEKLY = 6 # Schedule report to run on a monthly basis. MONTHLY = 7 end end # Condition for when to email the scheduled report. module DeliveryCondition # Never deliver report. NEVER = 0 # Always deliver report. ALWAYS = 1 # Deliver report when flag's conditions are met. WHEN_FLAG_CONDITIONS_MET = 2 end end |