Class: Google::Ads::AdManager::V1::SearchAdReviewCenterAdsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/ad_review_center_ad_service.rb

Overview

Request object for SearchAdReviewCenterAds method.

Instance Attribute Summary collapse

Instance Attribute Details

#ad_review_center_ad_id::Array<::String>

Returns Optional. Only return ads with the given AdReviewCenterAd IDs. If provided, no other filter can be set (other than page size and page token).

Returns:

  • (::Array<::String>)

    Optional. Only return ads with the given AdReviewCenterAd IDs. If provided, no other filter can be set (other than page size and page token).



86
87
88
89
# File 'proto_docs/google/ads/admanager/v1/ad_review_center_ad_service.rb', line 86

class SearchAdReviewCenterAdsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#buyer_account_id::Array<::Integer>

Returns Optional. If provided, restrict the search to creatives belonging to one of the given Adx buyer account IDs. Only applicable to RTB creatives. Adx buyer account IDs can be found using the ProgrammaticBuyerService.

Returns:

  • (::Array<::Integer>)

    Optional. If provided, restrict the search to creatives belonging to one of the given Adx buyer account IDs. Only applicable to RTB creatives. Adx buyer account IDs can be found using the ProgrammaticBuyerService.



86
87
88
89
# File 'proto_docs/google/ads/admanager/v1/ad_review_center_ad_service.rb', line 86

class SearchAdReviewCenterAdsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#date_time_range::Google::Type::Interval

Returns Optional. If provided, only return ads that served within the given date range (inclusive). The date range must be within the last 30 days. If not provided, the date range will be the last 30 days. This filter does not apply to the PENDING manual review status.

Returns:

  • (::Google::Type::Interval)

    Optional. If provided, only return ads that served within the given date range (inclusive). The date range must be within the last 30 days. If not provided, the date range will be the last 30 days. This filter does not apply to the PENDING manual review status.



86
87
88
89
# File 'proto_docs/google/ads/admanager/v1/ad_review_center_ad_service.rb', line 86

class SearchAdReviewCenterAdsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#manual_review_status::Google::Ads::AdManager::V1::ManualAdReviewCenterAdStatusEnum::ManualAdReviewCenterAdStatus

Returns Optional. Only return ads with the given manual review status. Only available for networks with Manual Creative Review enabled. For more information, see https://support.google.com/admanager/answer/2586531#manual-creative-review.

Note: The following fields are mutually exclusive: manual_review_status, status. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



86
87
88
89
# File 'proto_docs/google/ads/admanager/v1/ad_review_center_ad_service.rb', line 86

class SearchAdReviewCenterAdsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. The maximum number of AdReviewCenterAds to return. The service may return fewer than this value. If unspecified, at most 50 AdReviewCenterAds will be returned. The maximum value is 1000; values greater than 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of AdReviewCenterAds to return. The service may return fewer than this value. If unspecified, at most 50 AdReviewCenterAds will be returned. The maximum value is 1000; values greater than 1000 will be coerced to 1000.



86
87
88
89
# File 'proto_docs/google/ads/admanager/v1/ad_review_center_ad_service.rb', line 86

class SearchAdReviewCenterAdsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. The page token to fetch the next page of AdReviewCenterAds. This is the value returned from a previous Search request, or empty.

Returns:

  • (::String)

    Optional. The page token to fetch the next page of AdReviewCenterAds. This is the value returned from a previous Search request, or empty.



86
87
88
89
# File 'proto_docs/google/ads/admanager/v1/ad_review_center_ad_service.rb', line 86

class SearchAdReviewCenterAdsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent, which owns this collection of AdReviewCenterAds. Format: networks/{network_code}/webProperties/{web_property_code}

Since a network can only have a single web property of each ExchangeSyndicationProduct, you can use the ExchangeSyndicationProduct as an alias for the web property code:

networks/{network_code}/webProperties/display

networks/{network_code}/webProperties/videoAndAudio

networks/{network_code}/webProperties/mobileApp

networks/{network_code}/webProperties/games.

Returns:

  • (::String)

    Required. The parent, which owns this collection of AdReviewCenterAds. Format: networks/{network_code}/webProperties/{web_property_code}

    Since a network can only have a single web property of each ExchangeSyndicationProduct, you can use the ExchangeSyndicationProduct as an alias for the web property code:

    networks/{network_code}/webProperties/display

    networks/{network_code}/webProperties/videoAndAudio

    networks/{network_code}/webProperties/mobileApp

    networks/{network_code}/webProperties/games



86
87
88
89
# File 'proto_docs/google/ads/admanager/v1/ad_review_center_ad_service.rb', line 86

class SearchAdReviewCenterAdsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#search_text::Array<::String>

Returns Optional. If provided, restrict the search to AdReviewCenterAds associated with the text (including any text on the ad or in the destination URL). If more than one value is provided, the search will combine them in a logical AND. For example, ['car', 'blue'] will match ads that contain both "car" and "blue", but not an ad that only contains "car".

Returns:

  • (::Array<::String>)

    Optional. If provided, restrict the search to AdReviewCenterAds associated with the text (including any text on the ad or in the destination URL). If more than one value is provided, the search will combine them in a logical AND. For example, ['car', 'blue'] will match ads that contain both "car" and "blue", but not an ad that only contains "car".



86
87
88
89
# File 'proto_docs/google/ads/admanager/v1/ad_review_center_ad_service.rb', line 86

class SearchAdReviewCenterAdsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#status::Google::Ads::AdManager::V1::AdReviewCenterAdStatusEnum::AdReviewCenterAdStatus

Returns Optional. Only return ads with the given status.

Note: The following fields are mutually exclusive: status, manual_review_status. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



86
87
88
89
# File 'proto_docs/google/ads/admanager/v1/ad_review_center_ad_service.rb', line 86

class SearchAdReviewCenterAdsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end