Class: Google::Ads::AdManager::V1::SourceContentConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/cdn_config_messages.rb

Overview

Parameters about this CDN config as a source of content. This facilitates fetching the original content for conditioning and delivering the original content as part of a modified stream.

Instance Attribute Summary collapse

Instance Attribute Details

#default_delivery_settings::Google::Ads::AdManager::V1::MediaLocation

Returns Required. Default config for how DAI should deliver the non-modified media segments. At delivery time, we replace the ingest location's URL prefix with the delivery location's URL prefix and use the security policy from the delivery settings to determine how DAI needs to deliver the media so that users can access it. This value is required for a valid source content config.

Returns:

  • (::Google::Ads::AdManager::V1::MediaLocation)

    Required. Default config for how DAI should deliver the non-modified media segments. At delivery time, we replace the ingest location's URL prefix with the delivery location's URL prefix and use the security policy from the delivery settings to determine how DAI needs to deliver the media so that users can access it. This value is required for a valid source content config.



162
163
164
165
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 162

class SourceContentConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ingest_settings::Google::Ads::AdManager::V1::MediaLocation

Returns Required. Config for how DAI should ingest media. At ingest time, we match the URL prefix of media in a stream's playlist with an ingest location and use the authentication credentials from the corresponding ingest settings to download the media. This value is required for a valid source content config.

Returns:

  • (::Google::Ads::AdManager::V1::MediaLocation)

    Required. Config for how DAI should ingest media. At ingest time, we match the URL prefix of media in a stream's playlist with an ingest location and use the authentication credentials from the corresponding ingest settings to download the media. This value is required for a valid source content config.



162
163
164
165
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 162

class SourceContentConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end