Class: Google::Ads::AdManager::V1::TargetingPresetService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::TargetingPresetService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/ads/ad_manager/v1/targeting_preset_service/rest/client.rb
Overview
REST client for the TargetingPresetService service.
Provides methods for handling TargetingPreset objects.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the TargetingPresetService Client class.
Instance Method Summary collapse
-
#batch_create_targeting_presets(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::BatchCreateTargetingPresetsResponse
Creates
TargetingPresetobjects. -
#batch_deactivate_targeting_presets(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::BatchDeactivateTargetingPresetsResponse
Batch deactivates
TargetingPresetobjects. -
#configure {|config| ... } ⇒ Client::Configuration
Configure the TargetingPresetService Client instance.
-
#create_targeting_preset(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::TargetingPreset
Creates a
TargetingPresetobject. -
#get_targeting_preset(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::TargetingPreset
Retrieves a
TargetingPresetobject. -
#initialize {|config| ... } ⇒ Client
constructor
Create a new TargetingPresetService REST client object.
-
#list_targeting_presets(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::TargetingPreset>
Lists
TargetingPresetobjects. -
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
Methods included from Paths
#ad_unit_path, #application_path, #audience_segment_path, #bandwidth_group_path, #browser_language_path, #browser_path, #cms_metadata_value_path, #content_bundle_path, #content_path, #custom_targeting_key_path, #custom_targeting_value_path, #device_capability_path, #device_category_path, #device_manufacturer_path, #geo_target_path, #mobile_carrier_path, #mobile_device_path, #mobile_device_submodel_path, #network_path, #operating_system_path, #operating_system_version_path, #placement_path, #targeting_preset_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new TargetingPresetService REST client object.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/google/ads/ad_manager/v1/targeting_preset_service/rest/client.rb', line 126 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @targeting_preset_service_stub = ::Google::Ads::AdManager::V1::TargetingPresetService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @targeting_preset_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the TargetingPresetService Client class.
See Configuration for a description of the configuration fields.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/google/ads/ad_manager/v1/targeting_preset_service/rest/client.rb', line 64 def self.configure @configure ||= begin namespace = ["Google", "Ads", "AdManager", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config end yield @configure if block_given? @configure end |
Instance Method Details
#batch_create_targeting_presets(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchCreateTargetingPresetsResponse #batch_create_targeting_presets(parent: nil, requests: nil) ⇒ ::Google::Ads::AdManager::V1::BatchCreateTargetingPresetsResponse
Creates TargetingPreset objects.
504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 |
# File 'lib/google/ads/ad_manager/v1/targeting_preset_service/rest/client.rb', line 504 def batch_create_targeting_presets request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchCreateTargetingPresetsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_create_targeting_presets..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.batch_create_targeting_presets.timeout, metadata: , retry_policy: @config.rpcs.batch_create_targeting_presets.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @targeting_preset_service_stub.batch_create_targeting_presets request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#batch_deactivate_targeting_presets(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchDeactivateTargetingPresetsResponse #batch_deactivate_targeting_presets(parent: nil, requests: nil) ⇒ ::Google::Ads::AdManager::V1::BatchDeactivateTargetingPresetsResponse
Batch deactivates TargetingPreset objects.
584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 |
# File 'lib/google/ads/ad_manager/v1/targeting_preset_service/rest/client.rb', line 584 def batch_deactivate_targeting_presets request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchDeactivateTargetingPresetsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_deactivate_targeting_presets..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.batch_deactivate_targeting_presets.timeout, metadata: , retry_policy: @config.rpcs.batch_deactivate_targeting_presets.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @targeting_preset_service_stub.batch_deactivate_targeting_presets request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the TargetingPresetService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
96 97 98 99 |
# File 'lib/google/ads/ad_manager/v1/targeting_preset_service/rest/client.rb', line 96 def configure yield @config if block_given? @config end |
#create_targeting_preset(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::TargetingPreset #create_targeting_preset(parent: nil, targeting_preset: nil) ⇒ ::Google::Ads::AdManager::V1::TargetingPreset
Creates a TargetingPreset object.
420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 |
# File 'lib/google/ads/ad_manager/v1/targeting_preset_service/rest/client.rb', line 420 def create_targeting_preset request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::CreateTargetingPresetRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_targeting_preset..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_targeting_preset.timeout, metadata: , retry_policy: @config.rpcs.create_targeting_preset.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @targeting_preset_service_stub.create_targeting_preset request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_targeting_preset(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::TargetingPreset #get_targeting_preset(name: nil) ⇒ ::Google::Ads::AdManager::V1::TargetingPreset
Retrieves a TargetingPreset object.
Note: Deactivated targeting presets are "logically deleted" (filtered out)
by the get logic in the manager layer, so they will not be returned by the
GetTargetingPreset RPC.
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/google/ads/ad_manager/v1/targeting_preset_service/rest/client.rb', line 226 def get_targeting_preset request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::GetTargetingPresetRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_targeting_preset..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_targeting_preset.timeout, metadata: , retry_policy: @config.rpcs.get_targeting_preset.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @targeting_preset_service_stub.get_targeting_preset request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_targeting_presets(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::TargetingPreset> #list_targeting_presets(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil, skip: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::TargetingPreset>
Lists TargetingPreset objects.
337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/google/ads/ad_manager/v1/targeting_preset_service/rest/client.rb', line 337 def list_targeting_presets request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::ListTargetingPresetsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_targeting_presets..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_targeting_presets.timeout, metadata: , retry_policy: @config.rpcs.list_targeting_presets.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @targeting_preset_service_stub.list_targeting_presets request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @targeting_preset_service_stub, :list_targeting_presets, "targeting_presets", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
173 174 175 |
# File 'lib/google/ads/ad_manager/v1/targeting_preset_service/rest/client.rb', line 173 def logger @targeting_preset_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
106 107 108 |
# File 'lib/google/ads/ad_manager/v1/targeting_preset_service/rest/client.rb', line 106 def universe_domain @targeting_preset_service_stub.universe_domain end |