Class: Google::Ads::AdManager::V1::TaxonomyCategory

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/taxonomy_category_messages.rb

Overview

The TaxonomyCategory resource.

Instance Attribute Summary collapse

Instance Attribute Details

#ancestor_names::Array<::String> (readonly)

Returns Output only. The list of names of the ancestors of this TaxonomyCategory.

Returns:

  • (::Array<::String>)

    Output only. The list of names of the ancestors of this TaxonomyCategory.



53
54
55
56
# File 'proto_docs/google/ads/admanager/v1/taxonomy_category_messages.rb', line 53

class TaxonomyCategory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ancestor_taxonomy_category_ids::Array<::Integer> (readonly)

Returns Output only. The list of IDs of the ancestors of this TaxonomyCategory.

Returns:

  • (::Array<::Integer>)

    Output only. The list of IDs of the ancestors of this TaxonomyCategory.



53
54
55
56
# File 'proto_docs/google/ads/admanager/v1/taxonomy_category_messages.rb', line 53

class TaxonomyCategory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String (readonly)

Returns Output only. Display name of the TaxonomyCategory.

Returns:

  • (::String)

    Output only. Display name of the TaxonomyCategory.



53
54
55
56
# File 'proto_docs/google/ads/admanager/v1/taxonomy_category_messages.rb', line 53

class TaxonomyCategory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#grouping_only::Boolean (readonly)

Returns Output only. Whether this TaxonomyCategory only serves to group its children.

Returns:

  • (::Boolean)

    Output only. Whether this TaxonomyCategory only serves to group its children.



53
54
55
56
# File 'proto_docs/google/ads/admanager/v1/taxonomy_category_messages.rb', line 53

class TaxonomyCategory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The resource name of the TaxonomyCategory. Format: networks/{network_code}/taxonomyCategories/{taxonomy_category_id}.

Returns:

  • (::String)

    Identifier. The resource name of the TaxonomyCategory. Format: networks/{network_code}/taxonomyCategories/{taxonomy_category_id}



53
54
55
56
# File 'proto_docs/google/ads/admanager/v1/taxonomy_category_messages.rb', line 53

class TaxonomyCategory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent_taxonomy_category_id::Integer (readonly)

Returns Output only. The ID of the parent category this TaxonomyCategory descends from.

Returns:

  • (::Integer)

    Output only. The ID of the parent category this TaxonomyCategory descends from.



53
54
55
56
# File 'proto_docs/google/ads/admanager/v1/taxonomy_category_messages.rb', line 53

class TaxonomyCategory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#taxonomy_category_id::Integer (readonly)

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Output only. Deprecated: TaxonomyCategory ID.

Returns:

  • (::Integer)

    Output only. Deprecated: TaxonomyCategory ID.



53
54
55
56
# File 'proto_docs/google/ads/admanager/v1/taxonomy_category_messages.rb', line 53

class TaxonomyCategory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#taxonomy_type::Google::Ads::AdManager::V1::TaxonomyTypeEnum::TaxonomyType (readonly)

Returns Output only. The taxonomy that this TaxonomyCategory belongs to.

Returns:



53
54
55
56
# File 'proto_docs/google/ads/admanager/v1/taxonomy_category_messages.rb', line 53

class TaxonomyCategory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end