Class: Google::Ads::AdManager::V1::TeamService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::TeamService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/ads/ad_manager/v1/team_service/rest/client.rb
Overview
REST client for the TeamService service.
Provides methods for handling Team objects.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the TeamService Client class.
Instance Method Summary collapse
-
#batch_activate_teams(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::BatchActivateTeamsResponse
API to batch activate
Teamobjects. -
#batch_create_teams(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::BatchCreateTeamsResponse
API to batch create
Teamobjects. -
#batch_deactivate_teams(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::BatchDeactivateTeamsResponse
API to batch deactivate
Teamobjects. -
#batch_update_teams(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::BatchUpdateTeamsResponse
API to batch update
Teamobjects. -
#configure {|config| ... } ⇒ Client::Configuration
Configure the TeamService Client instance.
-
#create_team(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::Team
API to create a
Teamobject. -
#get_team(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::Team
API to retrieve a
Teamobject. -
#initialize {|config| ... } ⇒ Client
constructor
Create a new TeamService REST client object.
-
#list_teams(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::Team>
API to retrieve a list of
Teamobjects. -
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_team(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::Team
API to update a
Teamobject.
Methods included from Paths
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new TeamService REST client object.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/google/ads/ad_manager/v1/team_service/rest/client.rb', line 126 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @team_service_stub = ::Google::Ads::AdManager::V1::TeamService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @team_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the TeamService Client class.
See Configuration for a description of the configuration fields.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/google/ads/ad_manager/v1/team_service/rest/client.rb', line 64 def self.configure @configure ||= begin namespace = ["Google", "Ads", "AdManager", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config end yield @configure if block_given? @configure end |
Instance Method Details
#batch_activate_teams(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchActivateTeamsResponse #batch_activate_teams(parent: nil, names: nil) ⇒ ::Google::Ads::AdManager::V1::BatchActivateTeamsResponse
API to batch activate Team objects.
752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 |
# File 'lib/google/ads/ad_manager/v1/team_service/rest/client.rb', line 752 def batch_activate_teams request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchActivateTeamsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_activate_teams..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.batch_activate_teams.timeout, metadata: , retry_policy: @config.rpcs.batch_activate_teams.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @team_service_stub.batch_activate_teams request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#batch_create_teams(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchCreateTeamsResponse #batch_create_teams(parent: nil, requests: nil) ⇒ ::Google::Ads::AdManager::V1::BatchCreateTeamsResponse
API to batch create Team objects.
505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/google/ads/ad_manager/v1/team_service/rest/client.rb', line 505 def batch_create_teams request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchCreateTeamsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_create_teams..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.batch_create_teams.timeout, metadata: , retry_policy: @config.rpcs.batch_create_teams.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @team_service_stub.batch_create_teams request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#batch_deactivate_teams(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchDeactivateTeamsResponse #batch_deactivate_teams(parent: nil, names: nil) ⇒ ::Google::Ads::AdManager::V1::BatchDeactivateTeamsResponse
API to batch deactivate Team objects.
833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'lib/google/ads/ad_manager/v1/team_service/rest/client.rb', line 833 def batch_deactivate_teams request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchDeactivateTeamsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_deactivate_teams..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.batch_deactivate_teams.timeout, metadata: , retry_policy: @config.rpcs.batch_deactivate_teams.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @team_service_stub.batch_deactivate_teams request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#batch_update_teams(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchUpdateTeamsResponse #batch_update_teams(parent: nil, requests: nil) ⇒ ::Google::Ads::AdManager::V1::BatchUpdateTeamsResponse
API to batch update Team objects.
671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 |
# File 'lib/google/ads/ad_manager/v1/team_service/rest/client.rb', line 671 def batch_update_teams request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchUpdateTeamsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_update_teams..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.batch_update_teams.timeout, metadata: , retry_policy: @config.rpcs.batch_update_teams.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @team_service_stub.batch_update_teams request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the TeamService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
96 97 98 99 |
# File 'lib/google/ads/ad_manager/v1/team_service/rest/client.rb', line 96 def configure yield @config if block_given? @config end |
#create_team(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::Team #create_team(parent: nil, team: nil) ⇒ ::Google::Ads::AdManager::V1::Team
API to create a Team object.
421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 |
# File 'lib/google/ads/ad_manager/v1/team_service/rest/client.rb', line 421 def create_team request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::CreateTeamRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_team..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_team.timeout, metadata: , retry_policy: @config.rpcs.create_team.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @team_service_stub.create_team request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_team(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::Team #get_team(name: nil) ⇒ ::Google::Ads::AdManager::V1::Team
API to retrieve a Team object.
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/google/ads/ad_manager/v1/team_service/rest/client.rb', line 223 def get_team request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::GetTeamRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_team..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_team.timeout, metadata: , retry_policy: @config.rpcs.get_team.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @team_service_stub.get_team request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_teams(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::Team> #list_teams(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil, skip: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::Team>
API to retrieve a list of Team objects.
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/google/ads/ad_manager/v1/team_service/rest/client.rb', line 338 def list_teams request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::ListTeamsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_teams..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_teams.timeout, metadata: , retry_policy: @config.rpcs.list_teams.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @team_service_stub.list_teams request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @team_service_stub, :list_teams, "teams", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
173 174 175 |
# File 'lib/google/ads/ad_manager/v1/team_service/rest/client.rb', line 173 def logger @team_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
106 107 108 |
# File 'lib/google/ads/ad_manager/v1/team_service/rest/client.rb', line 106 def universe_domain @team_service_stub.universe_domain end |
#update_team(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::Team #update_team(team: nil, update_mask: nil) ⇒ ::Google::Ads::AdManager::V1::Team
API to update a Team object.
587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 |
# File 'lib/google/ads/ad_manager/v1/team_service/rest/client.rb', line 587 def update_team request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::UpdateTeamRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_team..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_team.timeout, metadata: , retry_policy: @config.rpcs.update_team.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @team_service_stub.update_team request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |