Class: Google::Ads::AdManager::V1::ThirdPartyCompany

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/admanager/v1/third_party_company_messages.rb

Overview

Represents a third-party company recognized by Google Ad Manager, which can be an ad network, ad server, or video technology partner.

Instance Attribute Summary collapse

Instance Attribute Details

#display_name::String (readonly)

Returns Output only. The display name of the ThirdPartyCompany. This field must be unique among all ThirdPartyCompanies for this network.

Returns:

  • (::String)

    Output only. The display name of the ThirdPartyCompany. This field must be unique among all ThirdPartyCompanies for this network.



42
43
44
45
# File 'proto_docs/google/ads/admanager/v1/third_party_company_messages.rb', line 42

class ThirdPartyCompany
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The resource name of the ThirdPartyCompany. Format: networks/{network_code}/thirdPartyCompanies/{third_party_company_id}.

Returns:

  • (::String)

    Identifier. The resource name of the ThirdPartyCompany. Format: networks/{network_code}/thirdPartyCompanies/{third_party_company_id}



42
43
44
45
# File 'proto_docs/google/ads/admanager/v1/third_party_company_messages.rb', line 42

class ThirdPartyCompany
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#status::Google::Ads::AdManager::V1::ThirdPartyCompanyStatusEnum::ThirdPartyCompanyStatus (readonly)

Returns Output only. The status of the ThirdPartyCompany. ThirdPartyCompanies are set to inactive rather than deleting them.

Returns:



42
43
44
45
# File 'proto_docs/google/ads/admanager/v1/third_party_company_messages.rb', line 42

class ThirdPartyCompany
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#type::Google::Ads::AdManager::V1::ThirdPartyCompanyTypeEnum::ThirdPartyCompanyType (readonly)

Returns Output only. The type of the ThirdPartyCompany.

Returns:



42
43
44
45
# File 'proto_docs/google/ads/admanager/v1/third_party_company_messages.rb', line 42

class ThirdPartyCompany
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end