Class: Google::Ads::AdManager::V1::Application
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::Application
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/application_messages.rb
Overview
An application that has been added to or "claimed" by the network to be used for targeting purposes. These mobile apps can come from various app stores.
Instance Attribute Summary collapse
-
#app_store_display_name ⇒ ::String
readonly
Output only.
-
#app_store_id ⇒ ::String
Optional.
-
#app_stores ⇒ ::Array<::Google::Ads::AdManager::V1::ApplicationStoreEnum::ApplicationStore>
Optional.
-
#application_code ⇒ ::String
readonly
Output only.
-
#approval_status ⇒ ::Google::Ads::AdManager::V1::ApplicationApprovalStatusEnum::ApplicationApprovalStatus
readonly
Output only.
-
#archived ⇒ ::Boolean
readonly
Output only.
-
#developer ⇒ ::String
readonly
Output only.
-
#display_name ⇒ ::String
Required.
-
#download_url ⇒ ::String
readonly
Output only.
-
#free ⇒ ::Boolean
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#platform ⇒ ::Google::Ads::AdManager::V1::ApplicationPlatformEnum::ApplicationPlatform
readonly
Output only.
-
#webview_claiming_status ⇒ ::Google::Ads::AdManager::V1::WebviewClaimingStatusEnum::WebviewClaimingStatus
readonly
Output only.
Instance Attribute Details
#app_store_display_name ⇒ ::String (readonly)
Returns Output only. The name of the application on the app store.
74 75 76 77 |
# File 'proto_docs/google/ads/admanager/v1/application_messages.rb', line 74 class Application include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#app_store_id ⇒ ::String
Returns Optional. The app store ID of the app to claim.
74 75 76 77 |
# File 'proto_docs/google/ads/admanager/v1/application_messages.rb', line 74 class Application include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#app_stores ⇒ ::Array<::Google::Ads::AdManager::V1::ApplicationStoreEnum::ApplicationStore>
Returns Optional. The app stores the application belongs to. This attribute is mutable to allow for third party app store linking.
74 75 76 77 |
# File 'proto_docs/google/ads/admanager/v1/application_messages.rb', line 74 class Application include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#application_code ⇒ ::String (readonly)
Returns Output only. The application code used to identify the app in the SDK.
Note that the UI refers to this as "App ID".
74 75 76 77 |
# File 'proto_docs/google/ads/admanager/v1/application_messages.rb', line 74 class Application include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#approval_status ⇒ ::Google::Ads::AdManager::V1::ApplicationApprovalStatusEnum::ApplicationApprovalStatus (readonly)
Returns Output only. The approval status for the application.
74 75 76 77 |
# File 'proto_docs/google/ads/admanager/v1/application_messages.rb', line 74 class Application include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#archived ⇒ ::Boolean (readonly)
Returns Output only. The archival status of the application.
When true, an application cannot be targeted and will not serve ads,
regardless of its status.
74 75 76 77 |
# File 'proto_docs/google/ads/admanager/v1/application_messages.rb', line 74 class Application include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#developer ⇒ ::String (readonly)
Returns Output only. The name of the developer of the application.
74 75 76 77 |
# File 'proto_docs/google/ads/admanager/v1/application_messages.rb', line 74 class Application include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Required. The display name of the application.
74 75 76 77 |
# File 'proto_docs/google/ads/admanager/v1/application_messages.rb', line 74 class Application include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#download_url ⇒ ::String (readonly)
Returns Output only. The download URL of the application on the app store it belongs to.
74 75 76 77 |
# File 'proto_docs/google/ads/admanager/v1/application_messages.rb', line 74 class Application include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#free ⇒ ::Boolean (readonly)
Returns Output only. Whether the application is free on the app store it belongs to.
74 75 76 77 |
# File 'proto_docs/google/ads/admanager/v1/application_messages.rb', line 74 class Application include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The resource name of the Application.
Format: networks/{network_code}/applications/{application_id}.
74 75 76 77 |
# File 'proto_docs/google/ads/admanager/v1/application_messages.rb', line 74 class Application include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#platform ⇒ ::Google::Ads::AdManager::V1::ApplicationPlatformEnum::ApplicationPlatform (readonly)
Returns Output only. The platform the application runs on.
74 75 76 77 |
# File 'proto_docs/google/ads/admanager/v1/application_messages.rb', line 74 class Application include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#webview_claiming_status ⇒ ::Google::Ads::AdManager::V1::WebviewClaimingStatusEnum::WebviewClaimingStatus (readonly)
Returns Output only. The webview claiming status for the application.
74 75 76 77 |
# File 'proto_docs/google/ads/admanager/v1/application_messages.rb', line 74 class Application include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |