Class: Google::Ads::AdManager::V1::BatchAdReviewCenterAdsOperationMetadata
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::BatchAdReviewCenterAdsOperationMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/ad_review_center_ad_service.rb
Overview
Metadata object for BatchAllowAdReviewCenterAds and
BatchBlockAdReviewCenterAds methods.
Defined Under Namespace
Classes: FailedRequestsEntry
Instance Attribute Summary collapse
-
#failed_requests ⇒ ::Google::Protobuf::Map{::Integer => ::Google::Rpc::Status}
The status of each failed request, keyed by the index of the corresponding request in the batch request.
Instance Attribute Details
#failed_requests ⇒ ::Google::Protobuf::Map{::Integer => ::Google::Rpc::Status}
Returns The status of each failed request, keyed by the index of the corresponding request in the batch request.
176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'proto_docs/google/ads/admanager/v1/ad_review_center_ad_service.rb', line 176 class BatchAdReviewCenterAdsOperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::Integer] # @!attribute [rw] value # @return [::Google::Rpc::Status] class FailedRequestsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |