Class: Google::Ads::AdManager::V1::BatchApproveSuggestedAdUnitsResponse
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::BatchApproveSuggestedAdUnitsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/suggested_ad_unit_service.rb
Overview
Response message for BatchApproveSuggestedAdUnits method.
Instance Attribute Summary collapse
-
#created_ad_units ⇒ ::Array<::String>
The resource names of the AdUnits that were created as part of the approval.
Instance Attribute Details
#created_ad_units ⇒ ::Array<::String>
Returns The resource names of the AdUnits that were created as part of the approval. The order of the ad units in the response is not guaranteed to be the same as the order of the suggestions in the request.
123 124 125 126 |
# File 'proto_docs/google/ads/admanager/v1/suggested_ad_unit_service.rb', line 123 class BatchApproveSuggestedAdUnitsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |