Class: Google::Ads::AdManager::V1::CdnSecurityPolicy
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::CdnSecurityPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/cdn_config_messages.rb
Overview
A set of security requirements to authenticate against in order to access video content. Different locations (e.g. different CDNs) can have different security policies.
Instance Attribute Summary collapse
-
#keyset ⇒ ::String
Optional.
-
#media_playlist_origin_forwarding_type ⇒ ::Google::Ads::AdManager::V1::CdnSecurityPolicyOriginForwardingEnum::CdnSecurityPolicyOriginForwarding
Optional.
-
#media_playlist_origin_path_prefix ⇒ ::String
Optional.
-
#origin_forwarding_type ⇒ ::Google::Ads::AdManager::V1::CdnSecurityPolicyOriginForwardingEnum::CdnSecurityPolicyOriginForwarding
Optional.
-
#origin_path_prefix ⇒ ::String
Optional.
-
#security_policy_type ⇒ ::Google::Ads::AdManager::V1::CdnSecurityPolicyTypeEnum::CdnSecurityPolicyType
Required.
-
#server_side_url_signing_disabled ⇒ ::Boolean
Optional.
-
#signed_request_expiration_ttl ⇒ ::Google::Protobuf::Duration
Optional.
-
#token_authentication_key ⇒ ::String
Optional.
Instance Attribute Details
#keyset ⇒ ::String
Returns Optional. The name of the EdgeCacheKeyset on the Media CDN config that will be used to validate signed requests from DAI to ingest content.
116 117 118 119 |
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 116 class CdnSecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#media_playlist_origin_forwarding_type ⇒ ::Google::Ads::AdManager::V1::CdnSecurityPolicyOriginForwardingEnum::CdnSecurityPolicyOriginForwarding
Returns Optional. The type of origin forwarding used to support Akamai
authentication policies for media playlists. This setting can only be used
with CDN configs with a cdnConfigType of
CdnConfigType.LIVE_STREAM_SOURCE_CONTENT, is not applicable to ingest
locations, and is only applicable to delivery media locations with the
CdnSecurityPolicyType set to CdnSecurityPolicyType.AKAMAI. Valid
options are CdnSecurityPolicyOriginForwarding.NONE or
CdnSecurityPolicyOriginForwarding.ORIGIN_PATH. This setting can only be
used with CDN configs with a cdnConfigType of
CdnConfigType.LIVE_STREAM_SOURCE_CONTENT.
116 117 118 119 |
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 116 class CdnSecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#media_playlist_origin_path_prefix ⇒ ::String
Returns Optional. The origin path prefix provided by the publisher for the media
playlists. Only applicable for delivery media locations with the value of
mediaPlaylistOriginForwardingType set to
CdnSecurityPolicyOriginForwarding.CONVENTIONAL, and will be set to null
otherwise.
116 117 118 119 |
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 116 class CdnSecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#origin_forwarding_type ⇒ ::Google::Ads::AdManager::V1::CdnSecurityPolicyOriginForwardingEnum::CdnSecurityPolicyOriginForwarding
Returns Optional. The type of origin forwarding used to support Akamai
authentication policies for the parent playlist. Not applicable to ingest
locations, and is only applicable to delivery media locations with the
securityPolicyType set to CdnSecurityPolicyType.AKAMAI. If set
elsewhere it will be reset to null.
116 117 118 119 |
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 116 class CdnSecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#origin_path_prefix ⇒ ::String
Returns Optional. The origin path prefix provided by the publisher for the parent
playlist. Only applicable for delivery media locations with the value of
originForwardingType set to
CdnSecurityPolicyOriginForwarding.CONVENTIONAL, and will be set to null
otherwise.
116 117 118 119 |
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 116 class CdnSecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#security_policy_type ⇒ ::Google::Ads::AdManager::V1::CdnSecurityPolicyTypeEnum::CdnSecurityPolicyType
Returns Required. Type of security policy. This determines which other fields should be populated. This value is required for a valid security policy.
116 117 118 119 |
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 116 class CdnSecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#server_side_url_signing_disabled ⇒ ::Boolean
Returns Optional. Whether the segment URLs should be signed using the
tokenAuthenticationKey on the server. This is only applicable for delivery
media locations that have token authentication enabled.
116 117 118 119 |
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 116 class CdnSecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#signed_request_expiration_ttl ⇒ ::Google::Protobuf::Duration
Returns Optional. The duration for which a request signed with a short token
will be valid. Only required if signedRequestMaximumExpirationTtl has
been set in the Media CDN config.
116 117 118 119 |
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 116 class CdnSecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#token_authentication_key ⇒ ::String
Returns Optional. Shared security key used to generate the Akamai HMAC token for
authenticating requests. Only applicable when the value of
CdnSecurityPolicyType is equal to CdnSecurityPolicyType.AKAMAI and will
be set to null otherwise. Required when the CdnConfig.cdnConfigType is
equal to CdnConfigType.LIVE_STREAM_SOURCE_CONTENT and this
CdnSecurityPolicy is being configured for
SourceContentConfig.ingestSettings.
116 117 118 119 |
# File 'proto_docs/google/ads/admanager/v1/cdn_config_messages.rb', line 116 class CdnSecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |