Class: Google::Ads::AdManager::V1::Content
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::Content
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/content_messages.rb
Overview
A piece of Content from a Publisher's CMS.
Instance Attribute Summary collapse
-
#cms_metadata_values ⇒ ::Array<::String>
readonly
Output only.
-
#cms_sources ⇒ ::Array<::Google::Ads::AdManager::V1::CmsContent>
readonly
Output only.
-
#content_bundles ⇒ ::Array<::String>
readonly
Output only.
-
#content_status_source ⇒ ::Google::Ads::AdManager::V1::ContentStatusSourceEnum::ContentStatusSource
readonly
Output only.
-
#dash_ingest_errors ⇒ ::Array<::Google::Ads::AdManager::V1::DaiIngestError>
readonly
Output only.
-
#dash_ingest_status ⇒ ::Google::Ads::AdManager::V1::DaiIngestStatusEnum::DaiIngestStatus
readonly
Output only.
-
#display_name ⇒ ::String
readonly
Output only.
-
#duration ⇒ ::Google::Protobuf::Duration
readonly
Output only.
-
#hls_ingest_errors ⇒ ::Array<::Google::Ads::AdManager::V1::DaiIngestError>
readonly
Output only.
-
#hls_ingest_status ⇒ ::Google::Ads::AdManager::V1::DaiIngestStatusEnum::DaiIngestStatus
readonly
Output only.
-
#import_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#last_dash_ingest_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#last_hls_ingest_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#status ⇒ ::Google::Ads::AdManager::V1::ContentStatusEnum::ContentStatus
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#cms_metadata_values ⇒ ::Array<::String> (readonly)
Returns Output only. The resource names of the [CmsMetadataValues]
[google.ads.admanager.v1.CmsMetadataValue] that
are associated with this Content.
103 104 105 106 |
# File 'proto_docs/google/ads/admanager/v1/content_messages.rb', line 103 class Content include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cms_sources ⇒ ::Array<::Google::Ads::AdManager::V1::CmsContent> (readonly)
Returns Output only. Information about the Content from the CMS it was ingested
from.
103 104 105 106 |
# File 'proto_docs/google/ads/admanager/v1/content_messages.rb', line 103 class Content include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#content_bundles ⇒ ::Array<::String> (readonly)
Returns Output only. The resource names of the
ContentBundles of
which this Content is a member.
103 104 105 106 |
# File 'proto_docs/google/ads/admanager/v1/content_messages.rb', line 103 class Content include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#content_status_source ⇒ ::Google::Ads::AdManager::V1::ContentStatusSourceEnum::ContentStatusSource (readonly)
Returns Output only. Whether the content status was defined by the user, or by the
source CMS from which the Content was ingested.
103 104 105 106 |
# File 'proto_docs/google/ads/admanager/v1/content_messages.rb', line 103 class Content include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#dash_ingest_errors ⇒ ::Array<::Google::Ads::AdManager::V1::DaiIngestError> (readonly)
Returns Output only. The list of any errors that occurred during the most recent
DAI ingestion process of the DASH media. This attribute will be empty if
the hlsIngestStatus is [DaiIngestStatus.SUCCESS][] or if the Content is
not eligible for dynamic ad insertion or if the Content does not have
DASH media.
103 104 105 106 |
# File 'proto_docs/google/ads/admanager/v1/content_messages.rb', line 103 class Content include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#dash_ingest_status ⇒ ::Google::Ads::AdManager::V1::DaiIngestStatusEnum::DaiIngestStatus (readonly)
Returns Output only. The current DAI ingest status of the DASH media for the
Content. This attribute is unset if the Content is not eligible for
dynamic ad insertion or if the Content does not have DASH media.
103 104 105 106 |
# File 'proto_docs/google/ads/admanager/v1/content_messages.rb', line 103 class Content include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String (readonly)
Returns Output only. The name of the Content.
103 104 105 106 |
# File 'proto_docs/google/ads/admanager/v1/content_messages.rb', line 103 class Content include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#duration ⇒ ::Google::Protobuf::Duration (readonly)
Returns Output only. The duration of the Content.
103 104 105 106 |
# File 'proto_docs/google/ads/admanager/v1/content_messages.rb', line 103 class Content include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#hls_ingest_errors ⇒ ::Array<::Google::Ads::AdManager::V1::DaiIngestError> (readonly)
Returns Output only. The list of any errors that occurred during the most recent
DAI ingestion process of the HLS media. This attribute will be empty if the
hlsIngestStatus is [DaiIngestStatus.SUCCESS][] or if the Content is
not eligible for dynamic ad insertion or if the Content does not have
HLS media.
103 104 105 106 |
# File 'proto_docs/google/ads/admanager/v1/content_messages.rb', line 103 class Content include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#hls_ingest_status ⇒ ::Google::Ads::AdManager::V1::DaiIngestStatusEnum::DaiIngestStatus (readonly)
Returns Output only. The current DAI ingest status of the HLS media for the
Content. This attribute is unset if the Content is not eligible for
dynamic ad insertion or if the Content does not have HLS media.
103 104 105 106 |
# File 'proto_docs/google/ads/admanager/v1/content_messages.rb', line 103 class Content include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#import_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp at which this Content was published.
103 104 105 106 |
# File 'proto_docs/google/ads/admanager/v1/content_messages.rb', line 103 class Content include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#last_dash_ingest_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp at which this Content's DASH media was last
ingested for DAI. This attribute will be unset if the Content is not
eligible for dynamic ad insertion or if the Content does not have DASH
media.
103 104 105 106 |
# File 'proto_docs/google/ads/admanager/v1/content_messages.rb', line 103 class Content include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#last_hls_ingest_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp at which this Content's HLS media was last
ingested for DAI. This attribute will be unset if the Content is not
eligible for dynamic ad insertion or if the Content does not have HLS
media.
103 104 105 106 |
# File 'proto_docs/google/ads/admanager/v1/content_messages.rb', line 103 class Content include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The resource name of the Content.
Format: networks/{network_code}/content/{content_id}.
103 104 105 106 |
# File 'proto_docs/google/ads/admanager/v1/content_messages.rb', line 103 class Content include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#status ⇒ ::Google::Ads::AdManager::V1::ContentStatusEnum::ContentStatus (readonly)
Returns Output only. The status of this Content.
103 104 105 106 |
# File 'proto_docs/google/ads/admanager/v1/content_messages.rb', line 103 class Content include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp at which this Content was last modified.
The last modified date time will always be updated when a
ContentBundle
association is changed, but will not always be updated when a
CmsMetadataValue
value is changed.
103 104 105 106 |
# File 'proto_docs/google/ads/admanager/v1/content_messages.rb', line 103 class Content include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |