Class: Google::Ads::AdManager::V1::CreativeSet
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::CreativeSet
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/creative_set_messages.rb
Overview
A CreativeSet is comprised of a master Creative and its companion
Creatives.
Instance Attribute Summary collapse
-
#companion_creatives ⇒ ::Array<::String>
Required.
-
#display_name ⇒ ::String
Required.
-
#master_creative ⇒ ::String
Required.
-
#name ⇒ ::String
Identifier.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#companion_creatives ⇒ ::Array<::String>
Returns Required. The resource names of the companion Creatives associated with
this CreativeSet. Format: networks/{network_code}/creatives/{creative}.
46 47 48 49 |
# File 'proto_docs/google/ads/admanager/v1/creative_set_messages.rb', line 46 class CreativeSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Required. The name of the CreativeSet. This attribute has a maximum
length of 255 characters.
46 47 48 49 |
# File 'proto_docs/google/ads/admanager/v1/creative_set_messages.rb', line 46 class CreativeSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#master_creative ⇒ ::String
Returns Required. Immutable. The master
Creative to which the CreativeSet is
associated.
46 47 48 49 |
# File 'proto_docs/google/ads/admanager/v1/creative_set_messages.rb', line 46 class CreativeSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The resource name of the CreativeSet.
Format: networks/{network_code}/creativeSets/{creative_set_id}.
46 47 48 49 |
# File 'proto_docs/google/ads/admanager/v1/creative_set_messages.rb', line 46 class CreativeSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time this CreativeSet was last modified.
46 47 48 49 |
# File 'proto_docs/google/ads/admanager/v1/creative_set_messages.rb', line 46 class CreativeSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |