Class: Google::Ads::AdManager::V1::EarningsProductBreakdown
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::EarningsProductBreakdown
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/mcm_earnings_messages.rb
Overview
The product type breakdown of earnings for a given month between a parent and child publisher in MCM.
Instance Attribute Summary collapse
-
#child_payment ⇒ ::Google::Type::Money
The portion of the total earnings for the specified product type paid to the child publisher.
-
#deductions ⇒ ::Google::Type::Money
The deductions for the specified product type for the month due to spam.
-
#parent_payment ⇒ ::Google::Type::Money
The portion of the total earnings for the specified product type paid to the parent publisher.
-
#product_type ⇒ ::Google::Ads::AdManager::V1::McmEarningsProductTypeEnum::McmEarningsProductType
The syndication product type of the child's earnings in MCM.
-
#total_earnings ⇒ ::Google::Type::Money
The total earnings for the specified product type for the month.
Instance Attribute Details
#child_payment ⇒ ::Google::Type::Money
Returns The portion of the total earnings for the specified product type paid to the child publisher.
94 95 96 97 |
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_messages.rb', line 94 class EarningsProductBreakdown include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#deductions ⇒ ::Google::Type::Money
Returns The deductions for the specified product type for the month due to spam.
94 95 96 97 |
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_messages.rb', line 94 class EarningsProductBreakdown include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent_payment ⇒ ::Google::Type::Money
Returns The portion of the total earnings for the specified product type paid to the parent publisher.
94 95 96 97 |
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_messages.rb', line 94 class EarningsProductBreakdown include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#product_type ⇒ ::Google::Ads::AdManager::V1::McmEarningsProductTypeEnum::McmEarningsProductType
Returns The syndication product type of the child's earnings in MCM.
94 95 96 97 |
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_messages.rb', line 94 class EarningsProductBreakdown include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_earnings ⇒ ::Google::Type::Money
Returns The total earnings for the specified product type for the month.
94 95 96 97 |
# File 'proto_docs/google/ads/admanager/v1/mcm_earnings_messages.rb', line 94 class EarningsProductBreakdown include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |