Module: Google::Ads::AdManager::V1::ExclusionScopeEnum::ExclusionScope
- Defined in:
- proto_docs/google/ads/admanager/v1/exclusion_scope_enum.rb
Overview
The scope to which the exclusion label applies.
Constant Summary collapse
- EXCLUSION_SCOPE_UNSPECIFIED =
No value specified.
0- PAGE =
The exclusion label applies to the entire page.
1- STREAM =
The exclusion label applies to the entire stream of content.
2- POD =
The exclusion label applies to the entire pod (or group).
3