Class: Google::Ads::AdManager::V1::GrpSettings
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::GrpSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/grp_settings.rb
Overview
GrpSettings contains information for a line item that will have a target demographic when serving. This information will be used to set up tracking and enable reporting on the demographic information.
Instance Attribute Summary collapse
-
#apply_true_coview ⇒ ::Boolean
Optional.
-
#in_target_ratio_estimate_milli_percent ⇒ ::Integer
Optional.
-
#max_target_age ⇒ ::Integer
Optional.
-
#min_target_age ⇒ ::Integer
Optional.
-
#nielsen_ctv_pacing_type ⇒ ::Google::Ads::AdManager::V1::NielsenCtvPacingEnum::NielsenCtvPacing
Optional.
-
#pacing_device_categorization_type ⇒ ::Google::Ads::AdManager::V1::PacingDeviceCategorizationEnum::PacingDeviceCategorization
Optional.
-
#provider ⇒ ::Google::Ads::AdManager::V1::GrpProviderEnum::GrpProvider
Optional.
-
#target_gender ⇒ ::Google::Ads::AdManager::V1::GrpTargetGenderEnum::GrpTargetGender
Optional.
Instance Attribute Details
#apply_true_coview ⇒ ::Boolean
Returns Optional. Specifies whether to apply true coviewing in Nielsen Line Item auto pacing. This field can only be true if nielsen_ctv_pacing_type is not NONE.
68 69 70 71 |
# File 'proto_docs/google/ads/admanager/v1/grp_settings.rb', line 68 class GrpSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#in_target_ratio_estimate_milli_percent ⇒ ::Integer
Returns Optional. Estimate for the in-target ratio given the line item's audience targeting. This field is only applicable if provider is Nielsen, [LineItem.primary_goal.unit_type][] is in-target impressions, and [LineItemCostType] is in-target CPM. This field determines the in-target ratio to use for pacing Nielsen line items before Nielsen reporting data is available. Represented as a milli percent, so 55.7% becomes 55700.
68 69 70 71 |
# File 'proto_docs/google/ads/admanager/v1/grp_settings.rb', line 68 class GrpSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_target_age ⇒ ::Integer
Returns Optional. Specifies the maximum target age (in years) of the LineItem. This field is only applicable if provider is not null.
68 69 70 71 |
# File 'proto_docs/google/ads/admanager/v1/grp_settings.rb', line 68 class GrpSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#min_target_age ⇒ ::Integer
Returns Optional. Specifies the minimum target age (in years) of the LineItem. This field is only applicable if provider is not null.
68 69 70 71 |
# File 'proto_docs/google/ads/admanager/v1/grp_settings.rb', line 68 class GrpSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#nielsen_ctv_pacing_type ⇒ ::Google::Ads::AdManager::V1::NielsenCtvPacingEnum::NielsenCtvPacing
Returns Optional. Specifies which pacing computation to apply in pacing to impressions from connected devices.
68 69 70 71 |
# File 'proto_docs/google/ads/admanager/v1/grp_settings.rb', line 68 class GrpSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pacing_device_categorization_type ⇒ ::Google::Ads::AdManager::V1::PacingDeviceCategorizationEnum::PacingDeviceCategorization
Returns Optional. Specifies whether to use Google or Nielsen device breakdown in Nielsen Line Item auto pacing.
68 69 70 71 |
# File 'proto_docs/google/ads/admanager/v1/grp_settings.rb', line 68 class GrpSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#provider ⇒ ::Google::Ads::AdManager::V1::GrpProviderEnum::GrpProvider
Returns Optional. Specifies the GRP provider of the LineItem.
68 69 70 71 |
# File 'proto_docs/google/ads/admanager/v1/grp_settings.rb', line 68 class GrpSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#target_gender ⇒ ::Google::Ads::AdManager::V1::GrpTargetGenderEnum::GrpTargetGender
Returns Optional. Specifies the target gender of the LineItem. This field is only applicable if provider is not null.
68 69 70 71 |
# File 'proto_docs/google/ads/admanager/v1/grp_settings.rb', line 68 class GrpSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |