Class: Google::Ads::AdManager::V1::LineItem
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::LineItem
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/line_item_messages.rb
Overview
A LineItem contains information about how specific ad creatives are intended to serve to your website or app along with pricing and other delivery details.
Instance Attribute Summary collapse
-
#allow_overbook ⇒ ::Boolean
Input only.
-
#allowed_formats ⇒ ::Array<::Google::Ads::AdManager::V1::LineItemAllowedFormatEnum::LineItemAllowedFormat>
Optional.
-
#applied_labels ⇒ ::Array<::Google::Ads::AdManager::V1::AppliedLabel>
Optional.
-
#archived ⇒ ::Boolean
readonly
Output only.
-
#auto_extension_days ⇒ ::Integer
Optional.
-
#budget ⇒ ::Google::Type::Money
readonly
Output only.
-
#child_content_eligibility ⇒ ::Google::Ads::AdManager::V1::ChildContentEligibilityEnum::ChildContentEligibility
Optional.
-
#companion_delivery_option ⇒ ::Google::Ads::AdManager::V1::CompanionDeliveryOptionEnum::CompanionDeliveryOption
Optional.
-
#competitive_constraint_scope ⇒ ::Google::Ads::AdManager::V1::ExclusionScopeEnum::ExclusionScope
Optional.
-
#contracted_units_bought ⇒ ::Integer
Optional.
-
#cost_type ⇒ ::Google::Ads::AdManager::V1::LineItemCostTypeEnum::LineItemCostType
Required.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#creative_placeholders ⇒ ::Array<::Google::Ads::AdManager::V1::CreativePlaceholder>
Required.
-
#creative_rotation_type ⇒ ::Google::Ads::AdManager::V1::CreativeRotationTypeEnum::CreativeRotationType
Required.
-
#creative_targetings ⇒ ::Array<::Google::Ads::AdManager::V1::CreativeTargeting>
Optional.
-
#custom_field_values ⇒ ::Array<::Google::Ads::AdManager::V1::CustomFieldValue>
Optional.
-
#custom_pacing_curve ⇒ ::Google::Ads::AdManager::V1::CustomPacingCurve
Optional.
-
#custom_vast_extension ⇒ ::String
Optional.
-
#deal_info ⇒ ::Google::Ads::AdManager::V1::LineItemDealInfo
Optional.
-
#delivery_forecast_source ⇒ ::Google::Ads::AdManager::V1::LineItemDeliveryForecastSourceEnum::LineItemDeliveryForecastSource
Optional.
-
#delivery_indicator ⇒ ::Google::Ads::AdManager::V1::DeliveryIndicator
readonly
Output only.
-
#delivery_rate_type ⇒ ::Google::Ads::AdManager::V1::LineItemDeliveryRateTypeEnum::LineItemDeliveryRateType
Optional.
-
#discount ⇒ ::Google::Ads::AdManager::V1::LineItemDiscount
Optional.
-
#display_name ⇒ ::String
Required.
-
#effective_applied_labels ⇒ ::Array<::Google::Ads::AdManager::V1::AppliedLabel>
readonly
Output only.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#end_time_unlimited ⇒ ::Boolean
Optional.
-
#environment_type ⇒ ::Google::Ads::AdManager::V1::EnvironmentTypeEnum::EnvironmentType
Optional.
-
#external_line_item_id ⇒ ::String
Optional.
-
#frequency_caps ⇒ ::Array<::Google::Ads::AdManager::V1::FrequencyCap>
Optional.
-
#goal ⇒ ::Google::Ads::AdManager::V1::Goal
Optional.
-
#grp_settings ⇒ ::Google::Ads::AdManager::V1::GrpSettings
Optional.
-
#line_item_type ⇒ ::Google::Ads::AdManager::V1::LineItemTypeEnum::LineItemType
Required.
-
#max_video_creative_duration ⇒ ::Google::Protobuf::Duration
Optional.
-
#missing_creatives ⇒ ::Boolean
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#notes ⇒ ::String
Optional.
-
#order ⇒ ::String
Required.
-
#order_display_name ⇒ ::String
readonly
Output only.
-
#priority ⇒ ::Integer
Optional.
-
#rate ⇒ ::Google::Type::Money
Required.
-
#repeated_creative_serving_enabled ⇒ ::Boolean
Optional.
-
#reservation_status ⇒ ::Google::Ads::AdManager::V1::LineItemReservationStatusEnum::LineItemReservationStatus
readonly
Output only.
-
#reserve_on_creation ⇒ ::Boolean
Input only.
-
#roadblocking_type ⇒ ::Google::Ads::AdManager::V1::RoadblockingTypeEnum::RoadblockingType
Optional.
-
#same_advertiser_exception_enabled ⇒ ::Boolean
Optional.
-
#secondary_goals ⇒ ::Array<::Google::Ads::AdManager::V1::Goal>
Optional.
-
#skip_cross_selling_rule_warning_checks ⇒ ::Boolean
Input only.
-
#skip_inventory_check ⇒ ::Boolean
Input only.
-
#skippable_ad_type ⇒ ::Google::Ads::AdManager::V1::SkippableAdTypeEnum::SkippableAdType
Optional.
-
#sponsorship_exclusivity_enabled ⇒ ::Boolean
Optional.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
Required.
-
#stats ⇒ ::Google::Ads::AdManager::V1::LineItemStats
readonly
Output only.
-
#status ⇒ ::Google::Ads::AdManager::V1::LineItemComputedStatusEnum::LineItemComputedStatus
readonly
Output only.
-
#target_end_time ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#targeting ⇒ ::Google::Ads::AdManager::V1::Targeting
Required.
-
#third_party_measurement_settings ⇒ ::Google::Ads::AdManager::V1::ThirdPartyMeasurementSettings
Optional.
-
#update_source ⇒ ::String
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#value_cpm ⇒ ::Google::Type::Money
Optional.
-
#viewability_provider_companies ⇒ ::Array<::String>
Optional.
-
#web_property_code ⇒ ::String
Optional.
-
#youtube_kids_restricted ⇒ ::Boolean
Optional.
Instance Attribute Details
#allow_overbook ⇒ ::Boolean
Returns Input only. The flag indicates whether overbooking should be allowed when creating or updating reservations of line item types SPONSORSHIP and STANDARD. When true, operations on this line item will never trigger a ForecastError, which corresponds to an overbook warning in the UI. The default value is false. Note: this field won't persist on the line item itself, and the value will only affect the current request.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#allowed_formats ⇒ ::Array<::Google::Ads::AdManager::V1::LineItemAllowedFormatEnum::LineItemAllowedFormat>
Returns Optional. The set of allowed formats for this line item. If empty, all formats are allowed. This property only applies to programmatic video line items.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#applied_labels ⇒ ::Array<::Google::Ads::AdManager::V1::AppliedLabel>
Returns Optional. The set of labels applied directly to this line item.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#archived ⇒ ::Boolean (readonly)
Returns Output only. The archival status of the LineItem.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#auto_extension_days ⇒ ::Integer
Returns Optional. The number of days to allow a line item to deliver past its target_end_time. A maximum of 7 days is allowed. This is feature is only available for Ad Manager 360 accounts.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#budget ⇒ ::Google::Type::Money (readonly)
Returns Output only. The amount of money allocated to the LineItem. This attribute is readonly and is populated by Google. The currency code is readonly.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#child_content_eligibility ⇒ ::Google::Ads::AdManager::V1::ChildContentEligibilityEnum::ChildContentEligibility
Returns Optional. Non-empty default. Child content eligibility designation for this line item. This field defaults to DISALLOWED.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#companion_delivery_option ⇒ ::Google::Ads::AdManager::V1::CompanionDeliveryOptionEnum::CompanionDeliveryOption
Returns Optional. The delivery option for companions. Setting this field is only meaningful if the following conditions are met:
- The "Guaranteed roadblocks" feature is enabled on your network.
- One of the following is true (both cannot be true, these are mutually
exclusive).
- The environmentType is VIDEO_PLAYER.
- The roadblockingType is CREATIVE_SET. This field defaults to OPTIONAL if the conditions are met. In all other cases it defaults to UNKNOWN and is not meaningful.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#competitive_constraint_scope ⇒ ::Google::Ads::AdManager::V1::ExclusionScopeEnum::ExclusionScope
Returns Optional. Non-empty default. The CompetitiveConstraintScope for the competitive exclusion labels assigned to this line item. This field defaults to POD.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#contracted_units_bought ⇒ ::Integer
Returns Optional. This attribute is only applicable for certain line item types and acts as an "FYI" or note, which does not impact adserving or other backend systems. For SPONSORSHIP line items, this represents the minimum quantity, which is a lifetime impression volume goal for reporting purposes only. For STANDARD line items, this represent the contracted quantity, which is the number of units specified in the contract the advertiser has bought for this LineItem. This field is just a "FYI" for traffickers to manually intervene with the LineItem when needed. This attribute is only available for STANDARD line items if you have this feature enabled on your network.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cost_type ⇒ ::Google::Ads::AdManager::V1::LineItemCostTypeEnum::LineItemCostType
Returns Required. The method used for billing this LineItem.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time this line item was created.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#creative_placeholders ⇒ ::Array<::Google::Ads::AdManager::V1::CreativePlaceholder>
Returns Required. Details about the creatives that are expected to serve through this LineItem.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#creative_rotation_type ⇒ ::Google::Ads::AdManager::V1::CreativeRotationTypeEnum::CreativeRotationType
Returns Required. The strategy used for displaying multiple Creative objects that are associated with the LineItem.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#creative_targetings ⇒ ::Array<::Google::Ads::AdManager::V1::CreativeTargeting>
Returns Optional. A list of CreativeTargeting objects that can be used to specify creative level targeting for this line item. Creative level targeting is specified in a CreativePlaceholder.creative_targeting_display_name field by referencing the [CreativeTargeting.display_name][] field. It also needs to be re-specified in the [LineItemCreativeAssociation.targeting_display_name][] field when associating a line item with a creative that fits into that placeholder.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#custom_field_values ⇒ ::Array<::Google::Ads::AdManager::V1::CustomFieldValue>
Returns Optional. The values of the custom fields associated with this line item.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#custom_pacing_curve ⇒ ::Google::Ads::AdManager::V1::CustomPacingCurve
Returns Optional. The curve that is used to pace the line item's delivery. This field is required if and only if the delivery forecast source is CUSTOM_PACING_CURVE.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#custom_vast_extension ⇒ ::String
Returns Optional. Custom XML to be rendered in a custom VAST response at serving time.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#deal_info ⇒ ::Google::Ads::AdManager::V1::LineItemDealInfo
Returns Optional. The deal information associated with this line item, if it is programmatic.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#delivery_forecast_source ⇒ ::Google::Ads::AdManager::V1::LineItemDeliveryForecastSourceEnum::LineItemDeliveryForecastSource
Returns Optional. Non-empty default. Strategy for choosing forecasted traffic shapes to pace line items. This field defaults to HISTORICAL.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#delivery_indicator ⇒ ::Google::Ads::AdManager::V1::DeliveryIndicator (readonly)
Returns Output only. Indicates how well the line item has been performing. This will be empty if the delivery indicator information is not available due to one of the following reasons:
- The line item is not delivering.
- The line item has an unlimited goal or cap.
- The line item has a percentage based goal or cap.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#delivery_rate_type ⇒ ::Google::Ads::AdManager::V1::LineItemDeliveryRateTypeEnum::LineItemDeliveryRateType
Returns Optional. Non-empty default. The strategy for delivering ads over the course of the line item's duration. This attribute defaults to EVENLY or FRONTLOADED depending on the network's configuration.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#discount ⇒ ::Google::Ads::AdManager::V1::LineItemDiscount
Returns Optional. Discount information for the line item.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Required. The name of the line item. This attribute has a maximum length of 255 characters.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#effective_applied_labels ⇒ ::Array<::Google::Ads::AdManager::V1::AppliedLabel> (readonly)
Returns Output only. Contains the set of labels inherited from the order that contains this line item and the advertiser that owns the order. If a label has been negated, only the negated label is returned.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#end_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp when the LineItem will stop serving. This attribute includes auto extension days.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#end_time_unlimited ⇒ ::Boolean
Returns Optional. Non-empty default. Specifies whether or not the LineItem has an end time. This attribute defaults to false. It can be be set to true for only line items of type SPONSORSHIP, NETWORK, PRICE_PRIORITY and HOUSE.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#environment_type ⇒ ::Google::Ads::AdManager::V1::EnvironmentTypeEnum::EnvironmentType
Returns Optional. Non-empty default. The environment that the LineItem is targeting. The default value is BROWSER. If this value is VIDEO_PLAYER, then this line item can only target AdUnits that have AdUnitSizes whose environmentType is also VIDEO_PLAYER.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#external_line_item_id ⇒ ::String
Returns Optional. An identifier for the LineItem that is meaningful to the publisher. This attribute has a maximum length of 255 characters.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#frequency_caps ⇒ ::Array<::Google::Ads::AdManager::V1::FrequencyCap>
Returns Optional. The set of frequency capping units for this LineItem.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#goal ⇒ ::Google::Ads::AdManager::V1::Goal
Returns Optional. The primary goal that this LineItem is associated with, which is used in its pacing and budgeting.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#grp_settings ⇒ ::Google::Ads::AdManager::V1::GrpSettings
Returns Optional. Contains the information for a line item which has a target GRP demographic.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#line_item_type ⇒ ::Google::Ads::AdManager::V1::LineItemTypeEnum::LineItemType
Returns Required. Indicates the line item type of a LineItem. The line item type determines the default priority of the line item. More information can be found at https://support.google.com/admanager/answer/177279.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_video_creative_duration ⇒ ::Google::Protobuf::Duration
Returns Optional. The max duration of a video creative associated with this LineItem. This attribute is only meaningful for video line items. This attribute is required for video line items and must be greater than 0.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#missing_creatives ⇒ ::Boolean (readonly)
Returns Output only. Indicates if a LineItem is missing any Creative creatives for the creativePlaceholders specified. Creative Creatives can be considered missing for several reasons including:
- Not enough Creative creatives of a certain size have been uploaded, as determined by expected_creative_count. For example a LineItem specifies 750x350, 400x200 but only a 750x350 was uploaded. Or LineItem specifies 750x350 with an expected count of 2, but only one was uploaded.
- The [Creative.applied_labels][] of an associated Creative don't match the CreativePlaceholder.applied_labels of the LineItem. For example LineItem specifies 750x350 with a Foo AppliedLabel but a 750x350 creative without a AppliedLabel was uploaded.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The resource name of the LineItem.
Format: networks/{network_code}/lineItems/{line_item_id}.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#notes ⇒ ::String
Returns Optional. Provides any additional notes that may annotate the LineItem. This attribute has a maximum length of 65,535 characters.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order ⇒ ::String
Returns Required. Immutable. The ID of the Order to which the LineItem belongs.
Format: networks/{network_code}/orders/{order}.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_display_name ⇒ ::String (readonly)
Returns Output only. The name of the Order.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#priority ⇒ ::Integer
Returns Optional. Non-empty default. The priority for the line item. Valid values range from 1 to 16. This field defaults to the default priority of the LineItemType. The following list shows the default, minimum, and maximum priority values are for each line item type:
- LineItemType: default priority (minimum priority, maximum priority)
- SPONSORSHIP: 4 (2, 5)
- STANDARD: 8 (6, 10)
- NETWORK: 12 (11, 14)
- BULK: 12 (11, 14)
- PRICE_PRIORITY: 12 (11, 14)
- HOUSE: 16 (15, 16)
- CLICK_TRACKING: 16 (1, 16)
- AD_EXCHANGE: 12 (1, 16)
- ADSENSE: 12 (1, 16)
- BUMPER: 16 (15, 16)
- ADMOB: 21 (1, 16)
- PREFERRED_DEAL: 12 (12, 12) This field can only be edited by certain networks, otherwise a PermissionError will occur.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rate ⇒ ::Google::Type::Money
Returns Required. The amount of money to spend per impression or click.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#repeated_creative_serving_enabled ⇒ ::Boolean
Returns Optional. Indicates whether repeated creative serving is enabled for this line item.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#reservation_status ⇒ ::Google::Ads::AdManager::V1::LineItemReservationStatusEnum::LineItemReservationStatus (readonly)
Returns Output only. Describes whether or not inventory has been reserved for the LineItem.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#reserve_on_creation ⇒ ::Boolean
Returns Input only. The flag indicates whether inventory should be reserved when creating a line item of types SPONSORSHIP and STANDARD in an unapproved Order. The default value is false.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#roadblocking_type ⇒ ::Google::Ads::AdManager::V1::RoadblockingTypeEnum::RoadblockingType
Returns Optional. Non-empty default. The strategy for serving roadblocked creatives, that is, instances where multiple creatives must be served together on a single web page. This attribute defaults to ONE_OR_MORE.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#same_advertiser_exception_enabled ⇒ ::Boolean
Returns Optional. If a line item has a series of competitive exclusions on it, it could be blocked from serving with line items from the same advertiser. Setting this to true will allow line items from the same advertiser to serve regardless of the other competitive exclusion labels being applied.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#secondary_goals ⇒ ::Array<::Google::Ads::AdManager::V1::Goal>
Returns Optional. The secondary goals that this LineItem is associated with. This is required and meaningful only if the line_item_type is SPONSORSHIP and cost_type is CPM.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#skip_cross_selling_rule_warning_checks ⇒ ::Boolean
Returns Input only. True to skip checks for warnings from rules applied to line items targeting inventory shared by a distributor partner for cross selling when performing an action on this line item. The default is false. Note: this field won't persist on the line item itself, and the value will only affect the current request.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#skip_inventory_check ⇒ ::Boolean
Returns Input only. The flag indicates whether the inventory check should be skipped when creating or updating a line item. The default value is false. Note: this field won't persist on the line item itself, and the value will only affect the current request.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#skippable_ad_type ⇒ ::Google::Ads::AdManager::V1::SkippableAdTypeEnum::SkippableAdType
Returns Optional. Non-empty default. The nature of the line item's creatives' skippability. This attribute is only applicable for video line items, and defaults to NOT_SKIPPABLE.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sponsorship_exclusivity_enabled ⇒ ::Boolean
Returns Optional. Whether the line item is enabled for sponsorship exclusivity. If true, only exclusive sponsorships can be served on inventory targeted by this LineItem. This control should only be available for 100% video sponsorships.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_time ⇒ ::Google::Protobuf::Timestamp
Returns Required. The date and time on which the LineItem is enabled to begin serving. This attribute is required and must be in the future.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#stats ⇒ ::Google::Ads::AdManager::V1::LineItemStats (readonly)
Returns Output only. Contains trafficking statistics for the line item. This will be empty in case there are no statistics for a line item yet.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#status ⇒ ::Google::Ads::AdManager::V1::LineItemComputedStatusEnum::LineItemComputedStatus (readonly)
Returns Output only. The status of the LineItem.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#target_end_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. The target end time of the line item. This attribute is required unless end_time_unlimited is set to true. If specified, it must be after the start_time. This does not include auto extension days.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#targeting ⇒ ::Google::Ads::AdManager::V1::Targeting
Returns Required. Contains the targeting criteria for the ad campaign.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#third_party_measurement_settings ⇒ ::Google::Ads::AdManager::V1::ThirdPartyMeasurementSettings
Returns Optional. Third party auto-pixeling settings for cross-sell Partners.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_source ⇒ ::String (readonly)
Returns Output only. The application that last modified this line item.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time this line item was last modified.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#value_cpm ⇒ ::Google::Type::Money
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#viewability_provider_companies ⇒ ::Array<::String>
Returns Optional. Optional IDs of the Company that provide ad verification for this line item.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#web_property_code ⇒ ::String
Returns Optional. The web property code used for dynamic allocation line items. This web property is only required with line item types AD_EXCHANGE and ADSENSE.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#youtube_kids_restricted ⇒ ::Boolean
Returns Optional. Designates this line item as intended for YT Kids app. If true, all creatives associated with this line item must be reviewed and approved. See the help center article for more information: https://support.google.com/yt-partner-sales/answer/10015534.
360 361 362 363 |
# File 'proto_docs/google/ads/admanager/v1/line_item_messages.rb', line 360 class LineItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |