Module: Google::Ads::AdManager::V1::LineItemComputedStatusEnum::LineItemComputedStatus
- Defined in:
- proto_docs/google/ads/admanager/v1/line_item_enums.rb
Overview
Describes the computed LineItem status that is derived from the current state of the LineItem.
Constant Summary collapse
- LINE_ITEM_COMPUTED_STATUS_UNSPECIFIED =
No value specified.
0- CANCELED =
The LineItem has been canceled and is no longer eligible to serve. This is a legacy status.
1- COMPLETED =
The LineItem has completed its run.
2- DELIVERING =
The LineItem has begun serving.
3- DELIVERY_EXTENDED =
The LineItem has past its endDateTime with an auto extension, but hasn't met its goal.
4- DISAPPROVED =
The LineItem has been disapproved and is not eligible to serve.
5- DRAFT =
The LineItem is still being drafted.
6- INACTIVE =
The LineItem is inactive. It is either caused by missing creatives or the network disabling auto-activation.
7- PAUSED =
The LineItem has been paused from serving.
8- PAUSED_INVENTORY_RELEASED =
The LineItem has been paused and its reserved inventory has been released. The LineItem will not serve.
9- PENDING_APPROVAL =
The LineItem has been submitted for approval.
10- READY =
The LineItem has been activated and is ready to serve.
11