Module: Google::Ads::AdManager::V1::LineItemReservationStatusEnum::LineItemReservationStatus
- Defined in:
- proto_docs/google/ads/admanager/v1/line_item_enums.rb
Overview
Defines the different reservation statuses of a line item.
Constant Summary collapse
- LINE_ITEM_RESERVATION_STATUS_UNSPECIFIED =
No value specified
0- RESERVED =
Indicates that inventory has been reserved for the line item.
1- UNRESERVED =
Indicates that inventory has not been reserved for the line item.
2