Module: Google::Ads::AdManager::V1::LinkedDeviceVisibilityEnum::LinkedDeviceVisibility
- Defined in:
- proto_docs/google/ads/admanager/v1/linked_device_enums.rb
Overview
Represents the visibility of a LinkedDevice.
Constant Summary collapse
- LINKED_DEVICE_VISIBILITY_UNSPECIFIED =
Default value. This value is unused.
0- PRIVATE =
The linked device can only be used by the user who owns the device linking.
2- PUBLIC =
The linked device can be used by anyone on the network.
3