Class: Google::Ads::AdManager::V1::ListSlatesResponse
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::ListSlatesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/slate_service.rb
Overview
Response message for ListSlates method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token that can be sent as
page_tokento retrieve the next page. -
#slates ⇒ ::Array<::Google::Ads::AdManager::V1::Slate>
The
Slateobjects from the specified network. -
#total_size ⇒ ::Integer
Total number of
Slateobjects.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
90 91 92 93 |
# File 'proto_docs/google/ads/admanager/v1/slate_service.rb', line 90 class ListSlatesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#slates ⇒ ::Array<::Google::Ads::AdManager::V1::Slate>
Returns The Slate objects from the specified network.
90 91 92 93 |
# File 'proto_docs/google/ads/admanager/v1/slate_service.rb', line 90 class ListSlatesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_size ⇒ ::Integer
Returns Total number of Slate objects.
If a filter was included in the request, this reflects the total number
after filtering.
total_size will not be returned if skip is nonzero.
90 91 92 93 |
# File 'proto_docs/google/ads/admanager/v1/slate_service.rb', line 90 class ListSlatesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |