Class: Google::Ads::AdManager::V1::LiveStream
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::LiveStream
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/live_stream_messages.rb
Overview
A LiveStream encapsulates all the information necessary to enable DAI (Dynamic Ad Insertion) into a live video stream. This includes information such as the start and expected end time of the live stream, the URL of the actual content for Ad Manager to pull and insert ads into, as well as the metadata necessary to generate ad requests during the live stream.
Instance Attribute Summary collapse
-
#ad_break_fill_type ⇒ ::Google::Ads::AdManager::V1::AdBreakFillTypeEnum::AdBreakFillType
Optional.
-
#ad_break_markup_types_enabled ⇒ ::Boolean
Optional.
-
#ad_break_markups ⇒ ::Array<::Google::Ads::AdManager::V1::AdBreakMarkupTypeEnum::AdBreakMarkupType>
Optional.
-
#ad_holiday_duration ⇒ ::Google::Protobuf::Duration
Optional.
-
#ad_media_delivery_config ⇒ ::String
Optional.
-
#ad_pod_trim_tolerance ⇒ ::Google::Protobuf::Duration
Optional.
-
#ad_tags ⇒ ::Array<::String>
Required.
-
#allowlisted_ips_enabled ⇒ ::Boolean
Optional.
-
#asset_key ⇒ ::String
readonly
Output only.
-
#auxiliary_ad_settings ⇒ ::Google::Ads::AdManager::V1::AuxiliaryAdSettings
Optional.
-
#content_urls ⇒ ::Array<::String>
Required.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#custom_asset_key ⇒ ::String
Immutable.
-
#default_ad_break_duration ⇒ ::Google::Protobuf::Duration
Optional.
-
#display_name ⇒ ::String
Required.
-
#dynamic_ad_insertion_type ⇒ ::Google::Ads::AdManager::V1::DynamicAdInsertionTypeEnum::DynamicAdInsertionType
Immutable.
-
#early_break_notification_multi_break_scheduling_enabled ⇒ ::Boolean
Optional.
-
#effective_asset_key ⇒ ::String
readonly
Output only.
-
#enable_dai_authentication_keys ⇒ ::Boolean
Optional.
-
#enable_durationless_ad_breaks ⇒ ::Boolean
Optional.
-
#enable_max_filler_duration ⇒ ::Boolean
Optional.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#end_time_unlimited ⇒ ::Boolean
Optional.
-
#forced_cue_in_enabled ⇒ ::Boolean
Optional.
-
#hls_settings ⇒ ::Google::Ads::AdManager::V1::HlsSettings
Optional.
-
#live_stream_conditioning ⇒ ::Google::Ads::AdManager::V1::LiveStreamConditioning
Optional.
-
#max_filler_duration ⇒ ::Google::Protobuf::Duration
Optional.
-
#name ⇒ ::String
Identifier.
-
#pod_serving_segment_duration ⇒ ::Google::Protobuf::Duration
Optional.
-
#prefetch_enabled ⇒ ::Boolean
Optional.
-
#prefetch_settings ⇒ ::Google::Ads::AdManager::V1::PrefetchSettings
Optional.
-
#preroll_settings ⇒ ::Google::Ads::AdManager::V1::PrerollSettings
Optional.
-
#relative_playlist_delivery_enabled ⇒ ::Boolean
Optional.
-
#short_segment_dropping_enabled ⇒ ::Boolean
Optional.
-
#source_content_configurations ⇒ ::Array<::String>
Optional.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#status ⇒ ::Google::Ads::AdManager::V1::LiveStreamEventStatusEnum::LiveStreamEventStatus
readonly
Output only.
-
#streaming_format ⇒ ::Google::Ads::AdManager::V1::LiveStreamEventStreamingFormatEnum::LiveStreamEventStreamingFormat
Immutable.
-
#underfill_ad_break_fill_type ⇒ ::Google::Ads::AdManager::V1::AdBreakFillTypeEnum::AdBreakFillType
Optional.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#ad_break_fill_type ⇒ ::Google::Ads::AdManager::V1::AdBreakFillTypeEnum::AdBreakFillType
Returns Optional. The type of content that should be used to fill an empty ad break. Defaults to SLATE.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ad_break_markup_types_enabled ⇒ ::Boolean
Returns Optional. Whether this LiveStream is specifying a subset of supported
adBreakMarkups. If this field is false, all supported formats will be
treated as ad break start/end markers.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ad_break_markups ⇒ ::Array<::Google::Ads::AdManager::V1::AdBreakMarkupTypeEnum::AdBreakMarkupType>
Returns Optional. The formats that will be recognized as ad break start/end
markers. This field is ignored if adBreakMarkupTypesEnabled is false.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ad_holiday_duration ⇒ ::Google::Protobuf::Duration
Returns Optional. The duration, starting from the time the user enters the DAI stream, for which mid-roll decisioning will be skipped. This field is only applicable when an ad holiday is requested in the stream create request. Defaults to 0.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ad_media_delivery_config ⇒ ::String
Returns Optional. The CdnConfiguration that provide settings for delivering ad media associated with this source. Format: "networks/{network_code}/cdnConfigs/{cdn_config_id}".
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ad_pod_trim_tolerance ⇒ ::Google::Protobuf::Duration
Returns Optional. The maximum amount of time by which a stitched ad pod is allowed to be trimmed before whole ads are dropped instead.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ad_tags ⇒ ::Array<::String>
Returns Required. The list of Ad Manager ad tag URLs generated by the Ad Manager trafficking workflow that are associated with this live stream. Currently, the list includes only one element: the master ad tag.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#allowlisted_ips_enabled ⇒ ::Boolean
Returns Optional. Whether specific allowlisted IP addresses should be used to access this live stream. Will default to false. To set this field a network needs to have the "Video live allowlisted IPS enabled" feature enabled. Modifying this field for an active live stream can impact traffic.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#asset_key ⇒ ::String (readonly)
Returns Output only. The code used in constructing a live stream master playlist URL.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#auxiliary_ad_settings ⇒ ::Google::Ads::AdManager::V1::AuxiliaryAdSettings
Returns Optional. The auxiliary ad tag settings for this live stream.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#content_urls ⇒ ::Array<::String>
Returns Required. The list of URLs pointing to the live stream content in Content Delivery Network. Can be modified when the live stream is in a PAUSED state.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The date and time this LiveStream was created.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#custom_asset_key ⇒ ::String
Returns Immutable. An additional code that can be used in constructing live stream event URLs. Can only be set for pod serving live streams. The custom asset key may be at most 64 characters and can contain alphanumeric characters and symbols other than the following: ", ', =, !, +, #, *, ~, ;, ^, (, ), <, >, [, ], the white space character.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#default_ad_break_duration ⇒ ::Google::Protobuf::Duration
Returns Optional. The default ad pod duration that will be requested when an ad break cue-out does not specify a duration. Defaults to 0.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Required. The name of the LiveStream. This value has a maximum length of 255 characters.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#dynamic_ad_insertion_type ⇒ ::Google::Ads::AdManager::V1::DynamicAdInsertionTypeEnum::DynamicAdInsertionType
Returns Immutable. The method of dynamic ad insertion that is used to insert ads into this live stream. Defaults to DynamicAdInsertionType.LINEAR.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#early_break_notification_multi_break_scheduling_enabled ⇒ ::Boolean
Returns Optional. Indicates whether multi-break scheduling via Early Break Notification (EBN) is enabled for this LiveStream.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#effective_asset_key ⇒ ::String (readonly)
Returns Output only. The effective asset key of the live stream. This is the user-defined custom_asset_key if specified; otherwise, it falls back to the autogenerated asset_key.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#enable_dai_authentication_keys ⇒ ::Boolean
Returns Optional. Whether the live stream's requests to the IMA SDK API will be authenticated using the DAI authentication keys.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#enable_durationless_ad_breaks ⇒ ::Boolean
Returns Optional. Whether there will be durationless ad breaks in this live stream.
If true, defaultAdBreakDuration should be specified. Defaults to false.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#enable_max_filler_duration ⇒ ::Boolean
Returns Optional. Whether there will be max filler duration in this live stream. If true, maxFillerDuration should be specified. Defaults to false.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#end_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. The scheduled end date and time of this LiveStream. This
attribute is required if unlimitedEndDateTime is false and ignored if
unlimitedEndDateTime is true. Modifying this attribute for an active live
stream can impact traffic.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#end_time_unlimited ⇒ ::Boolean
Returns Optional. Whether the LiveStream has an end time. Defaults to false. If
this field is true, endDateTime is ignored.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#forced_cue_in_enabled ⇒ ::Boolean
Returns Optional. Whether live stream placement opportunities without #EXT-CUE-IN
markers should be force closed. Defaults to false. To set this field a
network needs to have the "Video live stream forced cue in" feature
enabled.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#hls_settings ⇒ ::Google::Ads::AdManager::V1::HlsSettings
Returns Optional. The settings that are specific to HTTPS live streaming (HLS) protocol. If it is not set will use the default HLS settings.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#live_stream_conditioning ⇒ ::Google::Ads::AdManager::V1::LiveStreamConditioning
Returns Optional. The conditioning to apply to this LiveStream.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_filler_duration ⇒ ::Google::Protobuf::Duration
Returns Optional. The maximum duration that can be used to fill this ad pod, either with a slate or underlying content, depending on your settings. If more time needs to be filled, the ad pod will instead be dropped and the underlying content will be served.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The resource name of the LiveStream.
Format: networks/{network_code}/liveStreams/{live_stream_id}.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pod_serving_segment_duration ⇒ ::Google::Protobuf::Duration
Returns Optional. The duration that can be used when stitching ads for each livestream event. This attribute is only available for Pod Serving HLS Segment Redirect and Pod Serving Dash Segment Redirect.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#prefetch_enabled ⇒ ::Boolean
Returns Optional. Indicates whether the option to prefetch ad requests is enabled.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#prefetch_settings ⇒ ::Google::Ads::AdManager::V1::PrefetchSettings
Returns Optional. The information needed to prefetch ad requests for an ad break.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#preroll_settings ⇒ ::Google::Ads::AdManager::V1::PrerollSettings
Returns Optional. The settings specific to Preroll ad breaks. If null, this livestream does not have prerolls enabled.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#relative_playlist_delivery_enabled ⇒ ::Boolean
Returns Optional. Whether the served playlists can include relative URLs. Defaults to false. To set this field a network needs to have the "Video live stream relative playlist URLs" feature enabled. This field can be modified when the live stream is in a LiveStreamEventStatus#PAUSED state.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#short_segment_dropping_enabled ⇒ ::Boolean
Returns Optional. Whether segments shorter than 1 second at the end of an ad pod should be dropped. Defaults to false. To set this field a network needs to have the "Video live stream short segment dropping" feature enabled.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source_content_configurations ⇒ ::Array<::String>
Returns Optional. The list of CdnConfigurations that provide settings for ingesting and delivering the videos associated with this source. Modifying settings for an active live stream may break the stream for some users. Exercise caution. Format: "networks/{network_code}/cdnConfigs/{cdn_config_id}".
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. The start date and time of this LiveStream. Modifying this attribute for an active live stream can impact traffic.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#status ⇒ ::Google::Ads::AdManager::V1::LiveStreamEventStatusEnum::LiveStreamEventStatus (readonly)
Returns Output only. The status of this LiveStream. Live stream events are created in the PAUSED state.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#streaming_format ⇒ ::Google::Ads::AdManager::V1::LiveStreamEventStreamingFormatEnum::LiveStreamEventStreamingFormat
Returns Immutable. The streaming format of the LiveStream media.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#underfill_ad_break_fill_type ⇒ ::Google::Ads::AdManager::V1::AdBreakFillTypeEnum::AdBreakFillType
Returns Optional. The type of content that should be used to fill the time remaining in the ad break when there are not enough ads to fill the entire break. Defaults to SLATE. To set this field a network needs to have the "Live stream ad break underfill type" feature enabled.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The date and time this LiveStream was last modified.
215 216 217 218 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 215 class LiveStream include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |