Module: Google::Ads::AdManager::V1::LiveStreamEventStatusEnum::LiveStreamEventStatus
- Defined in:
- proto_docs/google/ads/admanager/v1/live_stream_event_enums.rb
Overview
Describes the status of a LiveStreamEvent object.
Constant Summary collapse
- LIVE_STREAM_EVENT_STATUS_UNSPECIFIED =
Default value. This value is unused.
0- ACTIVE =
Indicates the LiveStreamEvent has been created and is eligible for streaming.
1- ADS_PAUSED =
Indicates that the stream is still being served, but ad insertion should be paused temporarily.
2- ARCHIVED =
Indicates the LiveStreamEvent has been archived.
3- PAUSED =
Indicates the LiveStreamEvent has been paused. This can be made #ACTIVE at later time.
4