Class: Google::Ads::AdManager::V1::LiveStreamService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::LiveStreamService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/ads/ad_manager/v1/live_stream_service/rest/client.rb
Overview
REST client for the LiveStreamService service.
Provides methods for handling LiveStream objects.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the LiveStreamService Client class.
Instance Method Summary collapse
-
#batch_activate_live_streams(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::BatchActivateLiveStreamsResponse
Batch activates
LiveStreamobjects. -
#batch_archive_live_streams(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::BatchArchiveLiveStreamsResponse
Batch archives
LiveStreamobjects. -
#batch_create_live_streams(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::BatchCreateLiveStreamsResponse
Batch creates
LiveStreamobjects. -
#batch_pause_ads_live_streams(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::BatchPauseAdsLiveStreamsResponse
Batch pauses ads on
LiveStreamobjects. -
#batch_pause_live_streams(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::BatchPauseLiveStreamsResponse
Batch pauses
LiveStreamobjects. -
#batch_refresh_master_playlists(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::BatchRefreshMasterPlaylistsResponse
Batch refreshes master playlists on
LiveStreamobjects. -
#batch_update_live_streams(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::BatchUpdateLiveStreamsResponse
Batch updates
LiveStreamobjects. -
#configure {|config| ... } ⇒ Client::Configuration
Configure the LiveStreamService Client instance.
-
#create_live_stream(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::LiveStream
Creates a
LiveStreamobject. -
#get_live_stream(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::LiveStream
Retrieves a
LiveStreamobject. -
#initialize {|config| ... } ⇒ Client
constructor
Create a new LiveStreamService REST client object.
-
#list_live_streams(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::LiveStream>
Lists
LiveStreamobjects. -
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_live_stream(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::AdManager::V1::LiveStream
Updates a
LiveStreamobject.
Methods included from Paths
#cdn_config_path, #live_stream_path, #network_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new LiveStreamService REST client object.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/google/ads/ad_manager/v1/live_stream_service/rest/client.rb', line 126 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @live_stream_service_stub = ::Google::Ads::AdManager::V1::LiveStreamService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @live_stream_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the LiveStreamService Client class.
See Configuration for a description of the configuration fields.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/google/ads/ad_manager/v1/live_stream_service/rest/client.rb', line 64 def self.configure @configure ||= begin namespace = ["Google", "Ads", "AdManager", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config end yield @configure if block_given? @configure end |
Instance Method Details
#batch_activate_live_streams(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchActivateLiveStreamsResponse #batch_activate_live_streams(parent: nil, names: nil) ⇒ ::Google::Ads::AdManager::V1::BatchActivateLiveStreamsResponse
Batch activates LiveStream objects.
757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 |
# File 'lib/google/ads/ad_manager/v1/live_stream_service/rest/client.rb', line 757 def batch_activate_live_streams request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchActivateLiveStreamsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_activate_live_streams..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.batch_activate_live_streams.timeout, metadata: , retry_policy: @config.rpcs.batch_activate_live_streams.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @live_stream_service_stub.batch_activate_live_streams request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#batch_archive_live_streams(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchArchiveLiveStreamsResponse #batch_archive_live_streams(parent: nil, names: nil) ⇒ ::Google::Ads::AdManager::V1::BatchArchiveLiveStreamsResponse
Batch archives LiveStream objects.
919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 |
# File 'lib/google/ads/ad_manager/v1/live_stream_service/rest/client.rb', line 919 def batch_archive_live_streams request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchArchiveLiveStreamsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_archive_live_streams..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.batch_archive_live_streams.timeout, metadata: , retry_policy: @config.rpcs.batch_archive_live_streams.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @live_stream_service_stub.batch_archive_live_streams request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#batch_create_live_streams(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchCreateLiveStreamsResponse #batch_create_live_streams(parent: nil, requests: nil) ⇒ ::Google::Ads::AdManager::V1::BatchCreateLiveStreamsResponse
Batch creates LiveStream objects.
510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 |
# File 'lib/google/ads/ad_manager/v1/live_stream_service/rest/client.rb', line 510 def batch_create_live_streams request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchCreateLiveStreamsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_create_live_streams..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.batch_create_live_streams.timeout, metadata: , retry_policy: @config.rpcs.batch_create_live_streams.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @live_stream_service_stub.batch_create_live_streams request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#batch_pause_ads_live_streams(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchPauseAdsLiveStreamsResponse #batch_pause_ads_live_streams(parent: nil, names: nil) ⇒ ::Google::Ads::AdManager::V1::BatchPauseAdsLiveStreamsResponse
Batch pauses ads on LiveStream objects.
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/google/ads/ad_manager/v1/live_stream_service/rest/client.rb', line 1000 def batch_pause_ads_live_streams request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchPauseAdsLiveStreamsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_pause_ads_live_streams..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.batch_pause_ads_live_streams.timeout, metadata: , retry_policy: @config.rpcs.batch_pause_ads_live_streams.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @live_stream_service_stub.batch_pause_ads_live_streams request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#batch_pause_live_streams(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchPauseLiveStreamsResponse #batch_pause_live_streams(parent: nil, names: nil) ⇒ ::Google::Ads::AdManager::V1::BatchPauseLiveStreamsResponse
Batch pauses LiveStream objects.
838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 |
# File 'lib/google/ads/ad_manager/v1/live_stream_service/rest/client.rb', line 838 def batch_pause_live_streams request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchPauseLiveStreamsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_pause_live_streams..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.batch_pause_live_streams.timeout, metadata: , retry_policy: @config.rpcs.batch_pause_live_streams.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @live_stream_service_stub.batch_pause_live_streams request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#batch_refresh_master_playlists(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchRefreshMasterPlaylistsResponse #batch_refresh_master_playlists(parent: nil, names: nil) ⇒ ::Google::Ads::AdManager::V1::BatchRefreshMasterPlaylistsResponse
Batch refreshes master playlists on LiveStream objects.
1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 |
# File 'lib/google/ads/ad_manager/v1/live_stream_service/rest/client.rb', line 1082 def batch_refresh_master_playlists request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchRefreshMasterPlaylistsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_refresh_master_playlists..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.batch_refresh_master_playlists.timeout, metadata: , retry_policy: @config.rpcs.batch_refresh_master_playlists.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @live_stream_service_stub.batch_refresh_master_playlists request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#batch_update_live_streams(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::BatchUpdateLiveStreamsResponse #batch_update_live_streams(parent: nil, requests: nil) ⇒ ::Google::Ads::AdManager::V1::BatchUpdateLiveStreamsResponse
Batch updates LiveStream objects.
676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 |
# File 'lib/google/ads/ad_manager/v1/live_stream_service/rest/client.rb', line 676 def batch_update_live_streams request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::BatchUpdateLiveStreamsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_update_live_streams..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.batch_update_live_streams.timeout, metadata: , retry_policy: @config.rpcs.batch_update_live_streams.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @live_stream_service_stub.batch_update_live_streams request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the LiveStreamService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
96 97 98 99 |
# File 'lib/google/ads/ad_manager/v1/live_stream_service/rest/client.rb', line 96 def configure yield @config if block_given? @config end |
#create_live_stream(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::LiveStream #create_live_stream(parent: nil, live_stream: nil) ⇒ ::Google::Ads::AdManager::V1::LiveStream
Creates a LiveStream object.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/google/ads/ad_manager/v1/live_stream_service/rest/client.rb', line 426 def create_live_stream request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::CreateLiveStreamRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_live_stream..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_live_stream.timeout, metadata: , retry_policy: @config.rpcs.create_live_stream.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @live_stream_service_stub.create_live_stream request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_live_stream(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::LiveStream #get_live_stream(name: nil) ⇒ ::Google::Ads::AdManager::V1::LiveStream
Retrieves a LiveStream object.
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/google/ads/ad_manager/v1/live_stream_service/rest/client.rb', line 223 def get_live_stream request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::GetLiveStreamRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_live_stream..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_live_stream.timeout, metadata: , retry_policy: @config.rpcs.get_live_stream.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @live_stream_service_stub.get_live_stream request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_live_streams(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::LiveStream> #list_live_streams(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil, skip: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::AdManager::V1::LiveStream>
Lists LiveStream objects.
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/google/ads/ad_manager/v1/live_stream_service/rest/client.rb', line 343 def list_live_streams request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::ListLiveStreamsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_live_streams..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_live_streams.timeout, metadata: , retry_policy: @config.rpcs.list_live_streams.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @live_stream_service_stub.list_live_streams request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @live_stream_service_stub, :list_live_streams, "live_streams", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
173 174 175 |
# File 'lib/google/ads/ad_manager/v1/live_stream_service/rest/client.rb', line 173 def logger @live_stream_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
106 107 108 |
# File 'lib/google/ads/ad_manager/v1/live_stream_service/rest/client.rb', line 106 def universe_domain @live_stream_service_stub.universe_domain end |
#update_live_stream(request, options = nil) ⇒ ::Google::Ads::AdManager::V1::LiveStream #update_live_stream(live_stream: nil, update_mask: nil) ⇒ ::Google::Ads::AdManager::V1::LiveStream
Updates a LiveStream object.
592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 |
# File 'lib/google/ads/ad_manager/v1/live_stream_service/rest/client.rb', line 592 def update_live_stream request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::AdManager::V1::UpdateLiveStreamRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_live_stream..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::AdManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_live_stream.timeout, metadata: , retry_policy: @config.rpcs.update_live_stream.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @live_stream_service_stub.update_live_stream request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |