Class: Google::Ads::AdManager::V1::PrefetchSettings
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::PrefetchSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/live_stream_messages.rb
Overview
The information needed to prefetch ad requests for an ad break.
Instance Attribute Summary collapse
Instance Attribute Details
#stage_one_ad_request_duration ⇒ ::Google::Protobuf::Duration
Returns Optional. The duration of the part of the break to be prefetched.
224 225 226 227 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 224 class PrefetchSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |