Class: Google::Ads::AdManager::V1::PrerollSettings
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::PrerollSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/live_stream_messages.rb
Overview
Settings for ad breaks on a livestream that are specific to preroll.
Instance Attribute Summary collapse
-
#ad_tag ⇒ ::String
Required.
-
#max_ad_pod_duration ⇒ ::Google::Protobuf::Duration
Required.
Instance Attribute Details
#ad_tag ⇒ ::String
Returns Required. The Ad Manager ad tag URL generated by the Ad Manager trafficking workflow that is associated with this live stream.
278 279 280 281 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 278 class PrerollSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_ad_pod_duration ⇒ ::Google::Protobuf::Duration
Returns Required. The maximum duration for an ad break.
278 279 280 281 |
# File 'proto_docs/google/ads/admanager/v1/live_stream_messages.rb', line 278 class PrerollSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |