Class: Google::Ads::AdManager::V1::ReportDataTable::MetricValueGroup
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::ReportDataTable::MetricValueGroup
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/report_messages.rb
Overview
Contains all metric values requested for a single date range and set of column dimension values (returned in the columns field of the response). The order of the metrics in each field corresponds to the order of the metrics specified in the request.
Instance Attribute Summary collapse
-
#absolute_change_values ⇒ ::Array<::Google::Ads::AdManager::V1::ReportValue>
Data for the ABSOLUTE_CHANGE MetricValueType.
-
#comparison_percent_of_total_values ⇒ ::Array<::Google::Ads::AdManager::V1::ReportValue>
Data for the COMPARISON_PERCENT_OF_TOTAL MetricValueType.
-
#comparison_values ⇒ ::Array<::Google::Ads::AdManager::V1::ReportValue>
Data for the COMPARISON MetricValueType.
-
#flag_values ⇒ ::Array<::Boolean>
If true, the flag's conditions are met.
-
#primary_percent_of_total_values ⇒ ::Array<::Google::Ads::AdManager::V1::ReportValue>
Data for the PRIMARY_PERCENT_OF_TOTAL MetricValueType.
-
#primary_values ⇒ ::Array<::Google::Ads::AdManager::V1::ReportValue>
Data for the PRIMARY MetricValueType.
-
#relative_change_values ⇒ ::Array<::Google::Ads::AdManager::V1::ReportValue>
Data for the RELATIVE_CHANGE MetricValueType.
Instance Attribute Details
#absolute_change_values ⇒ ::Array<::Google::Ads::AdManager::V1::ReportValue>
133 134 135 136 |
# File 'proto_docs/google/ads/admanager/v1/report_messages.rb', line 133 class MetricValueGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#comparison_percent_of_total_values ⇒ ::Array<::Google::Ads::AdManager::V1::ReportValue>
133 134 135 136 |
# File 'proto_docs/google/ads/admanager/v1/report_messages.rb', line 133 class MetricValueGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#comparison_values ⇒ ::Array<::Google::Ads::AdManager::V1::ReportValue>
133 134 135 136 |
# File 'proto_docs/google/ads/admanager/v1/report_messages.rb', line 133 class MetricValueGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#flag_values ⇒ ::Array<::Boolean>
133 134 135 136 |
# File 'proto_docs/google/ads/admanager/v1/report_messages.rb', line 133 class MetricValueGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#primary_percent_of_total_values ⇒ ::Array<::Google::Ads::AdManager::V1::ReportValue>
133 134 135 136 |
# File 'proto_docs/google/ads/admanager/v1/report_messages.rb', line 133 class MetricValueGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#primary_values ⇒ ::Array<::Google::Ads::AdManager::V1::ReportValue>
133 134 135 136 |
# File 'proto_docs/google/ads/admanager/v1/report_messages.rb', line 133 class MetricValueGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#relative_change_values ⇒ ::Array<::Google::Ads::AdManager::V1::ReportValue>
133 134 135 136 |
# File 'proto_docs/google/ads/admanager/v1/report_messages.rb', line 133 class MetricValueGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |