Class: Google::Ads::AdManager::V1::RequestFormatTargeting
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::RequestFormatTargeting
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/targeting.rb
Overview
Request Format Targeting
This message specifies inclusion or exclusion of various request formats for targeting. Each optional boolean field controls the targeting of a specific request format:
- If set to
true, the corresponding format is included in targeting. - If set to
false, the corresponding format is excluded from targeting. - If unset, the format is neither explicitly included nor excluded.
Instance Attribute Summary collapse
-
#anchor_enabled ⇒ ::Boolean
Optional.
-
#app_open_enabled ⇒ ::Boolean
Optional.
-
#banner_enabled ⇒ ::Boolean
Optional.
-
#instream_audio_enabled ⇒ ::Boolean
Optional.
-
#instream_video_enabled ⇒ ::Boolean
Optional.
-
#interstitial_enabled ⇒ ::Boolean
Optional.
-
#native_advanced_enabled ⇒ ::Boolean
Optional.
-
#rewarded_enabled ⇒ ::Boolean
Optional.
-
#rewarded_interstitial_enabled ⇒ ::Boolean
Optional.
Instance Attribute Details
#anchor_enabled ⇒ ::Boolean
Returns Optional. Controls anchor format targeting. Set to true to include,
false to exclude, or leave unset for neither.
491 492 493 494 |
# File 'proto_docs/google/ads/admanager/v1/targeting.rb', line 491 class RequestFormatTargeting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#app_open_enabled ⇒ ::Boolean
Returns Optional. Controls app open format targeting. Set to true to include,
false to exclude, or leave unset for neither.
491 492 493 494 |
# File 'proto_docs/google/ads/admanager/v1/targeting.rb', line 491 class RequestFormatTargeting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#banner_enabled ⇒ ::Boolean
Returns Optional. Controls banner format targeting. Set to true to include,
false to exclude, or leave unset for neither.
491 492 493 494 |
# File 'proto_docs/google/ads/admanager/v1/targeting.rb', line 491 class RequestFormatTargeting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instream_audio_enabled ⇒ ::Boolean
Returns Optional. Controls instream audio format targeting. Set to true to
include, false to exclude, or leave unset for neither.
491 492 493 494 |
# File 'proto_docs/google/ads/admanager/v1/targeting.rb', line 491 class RequestFormatTargeting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instream_video_enabled ⇒ ::Boolean
Returns Optional. Controls instream video format targeting. Set to true to
include, false to exclude, or leave unset for neither.
491 492 493 494 |
# File 'proto_docs/google/ads/admanager/v1/targeting.rb', line 491 class RequestFormatTargeting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#interstitial_enabled ⇒ ::Boolean
Returns Optional. Controls interstitial format targeting. Set to true to include,
false to exclude, or leave unset for neither.
491 492 493 494 |
# File 'proto_docs/google/ads/admanager/v1/targeting.rb', line 491 class RequestFormatTargeting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#native_advanced_enabled ⇒ ::Boolean
Returns Optional. Controls native advanced format targeting. Set to true to
include, false to exclude, or leave unset for neither.
491 492 493 494 |
# File 'proto_docs/google/ads/admanager/v1/targeting.rb', line 491 class RequestFormatTargeting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rewarded_enabled ⇒ ::Boolean
Returns Optional. Controls rewarded format targeting. Set to true to include,
false to exclude, or leave unset for neither.
491 492 493 494 |
# File 'proto_docs/google/ads/admanager/v1/targeting.rb', line 491 class RequestFormatTargeting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rewarded_interstitial_enabled ⇒ ::Boolean
Returns Optional. Controls rewarded interstitial format targeting. Set to true to
include, false to exclude, or leave unset for neither.
491 492 493 494 |
# File 'proto_docs/google/ads/admanager/v1/targeting.rb', line 491 class RequestFormatTargeting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |