Module: Google::Ads::AdManager::V1::RichMediaAdsCompanyGdprStatusEnum::RichMediaAdsCompanyGdprStatus
- Defined in:
- proto_docs/google/ads/admanager/v1/rich_media_ads_company_enums.rb
Overview
The status of a RichMediaAdsCompany for use in a GdprProtection.
Constant Summary collapse
- RICH_MEDIA_ADS_COMPANY_GDPR_STATUS_UNSPECIFIED =
Default value. This value is unused.
0- COMPLIANCE_UNKNOWN =
The company has not been contacted or responded about GDPR compliance, or otherwise the GDPR compliance is undetermined.
1- COMPLIANT =
The company has been determined as compliant for GDPR.
2- COMPLIANT_AND_DEFAULT =
The company has been determined as compliant, and is part of the default set of companies eligible as a vendor.
3- COMPLIANT_LIGHTWEIGHT_VERIFIED =
The company has been determined to be compliant through certification process.
4- NOT_COMPLIANT =
The company has been determined as non-compliant for GDPR.
5