Class: Google::Ads::AdManager::V1::Slate
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::Slate
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/slate_messages.rb
Overview
A Slate encapsulates all the information necessary to represent a Slate entity, the video creative used by Dynamic Ad Insertion to fill vacant ad slots.
Instance Attribute Summary collapse
-
#display_name ⇒ ::String
Required.
-
#name ⇒ ::String
Identifier.
-
#status ⇒ ::Google::Ads::AdManager::V1::SlateStatusEnum::SlateStatus
readonly
Output only.
-
#transcode_status ⇒ ::Google::Ads::AdManager::V1::VideoTranscodeStatusEnum::VideoTranscodeStatus
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#video_source_url ⇒ ::String
Optional.
Instance Attribute Details
#display_name ⇒ ::String
Returns Required. The display name of the Slate. It has a maximum length of 255 characters.
49 50 51 52 |
# File 'proto_docs/google/ads/admanager/v1/slate_messages.rb', line 49 class Slate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The resource name of the Slate.
Format: networks/{network_code}/slates/{slate_id}.
49 50 51 52 |
# File 'proto_docs/google/ads/admanager/v1/slate_messages.rb', line 49 class Slate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#status ⇒ ::Google::Ads::AdManager::V1::SlateStatusEnum::SlateStatus (readonly)
Returns Output only. The status of this Slate. Slates are created in the [SlateStatus.ACTIVE][] state.
49 50 51 52 |
# File 'proto_docs/google/ads/admanager/v1/slate_messages.rb', line 49 class Slate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#transcode_status ⇒ ::Google::Ads::AdManager::V1::VideoTranscodeStatusEnum::VideoTranscodeStatus (readonly)
Returns Output only. Server side transcoding status of the current slate.
49 50 51 52 |
# File 'proto_docs/google/ads/admanager/v1/slate_messages.rb', line 49 class Slate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The date and time this slate was last modified.
49 50 51 52 |
# File 'proto_docs/google/ads/admanager/v1/slate_messages.rb', line 49 class Slate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#video_source_url ⇒ ::String
Returns Optional. The location of the original asset if publisher provided and slate is externally hosted.
49 50 51 52 |
# File 'proto_docs/google/ads/admanager/v1/slate_messages.rb', line 49 class Slate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |