Class: Google::Ads::AdManager::V1::SuggestedAdUnit
- Inherits:
-
Object
- Object
- Google::Ads::AdManager::V1::SuggestedAdUnit
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/admanager/v1/suggested_ad_unit_messages.rb
Overview
A read-only suggestion for a new ad unit based on an ad tag that has served 10+ times in the past week for an undefined ad unit.
Instance Attribute Summary collapse
-
#ad_unit_sizes ⇒ ::Array<::Google::Ads::AdManager::V1::AdUnitSize>
readonly
Output only.
-
#existing_code_path ⇒ ::Array<::Google::Ads::AdManager::V1::AdUnitParent>
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#new_code_path ⇒ ::Array<::String>
readonly
Output only.
-
#target_platform ⇒ ::Google::Ads::AdManager::V1::TargetPlatformEnum::TargetPlatform
readonly
Output only.
-
#target_window ⇒ ::Google::Ads::AdManager::V1::TargetWindowEnum::TargetWindow
readonly
Output only.
-
#weekly_request_count ⇒ ::Integer
readonly
Output only.
Instance Attribute Details
#ad_unit_sizes ⇒ ::Array<::Google::Ads::AdManager::V1::AdUnitSize> (readonly)
Returns Output only. Sizes associated with this suggested ad unit.
68 69 70 71 |
# File 'proto_docs/google/ads/admanager/v1/suggested_ad_unit_messages.rb', line 68 class SuggestedAdUnit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#existing_code_path ⇒ ::Array<::Google::Ads::AdManager::V1::AdUnitParent> (readonly)
Returns Output only. Code path of ad units leading up to and including the parent
of the first suggested ad unit. Combined with the new_code_path field,
this represents the full path for the suggested ad unit if approved.
Example:
If a -> b -> c are existing ad units with parent-child relationships, and
the suggested ad unit x is a child of c, the existing_code_path is (a,
b, c). If x is the grandchild of c, the existing_code_path is also (a,
b, c).
68 69 70 71 |
# File 'proto_docs/google/ads/admanager/v1/suggested_ad_unit_messages.rb', line 68 class SuggestedAdUnit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. Resource name of the SuggestedAdUnit.
Format: networks/{network_code}/suggestedAdUnits/{suggested_ad_unit_id}.
68 69 70 71 |
# File 'proto_docs/google/ads/admanager/v1/suggested_ad_unit_messages.rb', line 68 class SuggestedAdUnit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#new_code_path ⇒ ::Array<::String> (readonly)
Returns Output only. Path of suggested ad unit codes from the closest existing ancestor ad unit that will all be created as ad units when the suggestion is approved.
Example:
If a -> b -> c are existing ad units with parent-child
relationships, and the suggested ad unit x is a child of c, the
new_code_path is (x).
If x is the grandchild of c, the new_code_path is (y, x)
where y is an ad unit that would be created as the parent ad unit of x (and
the child of c) if the suggestion is approved.
68 69 70 71 |
# File 'proto_docs/google/ads/admanager/v1/suggested_ad_unit_messages.rb', line 68 class SuggestedAdUnit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#target_platform ⇒ ::Google::Ads::AdManager::V1::TargetPlatformEnum::TargetPlatform (readonly)
Returns Output only. Target platform for the browser that clicked the underlying ad tag.
68 69 70 71 |
# File 'proto_docs/google/ads/admanager/v1/suggested_ad_unit_messages.rb', line 68 class SuggestedAdUnit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#target_window ⇒ ::Google::Ads::AdManager::V1::TargetWindowEnum::TargetWindow (readonly)
Returns Output only. Target window of the underlying ad tag which will be used in the ad unit if the suggestion is approved.
68 69 70 71 |
# File 'proto_docs/google/ads/admanager/v1/suggested_ad_unit_messages.rb', line 68 class SuggestedAdUnit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#weekly_request_count ⇒ ::Integer (readonly)
Returns Output only. Number of times the ad tag has been served in the past week.
68 69 70 71 |
# File 'proto_docs/google/ads/admanager/v1/suggested_ad_unit_messages.rb', line 68 class SuggestedAdUnit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |